<?php

// Open Conference Systems 1.1
// (c) The Public Knowledge Project 2003
// http://www.pkp.ubc.ca
//
// This file is part of Open Conference Systems.
// 
// Open Conference Systems is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// Open Conference Systems is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with Open Conference Systems; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
// 
// admin/backup.php
// 
// $Id: backup.php,v 1.4 2003/04/01 07:58:46 kevin Exp $
// 
// script to backup and restore the conference database
// Note: backup code is based on that included in phpBB2 RC4 (http://phpbb.sourceforge.net)


// include necessary files
include("include/validate.inc.php");
include("../include/common.inc.php");

// get cookie
include("include/cookie.inc.php");
getadmincookie();

// this page's title
$title = "Backup/Restore Conference Database";

// creates a hierarchal tree to be printed out in header.php
$tree = array("Conference Manager"=>print_url("index.php"));


// validate the user's username and password, and formard to login page if invalid
if(!validate($username,$password) || ($multiple && $cf) || (!$multiple && !$cf)) {
	Header("Location: ".$baseurl.print_url("admin/index.php"));
	exit;
}


// generate a backup
if($action=="backup") {
	check_referer();

	$tables = $dbtables;

	$date = date("Y-m-d");

	header("Content-Type: text/x-delimtext; name=\"ocs-backup-$date.sql\"");
	header("Content-Disposition: inline; filename=\"ocs-backup-$date.sql\"\n");

	if($db_type == "pgsql") {
		echo pg_get_sequences();
	}

	for($i=0; $i<count($tables); $i++) {
		$table_name = $tables[$i];
		
		echo "--\n-- TABLE: $table_name\n--\n";

		if($db_type == "pgsql") {
			echo get_table_def_postgresql($table_name);
			echo "\n\n";
			get_table_content_postgresql($table_name, "output_table_content");
		
		}
		else {
			echo get_table_def_mysql($table_name);
			echo "\n\n";
			get_table_content_mysql($table_name, "output_table_content");
		}
		
		echo "\n\n";
	}
	exit;
}


// include the html header file
include("../include/header.inc.php");


// restore database
if($action == "restore" && $confirm == "true" && is_uploaded_file($backup_file)) {
	check_referer();

	$query = fread(fopen($backup_file, 'r'), filesize($backup_file));
	
	if($query == "") {
		echo "<p>Invalid backup file.</p>";
	}
	else {
		$query = remove_remarks($query);
		$pieces = split_sql_file($query, ";");
		
		$sql_count = count($pieces);
		for($i = 0; $i < $sql_count; $i++) {
			$sql = trim($pieces[$i]);

			if(!empty($sql) and $sql[0] != "--") {
				if(VERBOSE == 1) {
					echo "Executing: $sql\n<br />";
					flush();
				}

				$result = $db->query($sql);

				if(!$result && ( !($db_type == 'pgsql' && eregi("drop table", $sql) ) ) ) {
					die("Error importing backup file ".__LINE__." ".__FILE__." ".$sql);
				}
			}
		}
		
		echo "<p>Backup was restored successfully.</p>";
	}
}


// show form to upload backup file for restoration
else if($action == "restore") {
?>

<form action="<?php echo print_url("backup.php?action=restore"); ?>" method="post" enctype="multipart/form-data">
<input type="hidden" name="confirm" value="true">
<p><font class="ArticleTitle">Restore Database</font></p>

<p>Backup file: <input type="file" name="backup_file"><br />
<font class="instructions">Upload the backup file you would like to restore your conference database from. Note: you will lose any changes made to your site since the time the backup was made.</font></p>

<p><input type="submit" value="Restore" class="button"></p>
</form>

<?php
}


// show options
else {
?>

<p><font class="MainText">Use this page to make a backup of your conference database, or to restore it from a backup.</font></p>

<p><font class="ArticleTitle">Backup Database</font></p>

<p><b><a href="<?php echo print_url("backup.php?action=backup"); ?>">Download Backup</a></b><br />
<font class="instructions">Click on the above link to download a dump of the conference database. You can use this file to restore your database using the restore function below.</font></p>

<p><font class="ArticleTitle">Restore Database</font></p>

<p><b><a href="<?php echo print_url("backup.php?action=restore"); ?>">Restore Backup</a></b><br />
<font class="instructions">Click on the above link and you will be prompted to upload a backup of your database to restore from. Note: you will lose any changes made to your site since the time the backup was made.</font></p>
<?php
}
?>

<p><b><a href="<?php echo print_url("index2.php"); ?>">Return to Conference Manager</a></b></p>

<table>
<tr valign="middle" height="16"><td width="10"><img src="<?php echo $themesdir; ?>images/arrow.gif" width="12" height="12" border="0"></td><td><b><a href="<?php echo print_url("index2.php?action=logout"); ?>">Log Out</a></b></td></tr>
</table>

<?php


// include the html footer file
include("../include/footer.inc.php");



// Database backup functions, based on phpBB2

//
// This function is used for grabbing the sequences for postgres...
//
function pg_get_sequences()
{
	global $db;

	$get_seq_sql = "SELECT relname FROM pg_class WHERE NOT relname ~ 'pg_.*'
		AND relkind = 'S' ORDER BY relname";

	$seq = $db->query($get_seq_sql);

	if(!$num_seq = $db->num_rows($seq)) {
		$return_val = "-- No Sequences Found \n";
	}
	else {
		$return_val = "-- Sequences \n";
		$i_seq = 0;

		while($i_seq < $num_seq) {
			$row = $db->assoc_array($seq, $i_seq);
			$sequence = $row['relname'];

			$get_props_sql = "SELECT * FROM $sequence";
			$seq_props = $db->query($get_props_sql);

			if($db->num_rows($seq_props) > 0) {
				$row1 = $db->assoc_array($seq_props);

				$return_val .= "CREATE SEQUENCE $sequence start " . $row['last_value'] . ' increment ' . $row['increment_by'] . ' maxvalue ' . $row['max_value'] . ' minvalue ' . $row['min_value'] . ' cache ' . $row['cache_value'] . "; \n";

			}  // End if numrows > 0

			if($row['last_value'] > 1) {
				$return_val .= "SELECT NEXTVALE('$sequence'); \n";
				unset($row['last_value']);
			}

			$i_seq++;

		}

	}

	return $returnval;
}


//
// The following functions will return the "CREATE TABLE syntax for the
// varying DBMS's
//
// This function returns, will return the table def's for postgres...
//
function get_table_def_postgresql($table)
{
	global $db;
	$drop = 1;

	$schema_create = "";
	//
	// Get a listing of the fields, with their associated types, etc.
	//

	$field_query = "SELECT a.attnum, a.attname AS field, t.typname as type, a.attlen AS length, a.atttypmod as lengthvar, a.attnotnull as notnull
		FROM pg_class c, pg_attribute a, pg_type t
		WHERE c.relname = '$table'
			AND a.attnum > 0
			AND a.attrelid = c.oid
			AND a.atttypid = t.oid
		ORDER BY a.attnum";
	$result = $db->query($field_query);

	if(!$result) {
		die("Failed in get_table_def (show fields) ".__LINE__." ".__FILE__. " ".$field_query);
	}

	if($drop == 1) {
		$schema_create .= "DROP TABLE $table;\n";
	}

	//
	// Ok now we actually start building the SQL statements to restore the tables
	//

	$schema_create .= "CREATE TABLE $table(\n";

	for($i=0; $i<$db->num_rows($result); $i++) {
		$row = $db->assoc_array($result, $i);

		//
		// Get the data from the table
		//
		$sql_get_default = "SELECT d.adsrc AS rowdefault
			FROM pg_attrdef d, pg_class c
			WHERE (c.relname = '$table')
				AND (c.oid = d.adrelid)
				AND d.adnum = " . $row['attnum'];
		$def_res = $db->query($sql_get_default);

		if(!$def_res) {
			unset($row['rowdefault']);
		}
		else {
			$row['rowdefault'] = @pg_result($def_res, 0, 'rowdefault');
		}

		if($row['type'] == 'bpchar') {
			// Internally stored as bpchar, but isn't accepted in a CREATE TABLE statement.
			$row['type'] = 'char';
		}

		$schema_create .= '	' . $row['field'] . ' ' . $row['type'];

		if(eregi('char', $row['type'])) {
			if($row['lengthvar'] > 0)
			{
				$schema_create .= '(' . ($row['lengthvar'] -4) . ')';
			}
		}

		if(eregi('numeric', $row['type'])) {
			$schema_create .= '(';
			$schema_create .= sprintf("%s,%s", (($row['lengthvar'] >> 16) & 0xffff), (($row['lengthvar'] - 4) & 0xffff));
			$schema_create .= ')';
		}

		if(!empty($row['rowdefault'])) {
			$schema_create .= ' DEFAULT ' . $row['rowdefault'];
		}

		if($row['notnull'] == 't') {
			$schema_create .= ' NOT NULL';
		}

		$schema_create .= ",\n";

	}
	//
	// Get the listing of primary keys.
	//

	$sql_pri_keys = "SELECT ic.relname AS index_name, bc.relname AS tab_name, ta.attname AS column_name, i.indisunique AS unique_key, i.indisprimary AS primary_key
		FROM pg_class bc, pg_class ic, pg_index i, pg_attribute ta, pg_attribute ia
		WHERE (bc.oid = i.indrelid)
			AND (ic.oid = i.indexrelid)
			AND (ia.attrelid = i.indexrelid)
			AND	(ta.attrelid = bc.oid)
			AND (bc.relname = '$table')
			AND (ta.attrelid = i.indrelid)
			AND (ta.attnum = i.indkey[ia.attnum-1])
		ORDER BY index_name, tab_name, column_name ";
	$result = $db->query($sql_pri_keys);

	if(!$result) {
		die("Failed in get_table_def (show fields) ".__LINE__." ".__FILE__." ".$sql_pri_keys);
	}

	for($i=0; $i<$db->num_rows($result); $i++) {
		$row = $db->assoc_array($result, $i);
	
		if($row['primary_key'] == 't') {
			if(!empty($primary_key))
			{
				$primary_key .= ', ';
			}

			$primary_key .= $row['column_name'];
			$primary_key_name = $row['index_name'];

		}
		else {
			//
			// We have to store this all this info because it is possible to have a multi-column key...
			// we can loop through it again and build the statement
			//
			$index_rows[$row['index_name']]['table'] = $table;
			$index_rows[$row['index_name']]['unique'] = ($row['unique_key'] == 't') ? ' UNIQUE ' : '';
			$index_rows[$row['index_name']]['column_names'] .= $row['column_name'] . ', ';
		}
	}

	if(!empty($index_rows)) {
		while(list($idx_name, $props) = each($index_rows)) {
			$props['column_names'] = ereg_replace(", $", "" , $props['column_names']);
			$index_create .= 'CREATE ' . $props['unique'] . " INDEX $idx_name ON $table (" . $props['column_names'] . ");\n";
		}
	}

	if(!empty($primary_key)) {
		$schema_create .= "	CONSTRAINT $primary_key_name PRIMARY KEY ($primary_key),\n";
	}

	//
	// Generate constraint clauses for CHECK constraints
	//
	$sql_checks = "SELECT rcname as index_name, rcsrc
		FROM pg_relcheck, pg_class bc
		WHERE rcrelid = bc.oid
			AND bc.relname = '$table'
			AND NOT EXISTS (
				SELECT *
					FROM pg_relcheck as c, pg_inherits as i
					WHERE i.inhrelid = pg_relcheck.rcrelid
						AND c.rcname = pg_relcheck.rcname
						AND c.rcsrc = pg_relcheck.rcsrc
						AND c.rcrelid = i.inhparent
			)";
	$result = $db->query($sql_checks);

	if(!$result) {
		die("Failed in get_table_def (show fields) ".__LINE__." ".__FILE__." ".$sql_checks);
	}

	//
	// Add the constraints to the sql file.
	//
	for($i=0; $i<$db->num_rows($result); $i++) {
		$row = $db->assoc_array($result, $i);
		$schema_create .= '	CONSTRAINT ' . $row['index_name'] . ' CHECK ' . $row['rcsrc'] . ",\n";
	}

	$schema_create = ereg_replace(',' . "\n" . '$', '', $schema_create);
	$index_create = ereg_replace(',' . "\n" . '$', '', $index_create);

	$schema_create .= "\n);\n";

	if(!empty($index_create)) {
		$schema_create .= $index_create;
	}

	//
	// Ok now we've built all the sql return it to the calling function.
	//
	return (stripslashes($schema_create));

}

//
// This function returns the "CREATE TABLE" syntax for mysql dbms...
//
function get_table_def_mysql($table)
{
	global $db;
	$drop = 1;

	$schema_create = "";
	$field_query = "SHOW FIELDS FROM $table";
	$key_query = "SHOW KEYS FROM $table";

	//
	// If the user has selected to drop existing tables when doing a restore.
	// Then we add the statement to drop the tables....
	//
	if($drop == 1) {
		$schema_create .= "DROP TABLE IF EXISTS $table;\n";
	}

	$schema_create .= "CREATE TABLE $table(\n";

	//
	// Ok lets grab the fields...
	//
	$result = $db->query($field_query);
	if(!result) {
		die("Failed in get_table_def (show fields) ".__LINE__." ".__FILE__." ".$field_query);
	}

	for($i=0; $i<$db->num_rows($result); $i++) {
		$row = $db->assoc_array($result, $i);

		$schema_create .= '	' . $row['Field'] . ' ' . $row['Type'];

		if(!empty($row['Default'])) {
			$schema_create .= ' DEFAULT \'' . $row['Default'] . '\'';
		}

		if($row['Null'] != "YES") {
			$schema_create .= ' NOT NULL';
		}

		if($row['Extra'] != "") {
			$schema_create .= ' ' . $row['Extra'];
		}

		$schema_create .= ",\n";
	}
	//
	// Drop the last ',\n' off ;)
	//
	$schema_create = ereg_replace(',' . "\n" . '$', "", $schema_create);

	//
	// Get any Indexed fields from the database...
	//
	$result = $db->query($key_query);
	if(!$result) {
		die("FAILED IN get_table_def (show keys) ".__LINE__." ".__FILE__." ".$key_query);
	}

	for($i=0; $i<$db->num_rows($result); $i++) {
		$row = $db->assoc_array($result, $i);

		$kname = $row['Key_name'];

		if(($kname != 'PRIMARY') && ($row['Non_unique'] == 0)) {
			$kname = "UNIQUE|$kname";
		}
		else if($row['Comment'] == "FULLTEXT") {
			$kname = "FULLTEXT|$kname";
		}

		if(!is_array($index[$kname])) {
			$index[$kname] = array();
		}

		$index[$kname][] = $row['Column_name'];
	}

	while(list($x, $columns) = @each($index)) {
		$schema_create .= ", \n";

		if($x == 'PRIMARY') {
			$schema_create .= '	PRIMARY KEY (' . implode($columns, ', ') . ')';
		}
		else if(substr($x,0,6) == 'UNIQUE') {
			$schema_create .= '	UNIQUE ' . substr($x,7) . ' (' . implode($columns, ', ') . ')';
		}
		else if(substr($x,0,8) == 'FULLTEXT') {
			$schema_create .= '	FULLTEXT ' . substr($x,9) . ' (' . implode($columns, ', ') . ')';
		}
		else {
			$schema_create .= "	KEY $x (" . implode($columns, ', ') . ')';
		}
	}

	$schema_create .= "\n);";

	if(get_magic_quotes_runtime()) {
		return(stripslashes($schema_create));
	}
	else {
		return($schema_create);
	}

}


//
// This fuction will return a tables create definition to be used as an sql
// statement.
//
//
// The following functions Get the data from the tables and format it as a
// series of INSERT statements, for each different DBMS...
// After every row a custom callback function $handler gets called.
// $handler must accept one parameter ($sql_insert);
//
//
// Here is the function for postgres...
//
function get_table_content_postgresql($table, $handler)
{
	global $db;

	//
	// Grab all of the data from current table.
	//

	$result = $db->query("SELECT * FROM $table");

	if(!$result) {
		die("Failed in get_table_content (select *) ".__LINE__." ".__FILE__." SELECT * FROM $table");
	}

	$i_num_fields = $db->num_fields($result);

	for($i = 0; $i < $i_num_fields; $i++) {
		$aryType[] = $db->field_type($result, $i);
		$aryName[] = $db->field_name($result, $i);
	}

	$iRec = 0;

	for($x=0; $x<$db->num_rows($result); $x++) {
		$row = $db->assoc_array($result, $x);

		unset($schema_vals);
		unset($schema_fields);
		unset($schema_insert);
		//
		// Build the SQL statement to recreate the data.
		//
		for($i = 0; $i < $i_num_fields; $i++) {
			$strVal = $row[$aryName[$i]];
			if(eregi("char|text|bool", $aryType[$i]))
			{
				$strQuote = "'";
				$strEmpty = "";
				$strVal = addslashes($strVal);
			}
			else if(eregi("date|timestamp", $aryType[$i]))
			{
				if(empty($strVal))
				{
					$strQuote = "";
					$strEmpty = "NULL";
				}
				else
				{
					$strQuote = "'";
				}
			}
			else
			{
				$strQuote = "";
				$strEmpty = "NULL";
			}

			if(empty($strVal) && $strVal != "0")
			{
				$strVal = $strEmpty;
			}

			$schema_vals .= " $strQuote$strVal$strQuote,";
			$schema_fields .= " $aryName[$i],";

		}

		$schema_vals = ereg_replace(",$", "", $schema_vals);
		$schema_vals = ereg_replace("^ ", "", $schema_vals);
		$schema_fields = ereg_replace(",$", "", $schema_fields);
		$schema_fields = ereg_replace("^ ", "", $schema_fields);

		//
		// Take the ordered fields and their associated data and build it
		// into a valid sql statement to recreate that field in the data.
		//
		$schema_insert = "INSERT INTO $table ($schema_fields) VALUES($schema_vals);";

		$handler(trim($schema_insert));
	}

	return(true);

}

//
// This function is for getting the data from a mysql table.
//

function get_table_content_mysql($table, $handler)
{
	global $db;
	//
	// Grab the data from the table.
	//
	$result = $db->query("SELECT * FROM $table");

	if(!$result) {
		die("Failed in get_table_content (select *) ".__LINE__." ".__FILE__." SELECT * FROM $table");
	}

	if($db->num_rows($result) > 0) {
		$schema_insert = "\n--\n-- Table Data for $table\n--\n";
	}
	else {
		$schema_insert = "";
	}

	$handler($schema_insert);

	//
	// Loop through the resulting rows and build the sql statement.
	//

	for($x=0; $x<$db->num_rows($result); $x++) {
		$row = $db->assoc_array($result, $x);

		$table_list = '(';
		$num_fields = $db->num_fields($result);
		//
		// Grab the list of field names.
		//
		for($j = 0; $j < $num_fields; $j++) {
			$table_list .= $db->field_name($result, $j) . ', ';
		}
		//
		// Get rid of the last comma
		//
		$table_list = ereg_replace(', $', '', $table_list);
		$table_list .= ')';
		//
		// Start building the SQL statement.
		//
		$schema_insert = "INSERT INTO $table $table_list VALUES(";
		//
		// Loop through the rows and fill in data for each column
		//
		for($j = 0; $j < $num_fields; $j++) {
			if(!isset($row[$j]))
			{
				//
				// If there is no data for the column set it to null.
				// There was a problem here with an extra space causing the
				// sql file not to reimport if the last column was null in
				// any table.  Should be fixed now :) JLH
				//
				$schema_insert .= ' NULL,';
			}
			else if($row[$j] != '')
			{
				$schema_insert .= ' \'' . addslashes($row[$j]) . '\',';
			}
			else
			{
				$schema_insert .= '\'\',';
			}
		}
		//
		// Get rid of the the last comma.
		//
		$schema_insert = ereg_replace(',$', '', $schema_insert);
		$schema_insert .= ');';
		//
		// Go ahead and send the insert statement to the handler function.
		//
		$handler(trim($schema_insert));

	}
	return(true);
}


function output_table_content($content)
{
	echo $content ."\n";
	return;
}



// Database restore functions, based on phpBB2

//
// remove_remarks will strip the sql comment lines out of an uploaded sql file
//
function remove_remarks($sql)
{
	$lines = explode("\n", $sql);
	
	// try to keep mem. use down
	$sql = "";
	
	$linecount = count($lines);
	$output = "";

	for($i = 0; $i < $linecount; $i++) {
		if(($i != ($linecount - 1)) || (strlen($lines[$i]) > 0)) {
			if($lines[$i][0] != "--") {
				$output .= $lines[$i] . "\n";
			}
			else {
				$output .= "\n";
			}
			// Trading a bit of speed for lower mem. use here.
			$lines[$i] = "";
		}
	}
	
	return $output;
}


//
// split_sql_file will split an uploaded sql file into single sql statements.
// Note: expects trim() to have already been run on $sql.
//
function split_sql_file($sql, $delimiter) {
	// Split up our string into "possible" SQL statements.
	$tokens = explode($delimiter, $sql);

	// try to save mem.
	$sql = "";
	$output = array();
	
	// we don't actually care about the matches preg gives us.
	$matches = array();
	
	// this is faster than calling count($oktens) every time thru the loop.
	$token_count = count($tokens);
	for($i = 0; $i < $token_count; $i++) {
		// Don't wanna add an empty string as the last thing in the array.
		if(($i != ($token_count - 1)) || (strlen($tokens[$i] > 0))) {
			// This is the total number of single quotes in the token.
			$total_quotes = preg_match_all("/'/", $tokens[$i], $matches);
			// Counts single quotes that are preceded by an odd number of backslashes, 
			// which means they're escaped quotes.
			$escaped_quotes = preg_match_all("/(?<!\\\\)(\\\\\\\\)*\\\\'/", $tokens[$i], $matches);
			
			$unescaped_quotes = $total_quotes - $escaped_quotes;
			
			// If the number of unescaped quotes is even, then the delimiter did NOT occur inside a string literal.
			if(($unescaped_quotes % 2) == 0) {
				// It's a complete sql statement.
				$output[] = $tokens[$i];
				// save memory.
				$tokens[$i] = "";
			}
			else {
				// incomplete sql statement. keep adding tokens until we have a complete one.
				// $temp will hold what we have so far.
				$temp = $tokens[$i] . $delimiter;
				// save memory..
				$tokens[$i] = "";
				
				// Do we have a complete statement yet? 
				$complete_stmt = false;
				
				for($j = $i + 1; (!$complete_stmt && ($j < $token_count)); $j++) {
					// This is the total number of single quotes in the token.
					$total_quotes = preg_match_all("/'/", $tokens[$j], $matches);
					// Counts single quotes that are preceded by an odd number of backslashes, 
					// which means they're escaped quotes.
					$escaped_quotes = preg_match_all("/(?<!\\\\)(\\\\\\\\)*\\\\'/", $tokens[$j], $matches);
			
					$unescaped_quotes = $total_quotes - $escaped_quotes;
					
					if(($unescaped_quotes % 2) == 1) {
						// odd number of unescaped quotes. In combination with the previous incomplete
						// statement(s), we now have a complete statement. (2 odds always make an even)
						$output[] = $temp . $tokens[$j];

						// save memory.
						$tokens[$j] = "";
						$temp = "";
						
						// exit the loop.
						$complete_stmt = true;
						// make sure the outer loop continues at the right point.
						$i = $j;
					}
					else {
						// even number of unescaped quotes. We still don't have a complete statement. 
						// (1 odd and 1 even always make an odd)
						$temp .= $tokens[$j] . $delimiter;
						// save memory.
						$tokens[$j] = "";
					}
					
				}
			}
		}
	}

	return $output;
}

?>