<?php

// Open Conference Systems 1.1
// (c) The Public Knowledge Project 2003
// http://www.pkp.ubc.ca
//
// This file is part of Open Conference Systems.
// 
// Open Conference Systems is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// Open Conference Systems is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with Open Conference Systems; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
// 
// admin/reviewers.php
// 
// $Id: reviewers.php,v 1.4 2003/04/01 07:58:47 kevin Exp $
// 
// script to view and edit list of invited speakers


// include necessary files
include("include/validate.inc.php");
include("../include/common.inc.php");

if(!isset($cf)) {
	header("Location: index.php");
	exit;
}


// get cookie
include("include/cookie.inc.php");
getadmincookie();

// this page's title
$title = "Reviewers";

// creates a hierarchal tree to be printed out in header.php
$tree = array("Conference Manager"=>print_url("index.php"));


// validate the user's username and password, and formard to login page if invalid
if(!validate($username,$password)) {
	Header("Location: ".$baseurl.print_url("admin/index.php"));
	exit;
}

// assign papers to reviewers automatically
if($action=="assign") {
	check_referer();

	// get number of reviewers per paper
	$num_reviewersper = $conference_items[num_reviewers];
	// assign default value to number of reviewers per paper if not defined
	if(!$num_reviewersper || $num_reviewersper <= 0) {
		$num_reviewersper = 1;
	}
	
	// get unreviewed paper info from database
	$papers = array();
	$numassigned = array();
	$paper_result = $db->query("Select id from $dbtable[papers] where accepted='false' and (present_format!='multiple' or (present_format='multiple' and multiple_title!='')) and cf='$cf'");
	$numpapers = $db->num_rows($paper_result);
	
	for($i=0; $i<$numpapers; $i++) {
		$items = $db->assoc_array($paper_result, $i);
		$papers[$i] = $items[id];
		// get number of reviewers currently assigned to this paper
		$review_result = $db->query("select count(*) from $dbtable[reviewer_proposals] where paper='$items[id]' and cf='$cf'");
		$review_items = $db->assoc_array($review_result);
		$numassigned[$items[id]] = $review_items[0];
	}
	
	// get list of reviewers
	$review_result = $db->query("select login, password from $dbtable[reviewers] where cf='$cf'");
	$num_reviewers = $db->num_rows($review_result);
	
	// check that there is at least one reviewer
	if($num_reviewers != 0) {
		// lower value of number of reviewers per paper if it is higher than the number of reviewers
		if($num_reviewersper>$num_reviewers) {
			$num_reviewersper = $num_reviewers;
		}
		
		// get the number of papers each reviewer will be reviewing
		$numeach = ceil(($numpapers*$num_reviewersper)/$num_reviewers);
		
		// seed random number generator
		mt_srand((double)microtime()*1000000);
		
		// go through each reviewer and assign them papers to review
		for($i=0; $i<$num_reviewers; $i++) {
			$review_items = $db->assoc_array($review_result);
			$hasassigned = array();
			$haschecked = array();
			
			// get papers currently assigned to this reviewer
			$result = $db->query("select paper from $dbtable[reviewer_proposals] where reviewer='$review_items[login]' and cf='$cf' order by paper");
			for($j=0; $j<$db->num_rows($result); $j++) {
				$items = $db->assoc_array($result);
				array_push($hasassigned, $items[paper]);
			}
			
			$currassigned = $hasassigned;
			
			// check if reviewer has already been assigned enough proposals
			while(count($hasassigned) < $numeach) {
				// pick a random paper
				$rand = @mt_rand(0, count($papers)-1);
				$paper = $papers[$rand];
				
				// check if can be assigend
				if(!in_array($paper, $haschecked) && !in_array($paper, $hasassigned) && $numassigned[$paper] < $numeach) {
					// assign paper
					array_push($hasassigned, $paper);
					$numassigned[$paper]++;
				}
				else if(!in_array($paper, $haschecked)) {
					array_push($haschecked, $paper);
				}
	
				// break if we've been through all papers
				if(count($haschecked) >= $numpapers) {
					break;
				}	
			}
					
			// update reviewer's propoals for review in database
			for($j=0; $j<count($hasassigned); $j++) {
				if(!in_array($hasassigned[$j], $currassigned)) {
					$db->query("insert into $dbtable[reviewer_proposals] (cf, reviewer, paper) values ('$cf', '$review_items[login]', '$hasassigned[$j]')");
				}
			}
		}
	}
	
	$view="all";
}

// include the html header file
include("../include/header.inc.php");


// add a new reviewer
if($add) {
	check_referer();

	// check that required fields are complete
	if(empty($name) || empty($email) || empty($login) || empty($upassword)) {
		?>
		<p>Submission incomplete. Please go <a href="javascript:history.go(-1)">back</a> and complete all fields.</p>
		<?php
	}
	// check if username is valid
	else if(!check_name($login)) {
		?>
		<p>Username is invalid. Please go <a href="javascript:history.go(-1)">back</a> and correct your submission.</p>
		<?php
	}
	// check if password is valid
	else if(!check_name($upassword)) {
		?>
		<p>Password is invalid. Please go <a href="javascript:history.go(-1)">back</a> and correct your submission.</p>
		<?php
	}
	// check if email is valid
	else if(!check_email($email)) {
		?>
		<p>Email address is invalid. Please go <a href="javascript:history.go(-1)">back</a> and correct your submission.</p>
		<?php
	}
	// add entry to database
	else {
		list($login, $upassword, $name, $email) = strip_html($login, $upassword, $name, $email);

		list($login, $upassword, $name, $email) = sanitize_db_input($login, $upassword, $name, $email);

		// check that this isn't a duplicate
		$result = $db->query("Select login from $dbtable[reviewers] where lower(login)=lower('$login') and cf='$cf'");
		if($db->num_rows($result)==0) {
			$db->query("insert into $dbtable[reviewers] (cf, login, password, name, email) values ('$cf', '$login','".base64_encode($upassword)."','$name','$email')") or die("Unable to add entry to database");
			?>
			<p><?php echo sanitize_output($name); ?> has been added.</p>
				<p><a href="<?php echo print_url("reviewers.php"); ?>"><b>Back to Reviewers</b></a></p>
			<?php
		}
		// else print error if duplicate
		else {
			?>
			<p>A reviewer already exists with this username. Please go <a href="javascript:history.go(-1)">back</a> and modify the username field in order to add this reviewer.</p>
			<?php
		}
	}

}

// edit an existing reviewer's information
else if($edit) {
	$edit = sanitize_db_input($edit);

	// get reviewer's info from database
	$result = $db->query("Select * from $dbtable[reviewers] where login='$edit' and cf='$cf'");
	$items = $db->assoc_array($result);
	// print out reviewer's info if it is a valid reviewer
	if($items[login]) {
		// print out edit form
		?>
		<p><form action="<?php echo print_url("reviewers.php"); ?>" method="post"><input type="hidden" name="update" value="<?php echo $items[login]; ?>"><table border="0" cellpadding="0" cellspacing="0">
<tr><td width="130">Name: </td><td><input type="text" name="name" value="<?php echo $items[name]; ?>"><br /></td></tr>
<tr><td width="130" background="<?php echo $themesdir; ?>images/srchbg.gif">Email: </td><td><input type="text" name="email" value="<?php echo $items[email]; ?>"><br /></td></tr>
		<tr valign="top"><td width="130"><a href="<?php echo print_url("reviews.php"); ?>" target="_blank">Proposal Numbers</a>:</td><td><table border="0" cellpadding="0" cellspacing="0">
		<?php
		// show list of proposals for this reviewer
		$result = $db->query("select paper from $dbtable[reviewer_proposals] where reviewer='$items[login]' and cf='$cf' order by paper");
		for($i=0; $i<$db->num_rows($result); $i++) {
			$review_items = $db->assoc_array($result, $i);
			?><tr><td><a href="<?php echo print_url("reviews.php?id=$review_items[paper]"); ?>"><?php echo $review_items[paper]; ?></a> </td><td> <input type="checkbox" name="unassign[]" value="<?php echo $review_items[paper]; ?>"> Unassign</td></tr><?php		
		}
		if($db->num_rows($result) == 0) { echo "<tr><td>None</td></tr>"; }
		
		?>
		</table></td></tr>
		<tr><td width="130" background="<?php echo $themesdir; ?>images/srchbg.gif">Username: </td><td><?php echo $items[login]; ?><input type="hidden" name="login" value="<?php echo $items[login]; ?>"><br /></td></tr>
<tr><td width="130">Password: </td><td><input type="text" name="upassword" value="<?php echo base64_decode($items[password]); ?>"><br /></td></tr>
<tr><td colspan="2"><font class="instructions">Usernames and passwords may contain only alphanumeric characters.</font></td></tr>
<tr><td colspan="2">Delete: <input type="checkbox" name="delete" value="true"> <font class="SmallText">(Check box to delete this reviewer)</font><br /></td></tr>
<tr><td colspan="2"><br /><input type="submit" value="Update Reviewer" class="button"> <input type="reset" class="button"></td></tr></table>
</form></p>
		<p class="instructions">Note: usernames and passwords are case sensitive.</p>
		<?php
	}
	// else print out error message
	else {
		?>
		<p>Requested reviewer not found.</p>
		<?php
	}
}

// update an existing reviewer's information
else if($update) {
	check_referer();

	$update = sanitize_db_input($update);

	// check that required fields are complete
	if(empty($name) || empty($email) || empty($login) || empty($upassword)) {
		?>
		<p>Submission incomplete. Please go <a href="javascript:history.go(-1)">back</a> and complete all fields.</p>
		<?php
	}
	// check if username is valid
	else if(!check_name($login)) {
		?>
		<p>Username is invalid. Please go <a href="javascript:history.go(-1)">back</a> and correct your submission.</p>
		<?php
	}
	// check if password is valid
	else if(!check_name($upassword)) {
		?>
		<p>Password is invalid. Please go <a href="javascript:history.go(-1)">back</a> and correct your submission.</p>
		<?php
	}
	// check if email is valid
	else if(!check_email($email)) {
		?>
		<p>Email address is invalid. Please go <a href="javascript:history.go(-1)">back</a> and correct your submission.</p>
		<?php
	}
	// check if deleting
	else if($delete=="true") {
		$db->query("delete from $dbtable[reviewers] where login='$update' and cf='$cf'");
		$db->query("delete from $dbtable[reviewer_proposals] where reviewer='$update' and cf='$cf'");
		$db->query("delete from $dbtable[reviews] where reviewer='$update' and cf='$cf'");
		?>
		<p><?php echo $name; ?> has been deleted.</p>
			<p><a href="<?php echo print_url("reviewers.php"); ?>"><b>Back to Reviewers</b></a></p>
		<?php
	}
	// update entry in database
	else {
		list($login, $upassword, $name, $email) = strip_html($update, $upassword, $name, $email);
		list($login, $upassword, $name, $email) = sanitize_db_input($update, $upassword, $name, $email);

		$db->query("update $dbtable[reviewers] set login='$login', password='".base64_encode($upassword)."', name='$name', email='$email' where login='$update' and cf='$cf'") or die("Unable to update entry in database");

		// unassign papers, if applicable
		if(is_array($unassign)) {
			foreach($unassign as $k=>$v) {
				$v = sanitize_db_input($v);
				$db->query("delete from $dbtable[reviewer_proposals] where reviewer='$login' and paper='$v' and cf='$cf'");
				$db->query("delete from $dbtable[reviews] where reviewer='$login' and paper='$v' and cf='$cf'");
			}
		}
		?>
		<p><?php echo sanitize_output($name); ?> has been updated.</p>
			<p><a href="<?php echo print_url("reviewers.php"); ?>"><b>Back to Reviewers</b></a></p>
		<?php
	}	
}

// else show list of reviewers
else {
	?>
	
	<p><b>Reviewers</b><br />
	<font class="SmallText">(Click on a person's name to view details)</font></p>
	
	<p><a href="<?php echo print_url("revemail.php"); ?>"><b>Preview and Send Notification Email</b></a></p>
	
	<?php
	// show link to assign papers automatically, if applicable
	if($conference_items[review_assign]=="automatic") {
		?>
		<p><a href="<?php echo print_url("reviewers.php?action=assign"); ?>"><b>Automatically Assign Reviewers to Submitted Proposals</b></a></p>
		<?php
	}
	else {
		?>
		<p><a href="<?php echo print_url("reviews.php"); ?>"><b>Manually Assign Reviewers to Submitted Proposals</b></a></p>
		<?php
	}
	?>
	
	<p><a href="#add">Add Reviewer</a></p>
	
	<?php
	// print correct message if viewing all reviewers or not
	if($view!="all") {
		?>
		<p><a href="<?php echo print_url("reviewers.php?view=all"); ?>">View Details on All Reviewers</a></p>
		<?php
	}
	else {
		?>
		<p><a href="<?php echo print_url("reviewers.php"); ?>">Hide Details on All Reviewers</a></p>
		<?php
	}
	?>
	
	<table border="0" cellpadding="0" cellspacing="0" width="600">
	
	<?php
	// get list of reviewers from database
	$result = $db->query("Select * from $dbtable[reviewers] where cf='$cf' order by login");
	
	// get rid of extraneous slashes from variable
	if($view) {
		$view = sanitize_output(urldecode($view));
	}
	
	if($db->num_rows($result) == 0) { echo "<tr><td>No reviewers.</td></tr>\n"; }
	
	// print out list
	for ($count = 0; $count<$db->num_rows($result); $count++) {
		$items = $db->assoc_array($result,$count);
		$urlname = urlencode($items[login]);
		$url = "reviewers.php";
		// print out link to view full info, if applicable
		if($view!=$items[login] && $view!="all") {
			$url .= "?view=$urlname";
		}
		echo "<tr valign=\"top\"><td width=\"10\"><a href=\"".print_url($url)."\"><img src=\"".$themesdir."images/arrow";
		// print out correct arrow image
		if($view!=$items[login] && $view!="all") {
			echo "";
		}
		else {
			echo "down";
		}
		echo ".gif\" width=\"12\" height=\"12\" border=\"0\"></a>&nbsp;</td><td width=\"590\"><a href=\"".print_url($url)."\" class=\"AuthorTextLink\">$items[name]</a> <font class=\"SmallText\">(<a href=\"".print_url("reviewers.php?edit=$urlname")."\">Edit</a>)</font>";
		// print out full info if viewing this reviewer
		if($view==$items[login] || $view=="all") {
			echo "<br />\n<a href=\"".print_url("reviews.php")."\" target=\"_blank\">Proposal Numbers</a>: ";
			// get proposals for this reviewer
			$review_result = $db->query("select paper from $dbtable[reviewer_proposals] where reviewer='$items[login]' and cf='$cf' order by paper");
			for($i=0; $i<$db->num_rows($review_result); $i++) {
				if($i > 0) { echo ", "; }
				$review_items = $db->assoc_array($review_result, $i);
				?><a href="<?php echo print_url("reviews.php?id=$review_items[paper]"); ?>"><?php echo $review_items[paper]; ?></a><?php
			}
			if($db->num_rows($review_result) == 0) { echo "None"; }
			echo "<br />
			Email Address: <a href=\"mailto:$items[email]\">$items[email]</a><br />
			Username: $items[login]<br />
			Password: ".base64_decode($items[password]);
		}
		echo "</td></tr>
		<tr height=\"10\" colspan=\"2\"><td>&nbsp;</td></tr>";
	
	}
	
	// print out form to add a reviewer
	?>
	
	</table>
	
	<hr size="1" width="100%">
	
	<a name="add"></a><p><b>Add Reviewer</b></p>
	
	<script language="JavaScript">
	// script to create a user's username and password from their name
	function setlogin(name,form) {
			var newname = name.split(" ");
			var newpassword = "";
			var namelength = newname.length;
			// their username is their surname
			var newlogin = newname[namelength-1];
			// get rid of any quotes in their username
			newlogin = newlogin.replace(/[^A-Z0-9]/ig,"");
			form.login.value = newlogin.toLowerCase();
			// their password is their firstname (and middlename(s), if applicable)
			for(var i=0;i<namelength-1;i++) {
				newpassword += newname[i];
			}
			// get rid of any quotes in their password
			newpassword = newpassword.replace(/[^A-Z0-9]/ig,"");
			form.upassword.value = newpassword.toLowerCase();
	}
	</script>
	
	<p><form action="<?php echo print_url("reviewers.php"); ?>" method="post"><table border="0" cellpadding="0" cellspacing="0">
	<tr><td width="125">Name: </td><td><input type="text" name="name" onchange="setlogin(this.value,this.form);"><br /></td></tr>
	<tr><td width="125" background="<?php echo $themesdir; ?>images/srchbg.gif">Email: </td><td><input type="text" name="email"><br /></td></tr>
	<tr><td width="125">Username: </td><td><input type="text" name="login"><br /></td></tr>
	<tr><td width="125" background="<?php echo $themesdir; ?>images/srchbg.gif">Password: </td><td><input type="text" name="upassword"><br /></td></tr>
	<tr><td colspan="2"><font class="instructions">Usernames and passwords may contain only alphanumeric characters.</font></td></tr>
	<tr><td colspan="2"><br /><input type="submit" name="add" value="Add Reviewer" class="button"> <input type="reset" class="button"></td></tr>
	</table>
	</form></p>
	<p class="instructions">Note: usernames and passwords are case sensitive.</p>

	<?php

}

?>

<p><b><a href="<?php echo print_url("index2.php"); ?>">Return to Conference Manager</a></b></p>

<table>
<tr valign="middle" height="16"><td width="10"><img src="<?php echo $themesdir; ?>images/arrow.gif" width="12" height="12" border="0"></td><td><b><a href="<?php echo print_url("index2.php?action=logout"); ?>">Log Out</a></b></td></tr>
</table>

<?php


// include the html footer file
include("../include/footer.inc.php");

?>
