<?php

// Open Conference Systems 1.1
// (c) The Public Knowledge Project 2003
// http://www.pkp.ubc.ca
//
// This file is part of Open Conference Systems.
// 
// Open Conference Systems is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// Open Conference Systems is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with Open Conference Systems; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
// 
// admin/scheduler.php
// 
// $Id: scheduler.php,v 1.3 2003/04/01 07:58:47 kevin Exp $
// 
// configure and set up a conference schedule


// include necessary files
include("include/validate.inc.php");
include("../include/common.inc.php");

if(!isset($cf)) {
	header("Location: index.php");
	exit;
}


// get cookie
include("include/cookie.inc.php");
getadmincookie();

// this page's title
$title = "Conference Scheduler";

// creates a hierarchal tree to be printed out in header.php
$tree = array("Conference Manager"=>print_url("index.php"));


// validate the user's username and password, and formard to login page if invalid
if(!validate($username,$password)) {
	Header("Location: ".$baseurl.print_url("admin/index.php"));
	exit;
}


// include the html header file
include("../include/header.inc.php");

/******* NEEDS MULTI-CONFERENCE SUPPORT ********/
switch($op) {
	case "locations":
		schedulerLocations();
		break;
	case "save_locations":
		schedulerSaveLocations($HTTP_POST_VARS);
		break;
	case "times":
		schedulerTimes();
		break;
	case "save_times":
		schedulerSaveTimes($HTTP_POST_VARS);
		break;
	case "themes":
		schedulerThemes();
		break;
	case "save_themes":
		schedulerSaveThemes($HTTP_POST_VARS);
		break;
	case "types":
		schedulerTypes();
		break;
	case "save_types":
		schedulerSaveTypes($HTTP_POST_VARS);
		break;
	case "presentations":
		schedulerPresentations();
		break;
	case "save_presentations":
		schedulerSavePresentations($HTTP_POST_VARS);
		break;
	case "chairs":
		schedulerChairs();
		break;
	case "save_chairs":
		schedulerSaveChairs($HTTP_POST_VARS);
		break;
	case "additional":
		schedulerAdditional();
		break;
	case "save_additional":
		schedulerSaveAdditional($HTTP_POST_VARS);
		break;
	default:
		unset($op);
		schedulerIndex();
		break;
}

if(isset($op)) {
	?>
<p><b><a href="<?php echo print_url("scheduler.php"); ?>">Conference Scheduler</a></b></p>
	<?php
}
?>
<p><b><a href="<?php echo print_url("index2.php"); ?>">Return to Conference Manager</a></b></p>

<table>
<tr valign="middle" height="16"><td width="10"><img src="<?php echo $themesdir; ?>images/arrow.gif" width="12" height="12" border="0"></td><td><b><a href="<?php echo print_url("index2.php?action=logout"); ?>">Log Out</a></b></td></tr>
</table>
<?php

// include the html footer file
include("../include/footer.inc.php");


// conference scheduler index page
function schedulerIndex() {
	global $themesdir;
	?>
<p class="ArticleTitle">Conference Scheduler</p>

<ol>
	<li>Identify the locations for the conference presentations.</li>
	<li>Identify the session times for each day of the conference, including coffee, lunch, and special presentation times.</li>
	<li>Select a time for each of the presentations listed for the conference, grouping presentations at the same time and in the same location, as required. You can schedule more than one session per time slot.</li>
	<li>Review actual schedule and revise as required.</li>
	<li>Select Chairs and Discussants as required, and review schedule for gaps, balance.</li>
	<li>Times and locations will appear on each Abstract as well as in the <a href="<?php echo print_url("../schedule.php"); ?>">Conference Schedule</a>.</li>
</ol>

<blockquote class="ArticleTitle">
<?php
	$steps = array("locations" => "Conference Locations", "times" => "Conference Session Times", "themes" => "Conference Themes or Strands (optional)", "types" => "Conference Session Types", "presentations" => "Schedule Presentations", "chairs" => "Schedule Chairs and Discussants", "additional" => "Schedule Additional Conference Functions");

	foreach($steps as $op => $name) {
		?>
		<img src="<?php echo $themesdir; ?>images/arrow.gif" width="12" height="12" border="0" alt="" /> <a href="<?php echo print_url("scheduler.php?op=$op"); ?>"><?php echo $name; ?></a><br />
		<?php
	}
?>
	<img src="<?php echo $themesdir; ?>images/arrow.gif" width="12" height="12" border="0" alt="" /> <a href="<?php echo print_url("../schedule.php"); ?>">View Schedule</a>
</blockquote>
	<?php
}


// edit scheduler locations
function schedulerLocations($vars = "") {
	if(empty($vars)) {
		global $cf, $db, $dbtable;
		
		// get list of locations from database
		$result = $db->query("SELECT location_id, building, building_short, room FROM $dbtable[scheduler_locations] WHERE cf='$cf' ORDER BY location_id");
		for($i=0, $max=$db->num_rows($result); $i<$max; $i++) {
			list($vars[location_id][], $vars[building][], $vars[building_short][], $vars[room][]) = $db->assoc_array($result, $i);
		}
		
		// no locations, initialize with blank entry
		if($i == 0) { $vars[location_id] = array(0); }
	}
	?>
<p class="ArticleTitle">Conference Locations</p>

<form action="<?php echo print_url("scheduler.php?op=save_locations"); ?>" method="post">
<table border="0" cellpadding="2" cellspacing="1">
<tr bgcolor="#CCCCCC">
	<td class="SecondaryText">Building</td>
	<td class="SecondaryText">Short Form</td>
	<td class="SecondaryText">Rooms</td>
	<td></td>
</tr>
<?php
// initialize array if empty
if(empty($vars[location_id])) { $vars[location_id] = array(); }

// add a new location
if(isset($vars[add])) { array_push($vars[location_id], 0); }

// locations to delete
if(empty($vars[deleted])) { $deleted = array(); }
else { $deleted = explode(":", $vars[deleted]); }

// print out locations
for($i=0, $index=0, $max=count($vars[location_id]); $i<$max; $i++) {
	// skip this location if deleting
	if(isset($vars[delete][$i])) {
		// if existing location add to list of ones to delete
		if(!empty($vars[location_id][$i])) {
			array_push($deleted, $vars[location_id][$i]);
		}
		continue;
	}
	?>
	<tr>
		<td><input type="hidden" name="location_id[]" value="<?php echo $vars[location_id][$i]; ?>" /><input type="text" name="building[]" size="25" maxlength="90" value="<?php echo sanitize_output($vars[building][$i]); ?>" /></td>
		<td><input type="text" name="building_short[]" size="15" maxlength="20" value="<?php echo sanitize_output($vars[building_short][$i]); ?>" /></td>
		<td><input type="text" name="room[]" size="20" maxlength="60" value="<?php echo sanitize_output($vars[room][$i]); ?>" /></td>
		<td><input type="submit" name="delete[<?php echo $index; ?>]" value="Delete" class="button" /></td>
	</tr>
	<?php
	$index++;
}

if($index == 0) { ?><tr><td colspan="4" align="center" class="SmallText">No locations have been set.</td></tr><?php }
?>
<tr><td colspan="2"><input type="submit" name="add" value="Add Location" class="button" /></td><td colspan="2" class="SmallText">(Separate multiple rooms with commas)</td></tr>
<tr><td colspan="4">&nbsp;<br /><input type="submit" value="Submit" class="button" /></td></tr>
</table>
<input type="hidden" name="deleted" value="<?php echo join(":", $deleted); ?>" />
</form>
	<?php
}


// save scheduler locations
function schedulerSaveLocations($vars) {
	global $cf, $db, $dbtable;
	
	// send back to form if adding/deleting a location
	if(isset($vars[add]) || isset($vars[delete])) {
		schedulerLocations($vars);
		return;	
	}
	
	check_referer();
	
	// save locations
	for($i=0, $max=count($vars[location_id]); $i<$max; $i++) {
		// sanitize input
		$location_id = (int) $vars[location_id][$i];
		list($building, $building_short, $room) = strip_html($vars[building][$i], $vars[building_short][$i], $vars[room][$i]);
		list($building, $building_short, $room) = sanitize_db_input($building, $building_short, $room);
		

		if(empty($location_id)) {
			// add new location
			$db->query("INSERT INTO $dbtable[scheduler_locations] (cf, building, building_short, room) VALUES ('$cf', '$building', '$building_short', '$room')");
		} else {
			// update location
			$db->query("UPDATE $dbtable[scheduler_locations] SET building='$building', building_short='$building_short', room='$room' WHERE location_id='$location_id' AND cf='$cf'"); 
		}
	}
	
	// remove deleted locations
	if(!empty($vars[deleted])) {
		$deleted = explode(":", $vars[deleted]);
		for($i=0, $max=count($deleted); $i<$max; $i++) {
			$location_id = (int) $deleted[$i];
			$db->query("DELETE FROM $dbtable[scheduler_locations] WHERE location_id='$location_id' AND cf='$cf'");
		}
	}
	?>
	<p>Conference locations saved successfully. Continue to <a href="<?php echo print_url("scheduler.php?op=times"); ?>">Conference Session Times</a>.</p>
	<?php
}


// edit scheduler session times
function schedulerTimes($vars = "") {
	if(empty($vars)) {
		global $cf, $db, $dbtable;
		
		$vars[date] = array();
		
		// get list of times from database
		$result = $db->query("SELECT time_id, date, start_time, end_time FROM $dbtable[scheduler_session_times] WHERE cf='$cf' ORDER BY date, start_time");
		for($i=0, $max=$db->num_rows($result); $i<$max; $i++) {
			list($time_id, $date, $start_time, $end_time) = $db->assoc_array($result, $i);
			
			// add date to list of dates if it hasn't already been added
			if(!in_array($date, $vars[date])) { array_push($vars[date], $date); }

			// add values to date array
			$vars[time_id][$date][] = $time_id;
			list($vars[hour_start][$date][], $vars[min_start][$date][], $vars[ampm_start][$date][]) = explode(":", date("h:i:A", strtotime($start_time)));
			list($vars[hour_end][$date][], $vars[min_end][$date][], $vars[ampm_end][$date][]) = explode(":", date("h:i:A", strtotime($end_time)));
		}
		
		// no times, initialize with empty array
		if($i == 0) { $vars[date] = array(); }
	}
	?>
<p class="ArticleTitle">Conference Session Times</p>

<form action="<?php echo print_url("scheduler.php?op=save_times"); ?>" method="post">
<table border="0" cellpadding="2" cellspacing="1">
<tr bgcolor="#CCCCCC">
	<td class="SecondaryText">Date</td>
	<td class="SecondaryText">Start Time</td>
	<td></td>
	<td class="SecondaryText">End Time</td>
	<td></td>
</tr>
<?php
// initialize dates array if empty
if(empty($vars[date])) { $vars[date] = array(); }

// add a new date
if(isset($vars[add])) {
	$vars[add_date] = "$vars[add_year]-$vars[add_month]-$vars[add_day]";
	if(checkdate($vars[add_month],$vars[add_day],$vars[add_year]) && !in_array($vars[add_date], $vars[date])) {
		array_push($vars[date], $vars[add_date]);
	}
}

// sort dates
sort($vars[date]);

// times to delete
if(empty($vars[deleted])) { $deleted = array(); }
else { $deleted = explode(":", $vars[deleted]); }

// print out dates
for($i=0, $max=count($vars[date]); $i<$max; $i++) {
	$date = $vars[date][$i];
	$j = 0;
	
	// deleting first one
	if(isset($vars[delete][$date][$j])) {
		// if existing time add to list of ones to delete
		if(!empty($vars[time_id][$date][$j])) {
			array_push($deleted, $vars[time_id][$date][$j]);
		}
		
		// if deleting only one skip date altogether
		if(count($vars[time_id][$date]) <= 1) { continue; }
		
		$j++;
		
	}
	
	// add a new time
	if(isset($vars[add_time][$date])) { array_push($vars[time_id][$date], 0); }
	?>
	<tr>
		<td><?php echo date("m/d/Y", strtotime($date)); ?><input type="hidden" name="date[]" value="<?php echo $date; ?>"><input type="hidden" name="time_id[<?php echo $date; ?>][]" value="<?php echo $vars[time_id][$date][$j]; ?>"></td>
		<td><?php echo time_menu("start[$date][]", array($vars[hour_start][$date][$j], $vars[min_start][$date][$j], $vars[ampm_start][$date][$j]), true, true); ?></td>
		<td>to</td>
		<td><?php echo time_menu("end[$date][]", array($vars[hour_end][$date][$j], $vars[min_end][$date][$j], $vars[ampm_end][$date][$j]), true, true); ?></td>
		<td><input type="submit" name="delete[<?php echo $date; ?>][<?php echo $index; ?>]" value="Delete" class="button" /></td>
	</tr>
	<?php
	
	// show additional times
	for($j+=1, $index=$j, $max_times=count($vars[time_id][$date]); $j<$max_times; $j++) {
	
		// skip this time if deleting
		if(isset($vars[delete][$date][$j])) {
			// if existing time add to list of ones to delete
			if(!empty($vars[time_id][$date][$j])) {
				array_push($deleted, $vars[time_id][$date][$j]);
			}
			continue;
		}
		?>
		<tr>
			<td><input type="hidden" name="time_id[<?php echo $date; ?>][]" value="<?php echo $vars[time_id][$date][$j]; ?>"></td>
			<td><?php echo time_menu("start[$date][]", array($vars[hour_start][$date][$j], $vars[min_start][$date][$j], $vars[ampm_start][$date][$j]), true, true); ?></td>
			<td>to</td>
			<td><?php echo time_menu("end[$date][]", array($vars[hour_end][$date][$j], $vars[min_end][$date][$j], $vars[ampm_end][$date][$j]), true, true); ?></td>
			<td><input type="submit" name="delete[<?php echo $date; ?>][<?php echo $index; ?>]" value="Delete" class="button" /></td>
		</tr>
		<?php
		$index++;
	}
	?>
	<tr><td></td><td colspan="4"><input type="submit" name="add_time[<?php echo $date; ?>]" value="Add Time" class="button" /><br />&nbsp;</td></tr>
	<?php
}

if($index == 0) { ?><tr><td colspan="5" align="center" class="SmallText">No session times have been set. Please add a date below to begin.<br />&nbsp;</td></tr><?php }
?>
<tr><td colspan="5" class="SecondaryText">Add date: <?php date_menu("add", "", true); ?> <input type="submit" name="add" value="Add Date" class="button" /></td></tr>
<tr><td colspan="5">&nbsp;<br /><input type="submit" value="Submit" class="button" /></td></tr>
</table>
<input type="hidden" name="deleted" value="<?php echo join(":", $deleted); ?>" />
</form>
	<?php
}


// save scheduler session times
function schedulerSaveTimes($vars) {
	global $cf, $db, $dbtable;
	
	// send back to form if adding/deleting a time or date
	if(isset($vars[add]) || isset($vars[delete]) || isset($vars[add_time])) {
		schedulerTimes($vars);
		return;	
	}
	
	check_referer();
	
	// save times
	for($i=0, $max=count($vars[date]); $i<$max; $i++) {
		$date = sanitize_db_input(strip_html($vars[date][$i]));
	
		for($j=0, $max_times=count($vars[time_id][$date]); $j<$max_times; $j++) {
			// format start and end times properly
			if(empty($vars[hour_start][$date][$j])) { $vars[hour_start][$date][$j] = "12"; }
			if(empty($vars[min_start][$date][$j])) { $vars[min_start][$date][$j] = "00"; }
			if(empty($vars[ampm_start][$date][$j])) { $vars[hour_start][$date][$j] = "PM"; }
			
			if(empty($vars[hour_end][$date][$j])) { $vars[hour_end][$date][$j] = "12"; }
			if(empty($vars[min_end][$date][$j])) { $vars[min_end][$date][$j] = "00"; }
			if(empty($vars[ampm_end][$date][$j])) { $vars[ampm_end][$date][$j] = "PM"; }
			
			$start_time = date("H:i:00", strtotime($vars[hour_start][$date][$j].":".$vars[min_start][$date][$j]." ".$vars[ampm_start][$date][$j]));
			$end_time  = date("H:i:00", strtotime($vars[hour_end][$date][$j].":".$vars[min_end][$date][$j]." ".$vars[ampm_end][$date][$j]));
			
			// sanitize input
			$time_id = (int) $vars[time_id][$date][$j];
			list($start_time, $end_time) = strip_html($start_time, $end_time);
			list($start_time, $end_time) = sanitize_db_input($start_time, $end_time);

			if(empty($time_id)) {
				// add new time
				$db->query("INSERT INTO $dbtable[scheduler_session_times] (cf, date, start_time, end_time) VALUES ('$cf', '$date', '$start_time', '$end_time')");
			} else {
				// update time
				$db->query("UPDATE $dbtable[scheduler_session_times] SET date='$date', start_time='$start_time', end_time='$end_time' WHERE time_id='$time_id' AND cf='$cf'"); 
			}
		}
	}
	
	// remove deleted times
	if(!empty($vars[deleted])) {
		$deleted = explode(":", $vars[deleted]);
		for($i=0, $max=count($deleted); $i<$max; $i++) {
			$time_id = (int) $deleted[$i];
			$db->query("DELETE FROM $dbtable[scheduler_session_times] WHERE time_id='$time_id' AND cf='$cf'");
		}
	}
	?>
	<p>Conference session times saved successfully. Continue to <a href="<?php echo print_url("scheduler.php?op=themes"); ?>">Conference Themes or Strands</a>.</p>
	<?php
}


// edit scheduler themes
function schedulerThemes($vars = "") {
	if(empty($vars)) {
		global $cf, $db, $dbtable;
		
		// get list of themes from database
		$result = $db->query("SELECT theme_id, theme, theme_short FROM $dbtable[scheduler_themes] WHERE cf='$cf' ORDER BY theme_id");
		for($i=0, $max=$db->num_rows($result); $i<$max; $i++) {
			list($vars[theme_id][], $vars[theme][], $vars[theme_short][]) = $db->assoc_array($result, $i);
		}
		
		// no themes, initialize with blank entry
		if($i == 0) { $vars[theme_id] = array(0); }
	}
	?>
<p class="ArticleTitle">Conference Themes or Strands (optional)</p>

<form action="<?php echo print_url("scheduler.php?op=save_themes"); ?>" method="post">
<table border="0" cellpadding="2" cellspacing="1">
<tr bgcolor="#CCCCCC">
	<td class="SecondaryText">Theme</td>
	<td class="SecondaryText">Short Form</td>
	<td></td>
</tr>
<?php
// initialize array if empty
if(empty($vars[theme_id])) { $vars[theme_id] = array(); }

// add a new theme
if(isset($vars[add])) { array_push($vars[theme_id], 0); }

// themes to delete
if(empty($vars[deleted])) { $deleted = array(); }
else { $deleted = explode(":", $vars[deleted]); }

// print out themes
for($i=0, $index=0, $max=count($vars[theme_id]); $i<$max; $i++) {
	// skip this theme if deleting
	if(isset($vars[delete][$i])) {
		// if existing theme add to list of ones to delete
		if(!empty($vars[theme_id][$i])) {
			array_push($deleted, $vars[theme_id][$i]);
		}
		continue;
	}
	?>
	<tr>
		<td><input type="hidden" name="theme_id[]" value="<?php echo $vars[theme_id][$i]; ?>" /><input type="text" name="theme[]" size="25" maxlength="90" value="<?php echo sanitize_output($vars[theme][$i]); ?>" /></td>
		<td><input type="text" name="theme_short[]" size="15" maxlength="20" value="<?php echo sanitize_output($vars[theme_short][$i]); ?>" /></td>
		<td><input type="submit" name="delete[<?php echo $index; ?>]" value="Delete" class="button" /></td>
	</tr>
	<?php
	$index++;
}

if($index == 0) { ?><tr><td colspan="3" align="center" class="SmallText">No themes or strands have been set.</td></tr><?php }
?>
<tr><td colspan="3"><input type="submit" name="add" value="Add Theme" class="button" /></td></tr>
<tr><td colspan="3">&nbsp;<br /><input type="submit" value="Submit" class="button" /></td></tr>
</table>
<input type="hidden" name="deleted" value="<?php echo join(":", $deleted); ?>" />
</form>
	<?php
}


// save scheduler themes
function schedulerSaveThemes($vars) {
	global $cf, $db, $dbtable;
	
	// send back to form if adding/deleting a theme
	if(isset($vars[add]) || isset($vars[delete])) {
		schedulerThemes($vars);
		return;	
	}
	
	check_referer();
	
	// save themes
	for($i=0, $max=count($vars[theme_id]); $i<$max; $i++) {
		// sanitize input
		$theme_id = (int) $vars[theme_id][$i];
		list($theme, $theme_short) = strip_html($vars[theme][$i], $vars[theme_short][$i]);
		list($theme, $theme_short) = sanitize_db_input($theme, $theme_short);
		

		if(empty($theme_id)) {
			// add new theme
			$db->query("INSERT INTO $dbtable[scheduler_themes] (cf, theme, theme_short) VALUES ('$cf', '$theme', '$theme_short')");
		} else {
			// update theme
			$db->query("UPDATE $dbtable[scheduler_themes] SET theme='$theme', theme_short='$theme_short' WHERE theme_id='$theme_id' AND cf='$cf'"); 
		}
	}
	
	// remove deleted themes
	if(!empty($vars[deleted])) {
		$deleted = explode(":", $vars[deleted]);
		for($i=0, $max=count($deleted); $i<$max; $i++) {
			$theme_id = (int) $deleted[$i];
			$db->query("DELETE FROM $dbtable[scheduler_themes] WHERE theme_id='$theme_id' AND cf='$cf'");
		}
	}
	?>
	<p>Conference themes saved successfully. Continue to <a href="<?php echo print_url("scheduler.php?op=types"); ?>">Conference Session Types</a>.</p>
	<?php
}


// edit scheduler session types
function schedulerTypes($vars = "") {
	if(empty($vars)) {
		global $cf, $db, $dbtable;
		
		// get list of types from database
		$result = $db->query("SELECT type_id, type, type_short, num_presenters, chair_required, discussant_required FROM $dbtable[scheduler_session_types] WHERE cf='$cf' ORDER BY type_id");
		for($i=0, $max=$db->num_rows($result); $i<$max; $i++) {
			list($vars[type_id][], $vars[type][], $vars[type_short][], $vars[num_presenters][], $vars[chair_required][], $vars[discussant_required][]) = $db->assoc_array($result, $i);
		}
		
		// no types, initialize with blank entry
		if($i == 0) { $vars[type_id] = array(0); }
	}
	?>
<p class="ArticleTitle">Conference Session Types</p>

<form action="<?php echo print_url("scheduler.php?op=save_types"); ?>" method="post">
<table border="0" cellpadding="2" cellspacing="1">
<tr bgcolor="#CCCCCC">
	<td class="SecondaryText">Type</td>
	<td class="SecondaryText">Short Form</td>
	<td class="SecondaryText"># of Presenters</td>
	<td class="SecondaryText">Chair Required</td>
	<td class="SecondaryText">Discussant Required</td>
	<td></td>
</tr>
<?php
// initialize array if empty
if(empty($vars[type_id])) { $vars[type_id] = array(); }

// add a new type
if(isset($vars[add])) { array_push($vars[type_id], 0); }

// types to delete
if(empty($vars[deleted])) { $deleted = array(); }
else { $deleted = explode(":", $vars[deleted]); }

// print out types
for($i=0, $index=0, $max=count($vars[type_id]); $i<$max; $i++) {
	// skip this type if deleting
	if(isset($vars[delete][$i])) {
		// if existing type add to list of ones to delete
		if(!empty($vars[type_id][$i])) {
			array_push($deleted, $vars[type_id][$i]);
		}
		continue;
	}
	
	unset($sel_chair);
	unset($sel_discussant);
	$sel_chair[$vars[chair_required][$i]] = " checked=\"checked\"";
	$sel_discussant[$vars[discussant_required][$i]] = " checked=\"checked\"";
	?>
	<tr>
		<td><input type="hidden" name="type_id[]" value="<?php echo $vars[type_id][$i]; ?>" /><input type="text" name="type[]" size="25" maxlength="90" value="<?php echo sanitize_output($vars[type][$i]); ?>" /></td>
		<td><input type="text" name="type_short[]" size="15" maxlength="20" value="<?php echo sanitize_output($vars[type_short][$i]); ?>" /></td>
		<td><input type="text" name="num_presenters[]" size="15" maxlength="20" value="<?php echo sanitize_output($vars[num_presenters][$i]); ?>" /></td>
		<td><input type="checkbox" name="chair_required[<?php echo $index; ?>]" value="1"<?php echo $sel_chair[1]; ?> /></td>
		<td><input type="checkbox" name="discussant_required[<?php echo $index; ?>]" value="1"<?php echo $sel_discussant[1]; ?> /></td>
		<td><input type="submit" name="delete[<?php echo $index; ?>]" value="Delete" class="button" /></td>
	</tr>
	<?php
	$index++;
}

if($index == 0) { ?><tr><td colspan="6" align="center" class="SmallText">No session types have been set.</td></tr><?php }
?>
<tr><td colspan="6"><input type="submit" name="add" value="Add Session Type" class="button" /></td></tr>
<tr><td colspan="6">&nbsp;<br /><input type="submit" value="Submit" class="button" /></td></tr>
</table>
<input type="hidden" name="deleted" value="<?php echo join(":", $deleted); ?>" />
</form>
	<?php
}


// save scheduler session types
function schedulerSaveTypes($vars) {
	global $cf, $db, $dbtable;
	
	// send back to form if adding/deleting a type
	if(isset($vars[add]) || isset($vars[delete])) {
		schedulerTypes($vars);
		return;	
	}
	
	check_referer();
	
	// save types
	for($i=0, $max=count($vars[type_id]); $i<$max; $i++) {
		// sanitize input
		$type_id = (int) $vars[type_id][$i];
		list($type, $type_short) = strip_html($vars[type][$i], $vars[type_short][$i]);
		list($type, $type_short) = sanitize_db_input($type, $type_short);
		$num_presenters = (int) $vars[num_presenters][$i];
		$chair_required = (int) $vars[chair_required][$i];
		$discussant_required = (int) $vars[discussant_required][$i];
		

		if(empty($type_id)) {
			// add new type
			$db->query("INSERT INTO $dbtable[scheduler_session_types] (cf, type, type_short, num_presenters, chair_required, discussant_required) VALUES ('$cf', '$type', '$type_short', '$num_presenters', '$chair_required', '$discussant_required')");
		} else {
			// update type
			$db->query("UPDATE $dbtable[scheduler_session_types] SET type='$type', type_short='$type_short', num_presenters='$num_presenters', chair_required='$chair_required', discussant_required='$discussant_required' WHERE type_id='$type_id' AND cf='$cf'"); 
		}
	}
	
	// remove deleted types
	if(!empty($vars[deleted])) {
		$deleted = explode(":", $vars[deleted]);
		for($i=0, $max=count($deleted); $i<$max; $i++) {
			$type_id = (int) $deleted[$i];
			$db->query("DELETE FROM $dbtable[scheduler_session_types] WHERE type_id='$type_id' AND cf='$cf'");
		}
	}
	?>
	<p>Conference session types saved successfully. Continue to <a href="<?php echo print_url("scheduler.php?op=presentations"); ?>">Presentations</a>.</p>
	<?php
}


// edit scheduler presentations
function schedulerPresentations($vars = "") {
	global $cf, $db, $dbtable;
	
	if(empty($vars)) {
		// get list of presentations from database
		$result = $db->query("SELECT present_id, time, location, room, paper, type, theme FROM $dbtable[scheduler_presentations] WHERE cf='$cf' ORDER BY present_id");
		for($i=0, $max=$db->num_rows($result); $i<$max; $i++) {
			list($vars[present_id][], $vars[time][], $vars[location][], $vars[room][], $vars[paper][], $vars[type][], $vars[theme][]) = $db->assoc_array($result, $i);
			
			// get date for time
			$time_result = $db->query("SELECT date FROM $dbtable[scheduler_session_times] WHERE time_id='{$vars[time][$i]}' AND cf='$cf'");
			list($vars[date][]) = $db->assoc_array($time_result);
		}
		
		// no presentations, initialize with blank entry
		if($i == 0) { $vars[present_id] = array(0); }
	}
	
	
	// get list of dates
	$dates = schedulerGetDates();

	// get list of locations
	$locations = schedulerGetLocations();
	
	// get list of abstracts/papers
	$papers = array();
	$result = $db->query("SELECT id, first_name, surname, title FROM $dbtable[papers] WHERE accepted='true' AND cf='$cf' ORDER BY surname, first_name, title");
	for($i=0, $max=$db->num_rows($result); $i<$max; $i++) {
		list($paper, $first_name, $surname, $title) = $db->assoc_array($result, $i);
		if(strlen($title) > 15) { $title = substr($title, 0, 15)."&hellip;"; }
		$papers[$paper] = "$surname, $first_name - \"$title\"";
	}
	
	// get list of session types
	$types = array();
	$result = $db->query("SELECT type_id, type_short FROM $dbtable[scheduler_session_types] WHERE cf='$cf' ORDER BY type");
	for($i=0, $max=$db->num_rows($result); $i<$max; $i++) {
		list($type_id, $type, $type_short) = $db->assoc_array($result, $i);
		$types[$type_id] = "$type";
	}
	
	// get list of themes
	$themes = array();
	$result = $db->query("SELECT theme_id, theme_short FROM $dbtable[scheduler_themes] WHERE cf='$cf' ORDER BY theme");
	for($i=0, $max=$db->num_rows($result); $i<$max; $i++) {
		list($theme_id, $theme) = $db->assoc_array($result, $i);
		$themes[$theme_id] = "$theme";
	}
	
	
	// print javascript functions for handling date and location switches
	javascriptDateSwitch();
	javascriptLocationSwitch();
	?>
<p class="ArticleTitle">Schedule Presentations (Based on Abstracts)</p>

<form action="<?php echo print_url("scheduler.php?op=save_presentations"); ?>" method="post">
<table border="0" cellpadding="2" cellspacing="1">
<tr bgcolor="#CCCCCC">
	<td class="SecondaryText">Date</td>
	<td class="SecondaryText">Time</td>
	<td class="SecondaryText">Building</td>
	<td class="SecondaryText">Room</td>
	<td class="SecondaryText">Abstract/Paper</td>
	<td class="SecondaryText">Type</td>
	<td class="SecondaryText">Theme</td>
	<td></td>
</tr>
<?php	
// initialize array if empty
if(empty($vars[present_id])) { $vars[present_id] = array(); }

// add a new presentation
if(isset($vars[add])) { array_push($vars[present_id], 0); }

// presentations to delete
if(empty($vars[deleted])) { $deleted = array(); }
else { $deleted = explode(":", $vars[deleted]); }

$javascript_output = "";

// print out presentations
for($i=0, $index=0, $max=count($vars[present_id]); $i<$max; $i++) {
	// skip this presentation if deleting
	if(isset($vars[delete][$i])) {
		// if existing presentation add to list of ones to delete
		if(!empty($vars[present_id][$i])) {
			array_push($deleted, $vars[present_id][$i]);
		}
		continue;
	}
	
	unset($sel_date);
	unset($sel_location);
	unset($sel_paper);
	unset($sel_type);
	unset($sel_theme);
	$sel_date[$vars[date][$i]] = " selected=\"selected\"";
	$sel_location[$vars[location][$i]] = " selected=\"selected\"";
	$sel_paper[$vars[paper][$i]] = " selected=\"selected\"";
	$sel_type[$vars[type][$i]] = " selected=\"selected\"";
	$sel_theme[$vars[theme][$i]] = " selected=\"selected\"";
	
	$time_element = ($index * 9) + 2;
	$room_element = ($index * 9) + 4;
	
	// add javascript code for setting time and room
	$javascript_output .= "switchDate('{$vars[date][$i]}', document.forms[0].elements[{$time_element}], '{$vars[time][$i]}');\n";
	$javascript_output .= "switchLocation('{$vars[location][$i]}', document.forms[0].elements[{$room_element}], '{$vars[room][$i]}');\n";
	?>
	<tr>
		<td><input type="hidden" name="present_id[]" value="<?php echo $vars[present_id][$i]; ?>" /><select name="date[]" size="1" onChange="switchDate(this.options[this.selectedIndex].value, this.form.elements[<?php echo $time_element; ?>])" style="font-size: 10px">
		<option value=""></option>
		<?php
		foreach($dates as $k => $v) {
			echo "<option value=\"$k\"$sel_date[$k]>$v</option>\n";
		}
		?>
		</select></td>
		<td><select name="time[]" size="1" style="font-size: 10px">
		</select></td>
		<td><select name="location[]" size="1" onChange="switchLocation(this.options[this.selectedIndex].value, this.form.elements[<?php echo $room_element; ?>])" style="font-size: 10px">
		<option value=""></option>
		<?php
		foreach($locations as $k => $v) {
			echo "<option value=\"$k\"$sel_location[$k]>$v</option>\n";
		}
		?>
		</select></td>
		<td><select name="room[]" size="1" style="font-size: 10px">
		</select></td>
		<td><select name="paper[]" size="1" style="font-size: 10px">
		<option value=""></option>
		<?php
		foreach($papers as $k => $v) {
			echo "<option value=\"$k\"$sel_paper[$k]>$v</option>\n";
		}
		?>
		</select></td>
		<td><select name="type[]" size="1" style="font-size: 10px">
		<option value=""></option>
		<?php
		foreach($types as $k => $v) {
			echo "<option value=\"$k\"$sel_type[$k]>$v</option>\n";
		}
		?>
		</select></td>
		<td><select name="theme[]" size="1" style="font-size: 10px">
		<option value=""></option>
		<?php
		foreach($themes as $k => $v) {
			echo "<option value=\"$k\"$sel_theme[$k]>$v</option>\n";
		}
		?>
		</select></td>
		<td><input type="submit" name="delete[<?php echo $index; ?>]" value="Delete" class="button" /></td>
	</tr>
	<?php
	$index++;
}

if($index == 0) { ?><tr><td colspan="8" align="center" class="SmallText">No presentations have been set.</td></tr><?php }
?>
<tr><td colspan="8"><input type="submit" name="add" value="Add Presentation" class="button" /></td></tr>
<tr><td colspan="8">&nbsp;<br /><input type="submit" value="Submit" class="button" /></td></tr>
</table>
<input type="hidden" name="deleted" value="<?php echo join(":", $deleted); ?>" />
</form>
	<?php
	if(!empty($javascript_output)) { echo "<script type=\"text/javascript\"><!--\n$javascript_output\n--></script>\n"; }
}


// save scheduler presentations
function schedulerSavePresentations($vars) {
	global $cf, $db, $dbtable;
	
	// send back to form if adding/deleting a presentation
	if(isset($vars[add]) || isset($vars[delete])) {
		schedulerPresentations($vars);
		return;	
	}
	
	check_referer();
	
	// save presentations
	for($i=0, $max=count($vars[present_id]); $i<$max; $i++) {
		// sanitize input
		$present_id = (int) $vars[present_id][$i];
		$time = (int) $vars[time][$i];
		$location = (int) $vars[location][$i];
		$room = sanitize_db_input(strip_html($vars[room][$i]));
		$paper = (int) $vars[paper][$i];
		$type = (int) $vars[type][$i];
		$theme = (int) $vars[theme][$i];

		if(empty($present_id)) {
			// add new presentation
			$db->query("INSERT INTO $dbtable[scheduler_presentations] (cf, time, location, room, paper, type, theme) VALUES ('$cf', '$time', '$location', '$room', '$paper', '$type', '$theme')");
		} else {
			// update presentation
			$db->query("UPDATE $dbtable[scheduler_presentations] SET time='$time', location='$location', room='$room', paper='$paper', type='$type', theme='$theme' WHERE present_id='$present_id' AND cf='$cf'"); 
		}
	}
	
	// remove deleted presentations
	if(!empty($vars[deleted])) {
		$deleted = explode(":", $vars[deleted]);
		for($i=0, $max=count($deleted); $i<$max; $i++) {
			$present_id = (int) $deleted[$i];
			$db->query("DELETE FROM $dbtable[scheduler_presentations] WHERE present_id='$present_id' AND cf='$cf'");
		}
	}
	?>
	<p>Presentations saved successfully. Continue to <a href="<?php echo print_url("scheduler.php?op=chairs"); ?>">Chairs and Discussants</a>.</p>
	<?php
}


// edit scheduler chairs and discussants
function schedulerChairs($vars = "") {
	if(empty($vars)) {
		global $cf, $db, $dbtable;
	
		// get list of chairs from database
		$result = $db->query("SELECT chair_id, time, location, room, chair, chair_affiliation, discussant, discussant_affiliation FROM $dbtable[scheduler_chairs] WHERE cf='$cf' ORDER BY chair_id");
		for($i=0, $max=$db->num_rows($result); $i<$max; $i++) {
			list($vars[chair_id][], $vars[time][], $vars[location][], $vars[room][], $vars[chair][], $vars[chair_affiliation][], $vars[discussant][], $vars[discussant_affiliation][]) = $db->assoc_array($result, $i);
			
			// get date for time
			$time_result = $db->query("SELECT date FROM $dbtable[scheduler_session_times] WHERE time_id='{$vars[time][$i]}' AND cf='$cf'");
			list($vars[date][]) = $db->assoc_array($time_result);
		}
		
		// no chairs, initialize with blank entry
		if($i == 0) { $vars[chair_id] = array(0); }
	}
	
	
	// get list of dates
	$dates = schedulerGetDates();
	
	// get list of locations
	$locations = schedulerGetLocations();
	
	
	// print javascript functions for handling date and location switches
	javascriptDateSwitch();
	javascriptLocationSwitch();
	?>
<p class="ArticleTitle">Schedule Chairs and Discussants</p>

<form action="<?php echo print_url("scheduler.php?op=save_chairs"); ?>" method="post">
<table border="0" cellpadding="2" cellspacing="1">
<tr bgcolor="#cccccc">
	<td class="SecondaryText">Date</td>
	<td class="SecondaryText">Time</td>
	<td class="SecondaryText">Building</td>
	<td class="SecondaryText">Room</td>
	<td class="SecondaryText">Chair</td>
	<td class="SecondaryText">Affilition</td>
	<td class="SecondaryText">Discussant</td>
	<td class="SecondaryText">Affilition</td>
	<td></td>
</tr>
<?php	
// initialize array if empty
if(empty($vars[chair_id])) { $vars[chair_id] = array(); }

// add a new chair
if(isset($vars[add])) { array_push($vars[chair_id], 0); }

// chairs to delete
if(empty($vars[deleted])) { $deleted = array(); }
else { $deleted = explode(":", $vars[deleted]); }

$javascript_output = "";

// print out chairs
for($i=0, $index=0, $max=count($vars[chair_id]); $i<$max; $i++) {
	// skip this chair if deleting
	if(isset($vars[delete][$i])) {
		// if existing chair add to list of ones to delete
		if(!empty($vars[chair_id][$i])) {
			array_push($deleted, $vars[chair_id][$i]);
		}
		continue;
	}
	
	unset($sel_date);
	unset($sel_location);
	$sel_date[$vars[date][$i]] = " selected=\"selected\"";
	$sel_location[$vars[location][$i]] = " selected=\"selected\"";
	
	$time_element = ($index * 10) + 2;
	$room_element = ($index * 10) + 4;
	
	// add javascript code for setting time and room
	$javascript_output .= "switchDate('{$vars[date][$i]}', document.forms[0].elements[{$time_element}], '{$vars[time][$i]}');\n";
	$javascript_output .= "switchLocation('{$vars[location][$i]}', document.forms[0].elements[{$room_element}], '{$vars[room][$i]}');\n";
	?>
	<tr valign="top">
		<td><input type="hidden" name="chair_id[]" value="<?php echo $vars[chair_id][$i]; ?>" /><select name="date[]" size="1" onChange="switchDate(this.options[this.selectedIndex].value, this.form.elements[<?php echo $time_element; ?>])" style="font-size: 10px">
		<option value=""></option>
		<?php
		foreach($dates as $k => $v) {
			echo "<option value=\"$k\"$sel_date[$k]>$v</option>\n";
		}
		?>
		</select></td>
		<td><select name="time[]" size="1" style="font-size: 10px">
		</select></td>
		<td><select name="location[]" size="1" onChange="switchLocation(this.options[this.selectedIndex].value, this.form.elements[<?php echo $room_element; ?>])" style="font-size: 10px">
		<option value=""></option>
		<?php
		foreach($locations as $k => $v) {
			echo "<option value=\"$k\"$sel_location[$k]>$v</option>\n";
		}
		?>
		</select></td>
		<td><select name="room[]" size="1" style="font-size: 10px">
		</select></td>
		<td><textarea name="chair[]" cols="10" rows="2"><?php echo sanitize_output($vars[chair][$i]); ?></textarea></td>
		<td><textarea name="chair_affiliation[]" cols="10" rows="2"><?php echo sanitize_output($vars[chair_affiliation][$i]); ?></textarea></td>
		<td><textarea name="discussant[]" cols="10" rows="2"><?php echo sanitize_output($vars[discussant][$i]); ?></textarea></td>
		<td><textarea name="discussant_affiliation[]" cols="10" rows="2"><?php echo sanitize_output($vars[discussant_affiliation][$i]); ?></textarea></td>
		<td><input type="submit" name="delete[<?php echo $index; ?>]" value="Delete" class="button" /></td>
	</tr>
	<?php
	$index++;
}

if($index == 0) { ?><tr><td colspan="9" align="center" class="SmallText">No chairs and discussants have been set.</td></tr><?php }
?>
<tr><td colspan="9"><input type="submit" name="add" value="Add Chair" class="button" /></td></tr>
<tr><td colspan="9">&nbsp;<br /><input type="submit" value="Submit" class="button" /></td></tr>
</table>
<input type="hidden" name="deleted" value="<?php echo join(":", $deleted); ?>" />
</form>
	<?php
	if(!empty($javascript_output)) { echo "<script type=\"text/javascript\"><!--\n$javascript_output\n--></script>\n"; }
}


// save scheduler chairs and discussants
function schedulerSaveChairs($vars) {
	global $cf, $db, $dbtable;
	
	// send back to form if adding/deleting a chair
	if(isset($vars[add]) || isset($vars[delete])) {
		schedulerChairs($vars);
		return;	
	}
	
	check_referer();
	
	// save chairs
	for($i=0, $max=count($vars[chair_id]); $i<$max; $i++) {
		// sanitize input
		$chair_id = (int) $vars[chair_id][$i];
		$time = (int) $vars[time][$i];
		$location = (int) $vars[location][$i];
		
		list($room, $chair, $chair_affiliation, $discussant, $discussant_affiliation) = strip_html($vars[room][$i], $vars[chair][$i], $vars[chair_affiliation][$i], $vars[discussant][$i], $vars[discussant_affiliation][$i]);
		list($room, $chair, $chair_affiliation, $discussant, $discussant_affiliation) = sanitize_db_input($room, $chair, $chair_affiliation, $discussant, $discussant_affiliation);

		if(empty($chair_id)) {
			// add new chair
			$db->query("INSERT INTO $dbtable[scheduler_chairs] (cf, time, location, room, chair, chair_affiliation, discussant, discussant_affiliation) VALUES ('$cf', '$time', '$location', '$room', '$chair', '$chair_affiliation', '$discussant', '$discussant_affiliation')");
		} else {
			// update chair
			$db->query("UPDATE $dbtable[scheduler_chairs] SET time='$time', location='$location', room='$room', chair='$chair', chair_affiliation='$chair_affiliation', discussant='$discussant', discussant_affiliation='$discussant_affiliation' WHERE chair_id='$chair_id' AND cf='$cf'");
		}
	}
	
	// remove deleted chairs
	if(!empty($vars[deleted])) {
		$deleted = explode(":", $vars[deleted]);
		for($i=0, $max=count($deleted); $i<$max; $i++) {
			$chair_id = (int) $deleted[$i];
			$db->query("DELETE FROM $dbtable[scheduler_chairs] WHERE chair_id='$chair_id' AND cf='$cf'");
		}
	}
	?>
	<p>Chairs and discussants saved successfully. Continue to <a href="<?php echo print_url("scheduler.php?op=additional"); ?>">Additional Conference Functions</a>.</p>
	<?php
}


// edit additional conference functions
function schedulerAdditional($vars = "") {
	if(empty($vars)) {
		global $cf, $db, $dbtable;
	
		// get list of functions from database
		$result = $db->query("SELECT function_id, time, location, room, event, description FROM $dbtable[scheduler_functions] WHERE cf='$cf' ORDER BY function_id");
		for($i=0, $max=$db->num_rows($result); $i<$max; $i++) {
			list($vars[function_id][], $vars[time][], $vars[location][], $vars[room][], $vars[event][], $vars[description][]) = $db->assoc_array($result, $i);
			
			// get date for time
			$time_result = $db->query("SELECT date FROM $dbtable[scheduler_session_times] WHERE time_id='{$vars[time][$i]}' AND cf='$cf'");
			list($vars[date][]) = $db->assoc_array($time_result);
		}
		
		// no functions, initialize with blank entry
		if($i == 0) { $vars[function_id] = array(0); }
	}
	
	
	// get list of dates
	$dates = schedulerGetDates();
	
	// get list of locations
	$locations = schedulerGetLocations();
	
	
	// print javascript functions for handling date and location switches
	javascriptDateSwitch();
	javascriptLocationSwitch();
	?>
<p class="ArticleTitle">Schedule Additional Conference Functions</p>

<form action="<?php echo print_url("scheduler.php?op=save_additional"); ?>" method="post">
<table border="0" cellpadding="2" cellspacing="1">
<tr bgcolor="#CCCCCC">
	<td class="SecondaryText">Date</td>
	<td class="SecondaryText">Time</td>
	<td class="SecondaryText">Building</td>
	<td class="SecondaryText">Room</td>
	<td class="SecondaryText">Event</td>
	<td class="SecondaryText">Description</td>
	<td></td>
</tr>
<?php	
// initialize array if empty
if(empty($vars[function_id])) { $vars[function_id] = array(); }

// add a new function
if(isset($vars[add])) { array_push($vars[function_id], 0); }

// functions to delete
if(empty($vars[deleted])) { $deleted = array(); }
else { $deleted = explode(":", $vars[deleted]); }

$javascript_output = "";

// print out functions
for($i=0, $index=0, $max=count($vars[function_id]); $i<$max; $i++) {
	// skip this function if deleting
	if(isset($vars[delete][$i])) {
		// if existing function add to list of ones to delete
		if(!empty($vars[function_id][$i])) {
			array_push($deleted, $vars[function_id][$i]);
		}
		continue;
	}
	
	unset($sel_date);
	unset($sel_location);
	$sel_date[$vars[date][$i]] = " selected=\"selected\"";
	$sel_location[$vars[location][$i]] = " selected=\"selected\"";
	
	$time_element = ($index * 8) + 2;
	$room_element = ($index * 8) + 4;
	
	// add javascript code for setting time and room
	$javascript_output .= "switchDate('{$vars[date][$i]}', document.forms[0].elements[{$time_element}], '{$vars[time][$i]}');\n";
	$javascript_output .= "switchLocation('{$vars[location][$i]}', document.forms[0].elements[{$room_element}], '{$vars[room][$i]}');\n";
	?>
	<tr valign="top">
		<td><input type="hidden" name="function_id[]" value="<?php echo $vars[function_id][$i]; ?>" /><select name="date[]" size="1" onChange="switchDate(this.options[this.selectedIndex].value, this.form.elements[<?php echo $time_element; ?>])" style="font-size: 10px">
		<option value=""></option>
		<?php
		foreach($dates as $k => $v) {
			echo "<option value=\"$k\"$sel_date[$k]>$v</option>\n";
		}
		?>
		</select></td>
		<td><select name="time[]" size="1" style="font-size: 10px">
		</select></td>
		<td><select name="location[]" size="1" onChange="switchLocation(this.options[this.selectedIndex].value, this.form.elements[<?php echo $room_element; ?>])" style="font-size: 10px">
		<option value=""></option>
		<?php
		foreach($locations as $k => $v) {
			echo "<option value=\"$k\"$sel_location[$k]>$v</option>\n";
		}
		?>
		</select></td>
		<td><select name="room[]" size="1" style="font-size: 10px">
		</select></td>
		<td><input type="text" name="event[]" size="20" maxlength="255" value="<?php echo sanitize_output($vars[event][$i]); ?>"></td>
		<td><textarea name="description[]" cols="30" rows="4"><?php echo sanitize_output($vars[description][$i]); ?></textarea></td>
		<td><input type="submit" name="delete[<?php echo $index; ?>]" value="Delete" class="button" /></td>
	</tr>
	<?php
	$index++;
}

if($index == 0) { ?><tr><td colspan="9" align="center"><font class="SmallText">No additional conference functions have been set.</td></tr><?php }
?>
<tr><td colspan="9"><input type="submit" name="add" value="Add Conference Function" class="button" /></td></tr>
<tr><td colspan="9">&nbsp;<br /><input type="submit" value="Submit" class="button" /></td></tr>
</table>
<input type="hidden" name="deleted" value="<?php echo join(":", $deleted); ?>" />
</form>
	<?php
	if(!empty($javascript_output)) { echo "<script type=\"text/javascript\"><!--\n$javascript_output\n--></script>\n"; }
}


// save additional conference functions
function schedulerSaveAdditional($vars) {
	global $cf, $db, $dbtable;
	
	// send back to form if adding/deleting a function
	if(isset($vars[add]) || isset($vars[delete])) {
		schedulerAdditional($vars);
		return;	
	}
	
	check_referer();
	
	// save functions
	for($i=0, $max=count($vars[function_id]); $i<$max; $i++) {
		// sanitize input
		$function_id = (int) $vars[function_id][$i];
		$time = (int) $vars[time][$i];
		$location = (int) $vars[location][$i];
		
		list($room, $event, $description) = strip_html($vars[room][$i], $vars[event][$i], $vars[description][$i]);
		list($room, $event, $description) = sanitize_db_input($room, $event, $description);

		if(empty($function_id)) {
			// add new function
			$db->query("INSERT INTO $dbtable[scheduler_functions] (cf, time, location, room, event, description) VALUES ('$cf', '$time', '$location', '$room', '$event', '$description')");
		} else {
			// update function
			$db->query("UPDATE $dbtable[scheduler_functions] SET time='$time', location='$location', room='$room', event='$event', description='$description' WHERE function_id='$function_id' AND cf='$cf'"); 
		}
	}
	
	// remove deleted functions
	if(!empty($vars[deleted])) {
		$deleted = explode(":", $vars[deleted]);
		for($i=0, $max=count($deleted); $i<$max; $i++) {
			$function_id = (int) $deleted[$i];
			$db->query("DELETE FROM $dbtable[scheduler_functions] WHERE function_id='$function_id' AND cf='$cf'");
		}
	}
	?>
	<p>Additional conference functions saved successfully. View <a href="<?php echo print_url("../schedule.php"); ?>">Conference Schedule</a>.</p>
	<?php
}



// extra functions


// returns list of dates
function schedulerGetDates() {
	global $cf, $db, $dbtable;
	
	// get list of dates
	$dates = array();
	$result = $db->query("SELECT DISTINCT date FROM $dbtable[scheduler_session_times] WHERE cf='$cf' ORDER BY date");
	for($i=0, $max=$db->num_rows($result); $i<$max; $i++) {
		list($date) = $db->assoc_array($result, $i);
		$dates[$date] = date("m/d/Y", strtotime($date));
	}
	
	return $dates;
}


// return list of locations
function schedulerGetLocations() {
	global $cf, $db, $dbtable;
	
	$locations = array();
	$result = $db->query("SELECT location_id, building_short FROM $dbtable[scheduler_locations] WHERE cf='$cf' ORDER BY building");
	for($i=0, $max=$db->num_rows($result); $i<$max; $i++) {
		list($location_id, $building) = $db->assoc_array($result, $i);
		$locations[$location_id] = "$building";
	}
	
	return $locations;
}


// prints a javascript for switching time values based on a selected date
function javascriptDateSwitch() {
	global $cf, $db, $dbtable;
	?>
	<script type="text/javascript">
	<!--
	function switchDate(date, target, selected) {
		// clear target select list
		for(var i=target.length-1; i>=0; i--) {
			target.options[i] = null;
		}
		
		// find date values
		switch(date) {
			<?php
			// get list of dates
			$result = $db->query("SELECT DISTINCT date FROM $dbtable[scheduler_session_times] WHERE cf='$cf' ORDER BY date");
			for($i=0, $max=$db->num_rows($result); $i<$max; $i++) {
				list($date) = $db->assoc_array($result, $i);
				echo "\t\t\tcase \"$date\":\n";
				
				// get list of times for this date
				$time_id = array();
				$time_val = array();
				$time_result = $db->query("SELECT time_id, start_time, end_time FROM $dbtable[scheduler_session_times] WHERE date='$date' AND cf='$cf' ORDER BY start_time, end_time");
				for($j=0, $max_times=$db->num_rows($time_result); $j<$max_times; $j++) {
					list($time_id[], $start_time, $end_time) = $db->assoc_array($time_result, $j);
					$time_val[] = date("g:i A", strtotime($start_time)) . " - " . date("g:i A", strtotime($end_time));
				}
				
				echo "\t\t\t\tvar time_id = new Array(\"" . join("\", \"", $time_id) ."\");\n";
				echo "\t\t\t\tvar time_val = new Array(\"" . join("\", \"", $time_val) ."\");\n";
				echo "\t\t\t\tbreak;\n";
			}
			?>
			default:
				var time_id = new Array();
				var time_val = new Array();
				break;
		}
		
		// populate target select list
		var selectedIndex = 0;
		for(var i=0; i<time_id.length; i++) {
			target.options[i] = new Option(time_val[i], time_id[i]);
			if(selected == time_id[i]) { selectedIndex = i; }
		}
		if(selectedIndex) { target.selectedIndex = selectedIndex; }
	}
	-->
	</script>
	<?php
}


// prints a javascript for switching room values based on a selected location
function javascriptLocationSwitch() {
	global $cf, $db, $dbtable;
	?>
	<script type="text/javascript">
	<!--
	function switchLocation(location, target, selected) {
		// clear target select list
		for(var i=target.length-1; i>=0; i--) {
			target.options[i] = null;
		}
		
		// find location values
		switch(location) {
			<?php
			// get list of locations
			$result = $db->query("SELECT location_id, room FROM $dbtable[scheduler_locations] WHERE cf='$cf' ORDER BY building");
			for($i=0, $max=$db->num_rows($result); $i<$max; $i++) {
				list($location_id, $rooms) = $db->assoc_array($result, $i);
				echo "\t\t\tcase \"$location_id\":\n";
				
				// get list of rooms for this location
				$rooms = preg_split("/\s*,\s*/", $rooms);
								
				echo "\t\t\t\tvar rooms = new Array(\"" . join("\", \"", $rooms) ."\");\n";
				echo "\t\t\t\tbreak;\n";
			}
			?>
			default:
				var rooms = new Array();
				break;
		}
		
		// populate target select list
		var selectedIndex = 0;
		for(var i=0; i<rooms.length; i++) {
			target.options[i] = new Option(rooms[i], rooms[i]);
			if(selected == rooms[i]) { selectedIndex = i; }
		}
		if(selectedIndex) { target.selectedIndex = selectedIndex; }
	}
	-->
	</script>
	<?php
}

