<?php

// Open Conference Systems 1.1
// (c) The Public Knowledge Project 2003
// http://www.pkp.ubc.ca
//
// This file is part of Open Conference Systems.
// 
// Open Conference Systems is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// Open Conference Systems is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with Open Conference Systems; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
// 
// include/functions.inc.php
// 
// $Id: functions.inc.php,v 1.3 2003/04/01 07:58:47 kevin Exp $
// 
// defines several functions needed throughout the site


// print an URL, with $cf parameter for multiple conferences if applicable
function print_url($url) {
	global $multiple, $cf;
	
	if($multiple && $cf) {
		if(eregi("\?", $url)) { $url .= "&cf=$cf"; }
		else { $url .= "?cf=$cf"; }
	}
	
	return $url;
}


// check that the referer is valid
function check_referer() {
	global $HTTP_SERVER_VARS;
	
	$referer = $HTTP_SERVER_VARS[HTTP_REFERER];
	$host = $HTTP_SERVER_VARS[HTTP_HOST];
	$host_fwd = $HTTP_SERVER_VARS[HTTP_X_FORWARDED_HOST];
	if(empty($host_fwd)) { $host_fwd = $host; }
	$page = $HTTP_SERVER_VARS[PHP_SELF];

	if(empty($referer)) {
		$referer = getenv('HTTP_REFERER');
	}

	if(empty($referer)) {
		die("<p><b>Referer check failed. Please try submitting again.</b></p>");
	}
	
	$page = preg_replace("/[^\/]*$/", "", $page);
	$referer_check = $host.$page;
	$referer_check_fwd = $host_fwd.$page;
	
	if(!strstr($referer, $referer_check) && !strstr($referer, $referer_check_fwd)) {
		die("<p><b>Referer check failed. Please try submitting again.</b></p>");
	}
	else {
		return true;
	}
}


// check if a name is valid (alphanumeric characters only)
function check_name($name) {
	return preg_match("/^[A-Z0-9]+$/i", $name);
}


// email validation function
function check_email($email) {
	return (eregi( "^" .
            "[a-z0-9]+([_\\.-][a-z0-9]+)*" .    // user
            "@" .
            "([a-z0-9]+([\.-][a-z0-9]+)*)+" .   // domain
            "\\.[a-z]{2,}" .                    // sld, tld
            "$", $email)
		   );
}


// set the title and logo images for the theme
function theme_set_images() {
	global $themesdir;
	global $global_items, $conference_items, $cf, $basedir, $baseurl, $fullpath;
	global $title_image, $logo_image;
	
	if(isset($cf)) {
		$items = $conference_items;
		$img[title] = "title-$cf.gif";
		$img[logo] = "logo-$cf.gif";
	}
	else {
		$items = $global_items;
		$img[title] = "title.gif";
		$img[logo] = "logo.gif";
	}
	
	// set title image (or text)
	if($items[title_image] == "text" && $items[title_text]) {
		$title_image = "<font class=\"ConferenceTitle\">$items[title_text]</font>";
	}
	else if($items[title_image] == "custom" && file_exists($fullpath."images/$img[title]")) {
		$title_image = "<img src=\"".$basedir."images/$img[title]\" border=\"0\" vspace=\"0\" hspace=\"0\" alt=\"$items[name]\">";
	}
	else {
		$title_image = "<img src=\"".$themesdir."images/title.gif\" border=\"0\" vspace=\"0\" hspace=\"0\" alt=\"$items[name]\">";
	}
	
	// set logo image, if applicable
	if($items[logo_image] == "custom" && file_exists($fullpath."images/$img[logo]")) {
		$logo_image = "<img src=\"".$basedir."images/$img[logo]\" border=\"0\" vspace=\"0\" hspace=\"0\">";
	}
	else if($items[logo_image] == "none") {
		$logo_image = "<img src=\"".$basedir."images/spacer.gif\" border=\"0\" vspace=\"0\" hspace=\"0\">";
	}
	else {
		$logo_image = "<img src=\"".$themesdir."images/logo.gif\" border=\"0\" vspace=\"0\" hspace=\"0\">";
	}
	
}

// email footer text
function email_footer() {
	global $conference_items;
	
	$emailbody = "";
	if(!empty($conference_items[contact_name])) {
		$emailbody .= "$conference_items[contact_name]\n";
	}
	if(!empty($conference_items[contact_title])) {
		$emailbody .= "$conference_items[contact_title]\n";
	}
	if(!empty($conference_items[contact_address])) {
		$emailbody .= "$conference_items[contact_address]\n";
	}
	if(!empty($conference_items[contact_phone])) {
		$emailbody .= "Phone: $conference_items[contact_phone]\n";
	}
	if(!empty($conference_items[contact_fax])) {
		$emailbody .= "Fax: $conference_items[contact_fax]\n";
	}
	if(!empty($conference_items[contact_email])) {
		$emailbody .= "Email: $conference_items[contact_email]\n";
	}

	return $emailbody;	
}


// text sanitization functions

// sanitize variables for insertion into database
function sanitize_db_input() {
	$vars = array();
	foreach(func_get_args() as $var) {
		if(get_magic_quotes_gpc() == 0) { $var = addslashes($var); }
		array_push($vars, $var);
	}
	if(count($vars) == 1) { return $vars[0]; }
	else { return $vars; }
}

// sanitize variables for output (without html)
function sanitize_output() {
	$vars = array();
	foreach(func_get_args() as $var) {
		if(get_magic_quotes_gpc() == 1) { $var = stripslashes($var); }
		array_push($vars, htmlspecialchars($var));
	}
	if(count($vars) == 1) { return $vars[0]; }
	else { return $vars; }
}

// sanitize variables for output (with html, except javascript)
function sanitize_html_output() {
	$vars = array();
	foreach(func_get_args() as $var) {
		$var = preg_replace("/\<\/?script[^\>]*\>/i", "", $var);
		$var = preg_replace("/\s*onload=[^\>]*/i", "", $var);
		if(get_magic_quotes_gpc() == 1) { $var = stripslashes($var); }
		array_push($vars, $var);
	}
	if(count($vars) == 1) { return $vars[0]; }
	else { return $vars; }
}

// strip html
function strip_html() {
	$vars = array();
	foreach(func_get_args() as $var) {
		array_push($vars, htmlspecialchars($var));
	}
	if(count($vars) == 1) { return $vars[0]; }
	else { return $vars; }
}

// function to remove double quotes to prevent formatting issues with hidden preview fields
function remove_quotes($string) {
	$string=str_replace("\"","''",$string);
	return $string;
}

// function to add quotes back
function add_quotes($string) {
	$string=str_replace("\'\'","\"",$string);
	return $string;
}


// function to convert database timestamp to unix timestamp
function timestamp2php($timestamp) {
	global $db_type;
	if($db_type == "mysql") {
		$timestamp = substr($timestamp,0,4)."-".substr($timestamp,4,2)."-".substr($timestamp,6,2)." ".substr($timestamp,8,2).":".substr($timestamp,10,2).":".substr($timestamp,12,2);
	}
	return strtotime($timestamp);
}


// function to generate a date select menu
function date_menu($prefix, $date = "", $blank = 0) {
	// set default values for month, day, year
	if($date) {
		list($year, $month, $day) = explode("-", $date);
	}
	
	if(!$blank) {	
		if(!$month || $month == "00") { $month = date("m"); }
		if(!$day || $day == "00") { $day = date("d"); }
		if(!$year || $year == "0000") { $year = date("Y"); }
	}

	echo "<select name=\"".$prefix."_month\">
	<option value=\"\"></option>\n";
	
	// print months
	$months = array("January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December");
	for($i=1; $i<=12; $i++) {
		echo "<option value=\"".sprintf("%02d",$i)."\"";
		if(sprintf("%02d",$i) == $month) { echo " selected"; }
		echo ">".$months[$i-1]."</option>\n";
	}
	
	echo "</select>
	<select name=\"".$prefix."_day\">
	<option value=\"\"></option>\n";
	
	// print days
	for($i=1; $i<=31; $i++) {
		echo "<option value=\"".sprintf("%02d",$i)."\"";
		if(sprintf("%02d",$i) == $day) { echo " selected"; }
		echo ">$i</option>\n";	
	}
	
	echo "</select>
	<select name=\"".$prefix."_year\">
	<option value=\"\"></option>\n";
	
	// print years
	for($i=2000; $i<=2012; $i++) {
		echo "<option value=\"$i\"";
		if($i == $year) { echo " selected"; }
		echo ">$i</option>\n";	
	}
	echo "</select>\n";
}


// function to generate a time select menu
function time_menu($suffix, $time = "", $blank = 0, $is_array = 0) {
	// set default values for month, day, year
	if($time && $is_array) {
		list($hour, $min, $ampm) = $time;
	
	} else if($time) {
		list($hour, $min, $ampm) = explode(":", date("h:i:A", strtotime($time)));
	}
	
	if(!$blank) {	
		if(!$hour || $hour == "00") { $hour = date("h"); }
		if(!$min || $min == "00") { $day = date("i"); }
		if(!$ampm) { $ampm = date("A"); }
	}

	echo "<select name=\"hour_".$suffix."\">
	<option value=\"\"></option>\n";
	
	// print hours
	for($i=1; $i<=12; $i++) {
		echo "<option value=\"".sprintf("%02d",$i)."\"";
		if(sprintf("%02d",$i) == $hour) { echo " selected"; }
		echo ">$i</option>\n";
	}
	
	echo "</select>:<select name=\"min_".$suffix."\">
	<option value=\"\"></option>\n";
	
	// print minutes
	for($i=0; $i<=45; $i+=15) {
		echo "<option value=\"".sprintf("%02d",$i)."\"";
		if(sprintf("%02d",$i) == $min) { echo " selected"; }
		echo ">".sprintf("%02d",$i)."</option>\n";	
	}
	
	echo "</select>
	<select name=\"ampm_".$suffix."\">
	<option value=\"\"></option>
	<option value=\"AM\"";
	if($ampm == "AM") { echo " selected"; }
	echo ">AM</option>
	<option value=\"PM\"";
	if($ampm == "PM") { echo " selected"; }
	echo ">PM</option>
	</select>\n";
}
