<?php

// PKP Open Archives Initiative Interface v2.0
// (c) The Public Knowledge Project 2002
// http://www.pkp.ubc.ca
// 
// include/functions.inc.php
//
// defines various function for outputting information from the data repository

/*
 *
 * Required functions
 * The below functions must be defined for the OAI class to function correctly
 *
 */


// Returns the earliest datestamp in the repository
// Must be in UTC format (i.e. YYYY-MM-DD or YYYY-MM-DDThh:mm:ssZ)
function getEarliestDatestamp() {
	global $db, $dbtable;
	$result = $db->query("SELECT MIN(timestamp) FROM $dbtable[papers] WHERE accepted='true'");
	list($datestamp) = $db->assoc_array($result);
	return UTCDate(strtotime(date("Y-m-d", timestamp2php($datestamp)) . " -1 day"));
}


// Returns an associative array containing the metadata for the requested identifier if it exists
// Returns false if the identifier does not exist
function getRecordMetadata($identifier) {
	global $db, $dbtable;
	
	// get database id
	$id = getIdFromIdentifier($identifier);
	if(empty($id)) { return false; }
	
	// get metadata from database
	$result = $db->query("SELECT * FROM $dbtable[papers] WHERE id='$id' AND accepted='true'");
	if($db->num_rows($result) == 0) { return false; }
	
	$items = $db->assoc_array($result);
	
	return formatMetadata($items);
}


// Returns a list of identifiers matching the passed parameters
// Returns false if no matching records are found
// $offset is set to the current record offset, $total to the total number of results
// $from and $until are both UNIX timestamps
// ($from, $until, and $set are optional parameters and may not be set)
function getIdentifiers($metadataPrefix, $from, $until, $set, &$offset, &$total) {
	global $oai_config, $db, $dbtable;
	
	$sql = "SELECT id, timestamp FROM $dbtable[papers] WHERE accepted='true' ";
	
	// determine parameters for selective harvesting
	$where = array();
	if(isset($from)) { array_push($where, "timestamp>='" . date("Y-m-d", $from) . "'"); }
	if(isset($until)) { array_push($where, "timestamp<='" . date("Y-m-d", $until) . "'"); }
	if(!empty($where)) { $sql .= "AND " . join(" AND ", $where) . " "; }
	
	$sql .= "ORDER BY id";
	
	$result = $db->query($sql);
	$total = $db->num_rows($result);
	
	if($total == 0) {
		// no matching records found
		return false;
		
	} else {
		// return matching identifiers
		$identifiers = array();
		
		for($offset, $max=$offset + $oai_config[max_identifiers]; $offset<$max && $offset<$total; $offset++) {
			list($id, $datestamp) = $db->assoc_array($result, $offset);
			array_push($identifiers, array("identifier" => getIdentifierFromID($id), "datestamp" => UTCDate(timestamp2php($datestamp)), "set" => "conference-papers"));
		}
		
		return $identifiers;
	}
}


// Returns a list of records matching the passed parameters
// Returns false if no matching records are found
// $offset is set to the current record offset, $total to the total number of results
// $from and $until are both UNIX timestamps
// ($from, $until, and $set are optional parameters and may not be set)
function getRecords($metadataPrefix, $from, $until, $set, &$offset, &$total) {
	global $oai_config, $db, $dbtable;
	
	$sql = "SELECT * FROM $dbtable[papers] WHERE accepted='true' ";

	// determine parameters for selective harvesting
	$where = array();
	if(isset($from)) { array_push($where, " timestamp>='" . date("Y-m-d", $from) . "'"); }
	if(isset($until)) { array_push($where, " timestamp<='" . date("Y-m-d", $until) . "'"); }
	if(!empty($where)) { $sql .= "AND " . join(" AND ", $where) . " "; }
	
	$sql .= "ORDER BY id";
	
	$result = $db->query($sql);
	$total = $db->num_rows($result);
	
	if($total == 0) {
		// no matching records found
		return false;
		
	} else {
		// return matching records
		$records = array();
		
		for($offset, $max=$offset + $oai_config[max_records]; $offset<$max && $offset<$total; $offset++) {
			$items = $db->assoc_array($result, $offset);
			array_push($records, array("identifier" => getIdentifierFromID($items[id]), "datestamp" => UTCDate(timestamp2php($items[timestamp])), "metadata" => formatMetadata($items)));
		}
		
		return $records;
	}
}


// Returns an array of metadata formats supported by this repository
// (and optionally, supported by a specified record in this repository)
// The array should be formatted as array($prefix => array("schema" => $schema, "namespace" => $namespace));
// Return an empty array if no formats are available
function getMetadataFormats($identifier = false) {
	return array(
		"oai_dc" => array("schema" => "http://www.openarchives.org/OAI/2.0/oai_dc.xsd", "namespace" => "http://www.openarchives.org/OAI/2.0/oai_dc/"),
		"oai_marc" => array("schema" => "http://www.openarchives.org/OAI/1.1/oai_marc.xsd", "namespace" => "http://www.openarchives.org/OAI/1.1/oai_marc"),
		"marcxml" => array("schema" => "http://www.loc.gov/standards/marcxml/schema/MARC21slim.xsd", "namespace" => "http://www.loc.gov/MARC21/slim"),
		"rfc1807" => array("schema" => "http://www.openarchives.org/OAI/1.1/rfc1807.xsd", "namespace" => "http://info.internet.isi.edu:80/in-notes/rfc/files/rfc1807.txt")
	);
}


// Returns a list of sets in this repository, or false if sets are not supported
// $offset is set to the current record offset, $total to the total number of results
// Note: "spec" must not contain spaces, commas, colons (except when specifying a hierarchy), and certain other special characters
function getSets(&$offset, &$total) {
	global $oai_config, $db, $dbtable;
	
	return array("conference-papers");
}


// Returns true if the given identifier exists, false if it does not exist
function identifierExists($identifier) {
	global $db, $dbtable;
	
	$result = $db->query("SELECT id FROM $dbtable[papers] WHERE id='" . getIdFromIdentifier($identifier) . "' AND accepted='true'");
	if($db->num_rows($result) == 0) { return false; }
	else { return true; }
}


// Sets a new resumption token and returns its id
// $expiration_date is a UNIX timestamp, $offset an int, and $params an associative array of parameters to be stored
function setResumptionToken($expiration_date, $offset, $params) {
	global $db, $dbtable;
	resumptionTokenGC();
	
	do {
		// create unique token id
		$token = md5(uniqid(rand(),1));
		$result = $db->query("SELECT token FROM $dbtable[oai_resumption_tokens] WHERE token='$token'");
	} while($db->num_rows($result) != 0);
	
	// create token
	$params = addslashes(serialize($params));
	$result = $db->query("INSERT INTO $dbtable[oai_resumption_tokens] (token, expiration_date, record_offset, params) VALUES ('$token', '$expiration_date', '$offset', '$params')");

	return $token;
}


// Returns the parameters for the specified resumption token if it exists
// Returns false if the resumption token does not exist or has expired
function getResumptionToken($token) {
	global $db, $dbtable;
	resumptionTokenGC();
	
	$result = $db->query("SELECT record_offset, params FROM $dbtable[oai_resumption_tokens] WHERE token='$token'");
	if($db->num_rows($result) == 0) {
		// token is invalid
		return false;
		
	} else {
		// return token parameters
		list($offset, $params) = $db->assoc_array($result);
		$params = unserialize($params);
		$params[offset] = $offset;
		
		return $params;
	}
}


// Checks if the given identifier is in a valid format
// Returns false if invalid, true otherwise
function validIdentifier($identifier) {
	if(getIdFromIdentifier($identifier) === false) {
		return false;
	} else {
		return true;
	}
}




/*
 *
 * Extra functions
 * Helper functions used above
 *
 */


// Formats Dublin Core-style metadata from database record
function formatMetadata(&$items) {
	global $db, $dbtable, $multiple, $baseurl, $conference_items;
	
	if($multiple) {
		// get conference info
		$result = $db->query("SELECT * FROM $dbtable[conference] WHERE id='$items[cf]'");
		if($db->num_rows($result) != 0) {
			$conference_items = $db->assoc_array($result);
		}
	}
	
	// format multiple authors
	$creator = array("$items[surname], $items[first_name]; $items[affiliation]; $items[email]");
	if(!empty($items[add_surnames])) {
		$add_surnames = explode("\n", $items[add_surnames]);
		$add_first_names = explode("\n", $items[add_first_names]);
		$add_affiliations = explode("\n", $items[add_affiliations]);
		$add_emails = explode("\n", $items[add_emails]);
		
		for($i=0, $max=count($add_surnames); $i<$max; $i++) {
			if(!empty($add_surnames[$i])) {
				array_push($creator, "$add_surnames[$i], $add_first_names[$i]; $add_affiliations[$i]; $add_emails[$i]");
			}
		}
	}
	
	// include default DC metadata
	include("../include/defaults.inc.php");
	
	// return associative array of Dublin Core-style metadata
	return array(
		"identifier" => $baseurl . "viewabstract.php?id=$items[id]&cf=$items[cf]",
		"datestamp" => UTCDate(timestamp2php($items[timestamp])),
		"set" => "conference-papers",
		"title" => $items[title],
		"creator" => $creator,
		"subject" => array($items[discipline], $items[topic]),
		"description" => $items[abstract],
		"publisher" => $def_publisher,
		"contributor" => array($items[sponsor], $def_contributor),
		"date" => $def_date,
		"type" => array($items[relation] . " " . $def_type, $items[approach]),
		"format" => $items[format],
		"source" => $def_source,
		"language" => $items[language],
		"relation" => "",
		"coverage" => $items[coverage],
		"rights" => $def_rights
	);
}


// Formats an OAI identifier from a database record id
function getIdentifierFromID($id) {
	global $oai_config;
	return "oai".$oai_config[delimiter].$oai_config[repositoryidentifier].$oai_config[delimiter]."paper/$id";
}


// Returns the database record id from a passed OAI identifier
function getIdFromIdentifier($identifier) {
	global $oai_config;
	$identifier_match = "oai".$oai_config[delimiter].$oai_config[repositoryidentifier].$oai_config[delimiter]."paper/";
	if(strstr($identifier, $identifier_match)) {
		return (int) str_replace($identifier_match, "", $identifier);
	} else {
		return false;
	}
}


// Returns a UTC-formatted datestamp from a UNIX timestamp, with granularity as set in $oai_config[granularity]
function UTCDate($timestamp) {
	global $oai_config;
	$format = "Y-m-d";
	if($oai_config[granularity] == "YYYY-MM-DDThh:mm:ssZ") { $format .= "\TH:i:s\Z"; }
	return gmdate($format, $timestamp);
}


// Resumption token garbage collection
// Deletes expired resumption tokens
function resumptionTokenGC() {
	global $db, $dbtable;
	$db->query("DELETE FROM $dbtable[oai_resumption_tokens] WHERE expiration_date<'" . time() . "'");
}
