<?php

// PKP Open Archives Initiative Interface v2.0
// (c) The Public Knowledge Project 2002
// http://www.pkp.ubc.ca
// 
// include/oai.inc.php
//
// defines a class for handling OAI requests


class OAI
{
	/*
	 *
	 * Public Interface
	 *
	 */

	// Constructor
	function OAI() {
		// store response date
		$this->response_date = $this->UTCDate();
		
		// initialize parameters from GET or POST variables
		$this->params = array();
		
		if(isset($GLOBALS[HTTP_RAW_POST_DATA]) && !empty($GLOBALS[HTTP_RAW_POST_DATA])) {
			$this->parseStr($GLOBALS[HTTP_RAW_POST_DATA], $this->params);
		} else if(!empty($_SERVER[QUERY_STRING])) {
			$this->parseStr($_SERVER[QUERY_STRING], $this->params);		
		} else {
			$this->params = array_merge($_GET, $_POST);
		}
		
		// clean input variables
		$this->prepInput($this->params);
	}
	
	
	// Output GetRecord response
	function GetRecord() {
		// validate parameters
		$this->checkParams(array("identifier", "metadataPrefix"));
		
		// check that identifier is in valid format
		if(validIdentifier($this->getParam("identifier")) === false) {
			$this->error("badArgument", "Identifier is not in a valid format");
		}
		
		// get metadata for requested identifier
		if(($metadata = getRecordMetadata($this->getParam("identifier"))) === false) {
			$this->error("idDoesNotExist", "No matching identifier in this repository");
		}
		
		// check that the requested metadata format is supported for this identifier
		if(!in_array($this->getParam("metadataPrefix"), array_keys(getMetadataFormats($this->getParam("identifier"))))) {
			$this->error("cannotDisseminateFormat", "The requested metadataPrefix is not supported by this repository");
		}
		
		// format metadata for output
		$this->prepOutput($metadata);		
		
		$response = "  <GetRecord>\n" .
		            "    <record>\n" .
		            "      <header>\n" .
		            "        <identifier>" . $this->getParam("identifier") ."</identifier>\n" .
		            "        <datestamp>$metadata[datestamp]</datestamp>\n";
		// output set memberships
		if(isset($metadata[set])) {
			if(!is_array($metadata[set])) { $metadata[set] = array($metadata[set]); }
			foreach($metadata[set] as $k) {
				$response .= "        <setSpec>$k</setSpec>\n";
			}
		}
		$response .= "      </header>\n" .
		            "      <metadata>\n";
		// output metadata
		$response .= $this->getMetadata($this->getParam("metadataPrefix"), $metadata);
		$response .= "      </metadata>\n" .
		            "    </record>\n" .
		            "  </GetRecord>\n";
		
		$this->response($response);
	}
	
	
	// Output Identify response
	function Identify() {
		// validate parameters
		$this->checkParams();
		
		// format body of response
		$response = "  <Identify>\n" .
		            "    <repositoryName>" . $this->getConfig("repositoryname") . "</repositoryName>\n" .
		            "    <baseURL>" . $this->getConfig("baseurl") . "</baseURL>\n" .
		            "    <protocolVersion>" . $this->getConfig("protocolversion") . "</protocolVersion>\n" .
		            "    <adminEmail>" . $this->getConfig("adminemail") . "</adminEmail>\n" .
		            "    <earliestDatestamp>" . getEarliestDatestamp() . "</earliestDatestamp>\n" .
		            "    <deletedRecord>no</deletedRecord>\n" .
		            "    <granularity>" . $this->getConfig("granularity") . "</granularity>\n";
		// show compression options if server supports Zlib
		if(extension_loaded("zlib")) {
			$response .= "    <compression>gzip</compression>\n" .
		                "    <compression>deflate</compression>\n";
		}
		$response .= "    <description>\n" .
		            "      <oai-identifier\n" .
		            '        xmlns="http://www.openarchives.org/OAI/2.0/oai-identifier"' . "\n" .
		            '        xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"' . "\n" .
		            '        xsi:schemaLocation=' . "\n" .
		            '          "http://www.openarchives.org/OAI/2.0/oai-identifier' . "\n" .
		            '          http://www.openarchives.org/OAI/2.0/oai-identifier.xsd">' . "\n" .
		            "        <scheme>oai</scheme>\n" .
		            "        <repositoryIdentifier>" . $this->getConfig("repositoryidentifier") . "</repositoryIdentifier>\n" .
		            "        <delimiter>" . $this->getConfig("delimiter") . "</delimiter>\n" .
		            "        <sampleIdentifier>" . $this->getConfig("sampleidentifier") . "</sampleIdentifier>\n" .
		            "      </oai-identifier>\n" .
		            "    </description>\n" .
		            "  </Identify>\n";
		
		$this->response($response);
	}
	
	
	// Output ListIdentifiers response
	function ListIdentifiers() {
		// check for resumption token
		if($this->paramExists("resumptionToken")) {		
			// validate parameters
			$this->checkParams(array("resumptionToken"));
			
			// get parameters from resumption token
			if(($params = getResumptionToken($this->getParam("resumptionToken"))) === false) {
				$this->error("badResumptionToken", "The requested resumptionToken is invalid or has expired");
			}

 			$offset = $params[offset];
			unset($params[offset]);
			
		} else {		
			// validate parameters
			$this->checkParams(array("metadataPrefix"), array("from", "until", "set"));
		
			// use passed parameters
			$params = $this->getParams();
			
			// check that the requested metadata format is supported
			if(!in_array($params[metadataPrefix], array_keys(getMetadataFormats()))) {
				$this->error("cannotDisseminateFormat", "The requested metadataPrefix is not supported by this repository");
			}
		
			// if a set was passed check if repository supports sets
			if($this->paramExists("set") && $this->getConfig("max_sets") == 0) {
				$this->error("noSetHierarchy", "This repository does not support sets");
			}
			
			$offset = 0;
		}
		
		// get UNIX timestamps for from and until dates, if applicable
		$this->validateDateParams($params, $from, $until);
		
		// store current offset and total records for resumption token, if needed
		$cursor = $offset;
		$total = 0;
				
		// get list of matching identifiers
		if(($identifiers = getIdentifiers($params[metadataPrefix], $from, $until, $params[set], $offset, $total)) === false) {
			$this->error("noRecordsMatch", "No matching records in this repository");
		}

		// format body of response
		$response = "  <ListIdentifiers>\n";
		
		// format identifiers for output
		$this->prepOutput($identifiers);	
		
		// output identifiers
		for($i=0, $max=count($identifiers); $i<$max, $record = $identifiers[$i]; $i++) {
			$response .= "    <header>\n" .
			             "      <identifier>$record[identifier]</identifier>\n" .
			             "      <datestamp>$record[datestamp]</datestamp>\n";
			// output set memberships
			if(isset($record[set])) {
				if(!is_array($record[set])) { $record[set] = array($record[set]); }
				foreach($record[set] as $k) {
					$response .= "      <setSpec>$k</setSpec>\n";
				}
			}
			$response .= "    </header>\n";
		}
		
		if($offset != 0 && $offset < $total) {
			// partial result, set resumption token
			$expiration_date = time() + $this->getConfig("token_lifetime");
			$token = setResumptionToken($expiration_date, $offset, $params);

			$response .= '    <resumptionToken expirationDate="' . $this->UTCDate($expiration_date) . '"' . "\n" .
			             "        completeListSize=\"$total\"\n" .
			             "        cursor=\"$cursor\">$token</resumptionToken>\n";
		} else if($this->paramExists("resumptionToken")) {
			// current request completes a previous incomplete list, add empty resumption token
			$response .= "    <resumptionToken completeListSize=\"$total\" cursor=\"$cursor\" />\n";
		}
		
		$response .= "  </ListIdentifiers>\n";

		$this->response($response);
	}
	
	
	// Output ListMetadataFormats response
	function ListMetadataFormats() {
		// validate parameters
		$this->checkParams(array(), array("identifier"));
		
		
		// get list of metadata formats for select identifier, or all if no identifier was passed
		if($this->paramExists("identifier")) {
			if(!identifierExists($this->getParam("identifier"))) {
				$this->error("idDoesNotExist", "No matching identifier in this repository");
			} else {
				$formats = getMetadataFormats($this->getParam("identifier"));
			}
			
		} else {
			$formats = getMetadataFormats();
		}
		
		
		if(empty($formats) || !is_array($formats)) {
				$this->error("noMetadataFormats", "No metadata formats are available");
		}
		
		// format body of response
		$response = "  <ListMetadataFormats>\n";
		
		// output metadata formats
		foreach($formats as $k => $v) {
			$response .= "    <metadataFormat>\n" .
		                 "      <metadataPrefix>$k</metadataPrefix>\n" .
		                 "      <schema>$v[schema]</schema>\n" .
		                 "      <metadataNamespace>$v[namespace]</metadataNamespace>\n" .
		                 "    </metadataFormat>\n";
		}
		
		$response .= "  </ListMetadataFormats>\n";
		
		$this->response($response);
	}
	
	
	// Output ListRecords response
	function ListRecords() {
		// check for resumption token
		if($this->paramExists("resumptionToken")) {		
			// validate parameters
			$this->checkParams(array("resumptionToken"));
			
			// get parameters from resumption token
			if(($params = getResumptionToken($this->getParam("resumptionToken"))) === false) {
				$this->error("badResumptionToken", "The requested resumptionToken is invalid or has expired");
			}

 			$offset = $params[offset];
			unset($params[offset]);
			
		} else {		
			// validate parameters
			$this->checkParams(array("metadataPrefix"), array("from", "until", "set"));
		
			// use passed parameters
			$params = $this->getParams();
			
			// check that the requested metadata format is supported
			if(!in_array($params[metadataPrefix], array_keys(getMetadataFormats()))) {
				$this->error("cannotDisseminateFormat", "The requested metadataPrefix is not supported by this repository");
			}
		
			// if a set was passed check if repository supports sets
			if($this->paramExists("set") && $this->getConfig("max_sets") == 0) {
				$this->error("noSetHierarchy", "This repository does not support sets");
			}
			
			$offset = 0;
		}
		
		// get UNIX timestamps for from and until dates, if applicable
		$this->validateDateParams($params, $from, $until);
		
		// store current offset and total records for resumption token, if needed
		$cursor = $offset;
		$total = 0;
		
		// get list of matching records
		if(($records = getRecords($params[metadataPrefix], $from, $until, $params[set], $offset, $total)) === false) {
			$this->error("noRecordsMatch", "No matching records in this repository");
		}

		// format body of response
		$response = "  <ListRecords>\n";
		
		// format records for output
		$this->prepOutput($records);	
		
		// output records
		for($i=0, $max=count($records); $i<$max, $record = $records[$i]; $i++) {
			$response .= "    <record>\n" .
			             "      <header>\n" .
			             "        <identifier>$record[identifier]</identifier>\n" .
			             "        <datestamp>$record[datestamp]</datestamp>\n";
			// output set memberships
			if(isset($record[metadata][set])) {
				if(!is_array($record[metadata][set])) { $record[metadata][set] = array($record[metadata][set]); }
				foreach($record[metadata][set] as $k) {
					$response .= "        <setSpec>$k</setSpec>\n";
				}
			}
			$response .= "      </header>\n" .
			             "      <metadata>\n";
			// output metadata
			$response .= $this->getMetadata($this->getParam("metadataPrefix"), $record[metadata]);
			$response .= "      </metadata>\n" .
			             "    </record>\n";
		}
		
		if($offset != 0 && $offset < $total) {
			// partial result, set resumption token
			$expiration_date = time() + $this->getConfig("token_lifetime");
			$token = setResumptionToken($expiration_date, $offset, $params);

			$response .= '    <resumptionToken expirationDate="' . $this->UTCDate($expiration_date) . '"' . "\n" .
			             "        completeListSize=\"$total\"\n" .
			             "        cursor=\"$cursor\">$token</resumptionToken>\n";
		} else if($this->paramExists("resumptionToken")) {
			// current request completes a previous incomplete list, add empty resumption token
			$response .= "    <resumptionToken completeListSize=\"$total\" cursor=\"$cursor\" />\n";
		}
		
		$response .= "  </ListRecords>\n";

		$this->response($response);
	}
	
	
	// Output ListSets response
	function ListSets() {
		// check for resumption token
		if($this->paramExists("resumptionToken")) {		
			// validate parameters
			$this->checkParams(array("resumptionToken"));
			
			// get parameters from resumption token
			if(($params = getResumptionToken($this->getParam("resumptionToken"))) === false) {
				$this->error("badResumptionToken", "The requested resumptionToken is invalid or has expired");
			}

 			$offset = $params[offset];
			unset($params[offset]);
			
		} else {		
			// validate parameters
			$this->checkParams();
			
			$offset = 0;
		}
		
		// store current offset and total sets for resumption token, if needed
		$cursor = $offset;
		$total = 0;
		
		// get list of matching sets
		if(($sets = getSets($offset, $total)) === false) {
			$this->error("noSetHierarchy", "This repository does not support sets");
		}

		// format body of response
		$response = "  <ListSets>\n";
		
		// format sets for output
		$this->prepOutput($sets);	
		
		// output sets
		for($i=0, $max=count($sets); $i<$max, $set = $sets[$i]; $i++) {
			$response .= "    <set>\n" .
			             "      <setSpec>$set[spec]</setSpec>\n" .
			             "      <setName>$set[name]</setName>\n";
			// output set description, if applicable
			if(isset($set[description])) {
				$response .= "      <setDescription>\n" .
				             "        <oai_dc:dc\n" .
				             '          xmlns:oai_dc="http://www.openarchives.org/OAI/2.0/oai_dc/"' . "\n" .
				             '          xmlns:dc="http://purl.org/dc/elements/1.1/"' . "\n" .
				             '          xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"' . "\n" .
				             '          xsi:schemaLocation="http://www.openarchives.org/OAI/2.0/oai_dc/' . "\n" .
				             '          http://www.openarchives.org/OAI/2.0/oai_dc.xsd">' . "\n" .
				             "          <dc:description>$set[description]</dc:description>\n" .
				             "        </oai_dc:dc>\n" .
				             "      </setDescription>\n";
				             
			}
			$response .= "    </set>\n";
		}
		
		if($offset != 0 && $offset < $total) {
			// partial result, set resumption token
			$expiration_date = time() + $this->getConfig("token_lifetime");
			$token = setResumptionToken($expiration_date, $offset, $params);

			$response .= '    <resumptionToken expirationDate="' . $this->UTCDate($expiration_date) . '"' . "\n" .
			             "        completeListSize=\"$total\"\n" .
			             "        cursor=\"$cursor\">$token</resumptionToken>\n";
		} else if($this->paramExists("resumptionToken")) {
			// current request completes a previous incomplete list, add empty resumption token
			$response .= "    <resumptionToken completeListSize=\"$total\" cursor=\"$cursor\" />\n";
		}
		
		$response .= "  </ListSets>\n";

		$this->response($response);
	}


	// Output an OAI error response
	function error($code, $message) {
		if($code == "badVerb" || $code == "badArgument") { $print_params = false; }
		else { $print_params = true; }
		
		$this->response("\t<error code=\"$code\">$message</error>", $print_params);
		exit;
	}
	
	
	
	/*
	 *
	 * Private Functions
	 *
	 */
	
	// Output the passed OAI response
	function response($response, $print_params = true) {
		header("Content-Type: text/xml");
		
		// encode data with gzip, deflate, or none, depending on browser support
		ob_start("ob_gzhandler");
		
		echo '<?xml version="1.0" encoding="UTF-8"?>' . "\n" .
		     '<OAI-PMH xmlns="http://www.openarchives.org/OAI/2.0/"' . "\n" .
		     '         xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"' . "\n" .
		     '         xsi:schemaLocation="http://www.openarchives.org/OAI/2.0/' .  "\n" .
		     '         http://www.openarchives.org/OAI/2.0/OAI-PMH.xsd">' . "\n" .
		     '  <responseDate>' . $this->response_date . '</responseDate>' . "\n" .
		     '  <request';
		
		// print request params, if applicable
		if($print_params) {
			foreach($this->params as $k => $v) {
				echo " $k=\"" . $this->prepOutput($v) . "\"";
			}
		}
		
		echo ">" . $this->getConfig("baseurl") . "</request>\n" .
		     $response .
		     "</OAI-PMH>\n";
	}
	
	
	// Returns the value of the specified parameter
	function getParam($name) {
		return $this->params[$name];
	}
	
	
	// Returns an associative array of all parameters
	function getParams() {
		return $this->params;
	}
	
	
	// Returns true if the requested parameter is set, false if it is not set
	function paramExists($name) {
		return isset($this->params[$name]);
	}
	
	
	// Returns the value of the specified config variable
	function getConfig($name) {
		global $oai_config;
		return $oai_config[$name];
	}
	
	
	// Check parameters
	// Outputs error and exits if an invalid parameter is found
	function checkParams($required = array(), $optional = array()) {
		// get valid parameters for current request
		$required_params = array_merge(array("verb"), $required);
		$valid_params = array_merge($required_params, $optional);

		// check for missing or duplicate required parameters
		foreach($required_params as $k) {
			if(!$this->paramExists($k)) {
				$this->error("badArgument", "Missing $k parameter");
			} else if(is_array($this->getParam($k))) {
				$this->error("badArgument", "Multiple values are not allowed for the $k parameter");
			}
		}
		
		// check for duplicate optional parameters
		foreach($optional as $k) {
			if($this->paramExists($k) && is_array($this->getParam($k))) {
				$this->error("badArgument", "Multiple values are not allowed for the $k parameter");
			}
		
		}
		
		// check for illegal parameters
		foreach($this->params as $k => $v) {
			if(!in_array($k, $valid_params)) {
				$this->error("badArgument", "$k is an illegal parameter");
			}
		}
		
		return true;
	}
	
	
	// Returns metadata in specified format
	function getMetadata($format, $metadata) {
		switch($format) {
			case "marcxml":
				// MARC21 record
				include_once("formats/marcxml.inc.php");
				return metadataMARCXML($metadata);
				break;
			case "oai_marc":
				// MARC record
				include_once("formats/oai_marc.inc.php");
				return metadataOAI_MARC($metadata);
				break;
			case "rfc1807":
				// RFC 1807 record
				include_once("formats/rfc1807.inc.php");
				return metadataRFC1807($metadata);
				break;
			case "oai_dc":
			default:
				// Dublin Core record
				include_once("formats/oai_dc.inc.php");
				return metadataOAI_DC($metadata);
				break;
		}
	}
	
	
	// Return a UTC-formatted datestamp from the specified UNIX timestamp
	function UTCDate($timestamp = "", $include_time = true) {
		$format = "Y-m-d";
		if($include_time) { $format .= "\TH:i:s\Z"; }
		
		if(empty($timestamp)) { return gmdate($format); }
		else { return gmdate($format, $timestamp); }
	}
	
	
	// Returns a UNIX timestamp from a UTC-formatted datestamp
	// Returns the string "invalid" if invalid, or "invalid_granularity" if unsupported granularity
	function UTCtoTimestamp($date, $check_granularity = true) {
		if(preg_match("/^\d\d\d\d\-\d\d\-\d\d$/", $date)) {
			// match date
			$time = strtotime("$date UTC");
			return ($time != -1) ? $time : "invalid";
		} else if(preg_match("/^(\d\d\d\d\-\d\d\-\d\d)T(\d\d:\d\d:\d\d)Z$/", $date, $matches)) {
			// match datetime
			$date = "$matches[1] $matches[2]";
			if($check_granularity && $this->getConfig("granularity") != "YYYY-MM-DDThh:mm:ssZ") {
				return "invalid_granularity";
			} else {
				$time = strtotime("$date UTC");
				return ($time != -1) ? $time : "invalid";
			}
		}
		
		return "invalid";
	}
	
	
	// Checks if from and until parameters have been passed
	// If passed, validate and convert to UNIX timestamps
	function validateDateParams($params, &$from, &$until) {
		if(isset($params[from])) {
			$from = $this->UTCtoTimestamp($params[from]);
			if($from == "invalid") {
				$this->error("badArgument", "Illegal from parameter");
			
			} else if($from == "invalid_granularity") {
				$this->error("badArgument", "Illegal granularity for from parameter");
			}
		}
		if(isset($params[until])) {
			$until = $this->UTCtoTimestamp($params[until]);
			if($until == "invalid") {
				$this->error("badArgument", "Illegal until parameter");
			
			} else if($until == "invalid_granularity") {
				$this->error("badArgument", "Illegal granularity for until parameter");
			}
			
			// check that until value is greater than or equal to from value
			if(isset($from) && $from > $until) {
				$this->error("badArgument", "until parameter must be greater than or equal to from parameter");
			}
			
			// check that granularities are equal
			if(isset($from) && strlen($params[from]) != strlen($params[until])) {
				$this->error("badArgument", "until and from parameters must be of the same granularity");
			}
		}
	}
	
	
	// Clean input variables
	function prepInput(&$data) {
		if(!is_array($data)) { $data = urldecode($data); }
		else {
			foreach($data as $k => $v) {
				if(is_array($data[$k])) {
					$this->prepInput($data[$k]);
				} else {
					$data[$k] = urldecode($v);
				}
			}
		}
		return $data;
	}
	
	
	// Prepare variables for output
	function prepOutput(&$data) {
		if(!is_array($data)) { $data = utf8_encode(htmlspecialchars($data)); }
		else {
			foreach($data as $k => $v) {
				if(is_array($data[$k])) {
					$this->prepOutput($data[$k]);
				} else {
					$data[$k] = utf8_encode(htmlspecialchars($v));
				}
			}
		}
		return $data;
	}
	
	
	// Parses string $string into an associate array $array
	// Acts like parse_str($string, $array) except duplicate variable names in $string are converted to an array
	function parseStr($string, &$array) {
		$pairs = explode("&", $string);
		foreach($pairs as $p) {
			$vars = explode("=", $p);
			if(!empty($vars[0]) && isset($vars[1])) {
				$key = $vars[0];
				$value = join("=", array_splice($vars, 1));
				if(!isset($array[$key])) {
					$array[$key] = $value;
				} else if(is_array($array[$key])) {
					array_push($array[$key], $value);
				} else {
					$array[$key] = array($array[$key], $value);
				}
			}
		}
	}

	
	
	/*
	 *
	 * Private Variables
	 *
	 */
	
	// Stores list of parameters
	var $params;
	
	// Store date of response
	var $response_date;
	
}

