<?php

// Open Conference Systems 1.1
// (c) The Public Knowledge Project 2003
// http://www.pkp.ubc.ca
//
// This file is part of Open Conference Systems.
// 
// Open Conference Systems is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// Open Conference Systems is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with Open Conference Systems; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
// 
// reviews.php
// 
// $Id: reviews.php,v 1.5 2003/04/01 08:49:48 kevin Exp $
// 
// generates an online Peer Review page, allowing reviewers to post reviews on papers, and authors to view reviews on their paper(s)


// include necessary files
include("include/db.inc.php"); 
include("include/common.inc.php");

if(!isset($cf)) {
	header("Location: index.php");
	exit;
}


// include cookie script
include("include/cookie.inc.php");
if(!$login) { getusercookie(); }

// this page's title
$title = "Paper Proposals for Review";

// creates a hierarchal tree to be printed out in header.php
$tree = array("Home"=>print_url("index.php"));


// include validation script
include("include/validate.inc.php");

// choose the appropriate database to validate with
// "reviewers" if submitting a review
if($action=="submit" || $submit || $action =="changepw") {
	$login_table = $dbtable[reviewers];
}

// or "papers" if viewing reviews
else if($action=="view") {
	$login_table = $dbtable[papers];
}

// if logging in, validate the supplied username and password and store in cookie if valid
if($login) {
	if((validate($username,$password,$login_table,"",true))) {
		setusercookie($username, $password, $save);
	}
	else {
		unset($login);
		if($login_table == $dbtable[reviewers]) { $action = "submit"; }
		else { $action = "view"; }
	}
}


// check if logging out
if($action == "logout") {
	deleteusercookie();
	Header("Location: ".$baseurl.print_url("reviews.php"));
	exit;
}


// include the html header file
include("include/header.inc.php");


// check if the user's login is valid
if(($login || $action || $submit) && validate($username,$password,$login_table)) {
	// check if submitting
	if($submit) {
		check_referer();
		
		// get paper info from database
		$paper = sanitize_db_input($paper);
		$paper_result = $db->query("select title, accepted from $dbtable[papers] where id='$paper' and cf='$cf'");
		$paper_items = $db->assoc_array($paper_result);
		
		// check if reviewer can still submit/edit review
		if($paper_items[accepted]=="false" && time()<strtotime($conference_items[review_deadline])) {
			$can_review = true;
		}
		else {
			$can_review = false;
		}

		// check that this reviewer can review this paper
		$result = $db->query("select paper from $dbtable[reviewer_proposals] where reviewer='$username' and paper='$paper' and cf='$cf'");
		if($db->num_rows($result) == 0 || !$can_review) {
			?>
			<p>You are not allowed to review this paper.</p>
			<?php
		}
		
		// check arguments
		else if(empty($paper) || empty($comments) || empty($recommendation)) {
		?>
		<p>Submission incomplete. Please go <a href="javascript:history.go(-1)">back</a> and complete all fields.</p>
		<?php
		}

		// submit review
		else {
			
			// set default value of anonymity option
			if(!$reveal_name || $conference_items[review_anon] != "true") {
				$reveal_name = "false";
			}
			
			list($paper, $comments, $recommendation, $reveal_name) = strip_html($paper, $comments, $recommendation, $reveal_name);
			list($comments, $recommendation, $reveal_name) = sanitize_db_input($comments, $recommendation, $reveal_name);
			
			// query to create a new review
			if($update=="false") {
				$query = "insert into $dbtable[reviews] (cf, paper, reviewer, comments, recommendation, reveal_name) values('$cf', '$paper', '$username', '$comments', '$recommendation', '$reveal_name')";
			}
			// query to update an existing review 
			else {
				$query = "update $dbtable[reviews] set comments='$comments', recommendation='$recommendation', reveal_name='$reveal_name' where paper='$paper' and reviewer='$username' and cf='$cf'";
			}
			
			// execute the query
			$db->query($query) or die("Unable to add submission to database");
			
			// send notification to conference contact
			if($conference_items[contact_notify]) {
				// get reviewer's name
				$result = $db->query("select name from $dbtable[reviewers] where login='$username'");
 				$reviewer_items = $db->assoc_array($result);
				mail("$conference_items[contact_email] ($conference_items[contact_name])", "$conference_items[name]: New Review Submitted", "$reviewer_items[name] has submitted a review on the proposal \"$paper_items[title]\", at the $conference_items[name] web site, viewable at ".$baseurl.print_url("admin/reviews.php?id=$paper")."\n\nYou can login at ".print_url($baseurl."admin/index.php")." to view this and other reviews.","From: $conference_items[contact_email] ($conference_items[contact_name])", "-f$conference_items[contact_email]");
			}
			
			echo "<font class=\"ArticleTitle\">$title</font></p>
			<p>Your review has been submitted.</p>
				<p><b><a href=\"".print_url("reviews.php?action=submit")."\">Back to Reviews</a></b></p>";
		}
	}
	
	
	// else change reviewer password
	else if($action == "changepw") {
		unset($err);
		unset($pass_changed);
			
		// update password
		if(!empty($old_password) && !empty($new_password) && !empty($new_password2)) {
			check_referer();
			
			if(validate($username,$old_password,$dbtable[reviewers],"",true)) {
				// check if name ias valid
				if(!check_name($new_password)) {
					$err = "New password is invalid.";
				}
				else if($new_password == $new_password2) {
					// update password for reviewer
					$db->query("update $dbtable[reviewers] set password='".base64_encode($new_password)."' where login='$username' and password='".base64_encode($old_password)."' and cf='$cf'");
					?>
					<p>Your password has been changed. You will need to <a href="<?php echo print_url("reviews.php?action=submit"); ?>">login</a> again.</p>
					<?php
					$pass_changed = 1;
				}
				else {
					$err = "New passwords do not match.";
				}
			}
			else {
				$err = "Old password is incorrect.";
			}
		}
		
		if(!isset($pass_changed)) {
			if(isset($err)) { echo "<p>$err</p>"; }
			?>
			<form action="<?php echo print_url("reviews.php?action=changepw"); ?>" method="post">
			
			<p>Use this form to change the password used to login to the reviewer's area. Note: passwords are case sensitive.</p>
			
			<p><b>Old Password</b>: <input type="password" name="old_password" value="<?php echo $old_password; ?>"></p>
			<p><b>New Password</b>: <input type="password" name="new_password" value="<?php echo $new_password; ?>"></p>
			<p><b>New Password Again</b>: <input type="password" name="new_password2" value="<?php echo $new_password2; ?>"></p>
			<p><font class="instructions">Passwords may contain only alphanumeric characters.</font></p>
			<p><input type="submit" value="Change Password" class="button"></p>
			</form>
			<?php
		}	
	}
	
	
	// else show list of abstracts for review
	else if($login_table == $dbtable[reviewers]) {
		// get reviewer info from database
		$result = $db->query("select * from $dbtable[reviewers] where login='$username' and cf='$cf'");
		$items = $db->assoc_array($result);
		
		echo "<font class=\"ArticleTitle\">$title: $items[name]</font></p>";
		
		// review a specific proposal
		if($id) {
			// check that this reviewer can review this paper
			$id = sanitize_db_input($id);
			$result = $db->query("select paper from $dbtable[reviewer_proposals] where reviewer='$username' and paper='$id' and cf='$cf'");
			if($db->num_rows($result) == 0) {
				?>
				<p>You are not allowed to review this paper.</p>
				<?php
			}
			
			else {
			
				// get paper info from database
				$paper_result = $db->query("select * from $dbtable[papers] where id='$id' and cf='$cf'");
				$paper_items = $db->assoc_array($paper_result);
				
				// check if reviewer can still submit/edit review
				if($paper_items[accepted]=="false" && time()<strtotime($conference_items[review_deadline])) {
					$can_review = true;
				}
				else {
					$can_review = false;
				}
				
				// get review info from database if reviewer has already reviewed this proposal
				$review_result = $db->query("select * from $dbtable[reviews] where paper='$id' and reviewer='$username' and cf='$cf'");
				// this is a new review
				if($db->num_rows($review_result)==0) {
					$update = "false";
					$review_items="";
				}
				// this is an existing review
				else {
					$review_items = $db->assoc_array($review_result);
					$update = "true";
				}
				
				// show title/overview of multiple paper presentation, if applicable
				if($paper_items[present_format]=="multiple") {
					echo "a) Title of Multiple Paper Presentation: $paper_items[multiple_title]</p>
				<p>b) Overview:<br />".nl2br($paper_items[multiple_overview])."</p>";
				}
				
				// print out the proposal info
				?>
				<table border="0" width="600" cellpadding="2" cellspacing="0">
				<tr valign="top"><td width="10"><img src="<?php echo $themesdir; ?>images/arrow.gif" width="12" height="12" border="0" name="papers"></td><td width="590"><b><font class="instructions">Proposal #<?php echo $paper_items[id]; ?></font></b><br />
				<font class="ArticleTitle"><?php echo $paper_items[title]; ?></font><br />
				<?php
				if($conference_items[review_blind] == "false") {
					// show author names for non-blind review
					echo $paper_items[first_name] . " " . $paper_items[surname] . ", " . $paper_items[affiliation] . "<br />\n";

					// print additional authors, if applicable
					if($paper_items[add_first_names]) {
						$add_first_names = explode("\n",$paper_items[add_first_names]);
						$add_surnames = explode("\n",$paper_items[add_surnames]);
						$add_affiliations = explode("\n",$paper_items[add_affiliations]);
						for($i=0; $i<count($add_first_names); $i++) {
							echo $add_first_names[$i] . " " . $add_surnames[$i] . ", " . $add_affiliations[$i] . "<br />\n";
						}
					}
				}
				?>
				<font class="instructions"><?php
				
				// check if single present format
				if($paper_items[present_format]=="single") {
					echo "Single paper presentation";
				}
				
				// check if multiple present format
				else if($paper_items[present_format]=="multiple") {
					echo "Multiple paper presentation";
				}
				
				// check if other present format
				else if($conference_items[present_other]=="true") {
					// get other format this paper is using
					if($paper_items[present_format]) {
						$present_othertmp = str_replace("other % ","",$paper_items[present_format]);
					}
					// split other formats into an array
					$present_other_desc = explode("\n",$conference_items[present_other_desc]);
					$present_other_length = explode("\n",$conference_items[present_other_length]);
					$present_other_time = explode("\n",$conference_items[present_other_time]);
					// loop through other present formats and look for a match
					for($i=0; $i<count($present_other_desc); $i++) {
						$y=$i+1;
						if($present_othertmp==$y) {
							echo "$present_other_desc[$i]";
						}
					}
				}
				
				echo "</font><br /><br />
				<b>Abstract</b><br />";
				echo nl2br($paper_items[abstract]);
				
				echo "<br /><br />";
				
				// show additional abstracts if multiple paper presentation
				if($paper_items[present_format]=="multiple" && $paper_items[multiple_presenters]) {
					// split multiple presenters into an array
					$multiple_presenters = explode("; ",$paper_items[multiple_presenters]);
					for($i=0; $i<count($multiple_presenters); $i++) {
						$multiple_presenters[$i] = sanitize_db_input($multiple_presenters[$i]);
						$tmppaper_result = $db->query("select * from $dbtable[papers] where email='$multiple_presenters[$i]' and present_format='multiple' and cf='$cf'");
						$tmppaper_items = $db->assoc_array($tmppaper_result);
						?>
						<b><font class="instructions">Proposal #<?php echo $tmppaper_items[id]; ?></font></b><br />
						<font class="ArticleTitle"><?php echo $tmppaper_items[title]; ?></font><br /><br />
						<b>Abstract</b><br />
						<?php
						echo nl2br($tmppaper_items[abstract]);
						
						echo "<br /><br />";
					}
				}
				
				if($conference_items[submission_type] == "both") {
					// show link to full-text
					echo "<b>Full Text</b><br />";
					
					if($paper_items[paper]=="PDF") {
						// print link to pdf
						$paper_file = "$paper_items[pdf]";
						
						// remove troublesome characters
						$paper_file = str_replace(" ","",$paper_file);
						$paper_file = str_replace("/","",$paper_file);
						$paper_file = str_replace("'","",$paper_file);
						$paper_file = str_replace("\"","",$paper_file);
						$paper_file = str_replace("\\","",$paper_file);
						
						$paper_file = $baseurl."papers/".$paper_file;
						
						echo "The full text of this paper is available <a class=\"MainTextLink\" href=\"$paper_file\">here</a> in PDF format";

					} else {
						echo $paper_items[paper];
					}
						
					echo "<br /><br />";
				}
				
				// print out the review submssion form
				if($can_review) {
				?>
				<form action="<?php echo print_url("reviews.php"); ?>" method="post">
				<input type="hidden" name="paper" value="<?php echo $paper_items[id]; ?>">
				<input type="hidden" name="update" value="<?php echo $update; ?>">
				<?php
				}
				?>
				
				<b>Comments</b><br />
				<?php
				// print out comment instructions, if applicable
				if($conference_items[review_com]) {
					echo "<font class=\"instructions\">" . nl2br($conference_items[review_com]) . "</font><br />";
				}
				if($can_review) {
					echo "<textarea name=\"comments\" wrap=\"virtual\" cols=\"60\" rows=\"10\">$review_items[comments]</textarea>";
				}
				else {
					echo nl2br($review_items[comments]);
				}
				echo "<br /><br />
				
				<b>Recommendations</b><br />";
				// print out recommendations instructions, if applicable
				if($conference_items[review_rec]) {
					echo "<font class=\"instructions\">" . nl2br($conference_items[review_rec]) . "</font><br />";
				}
				if($can_review) {
					echo "<textarea name=\"recommendation\" wrap=\"virtual\" cols=\"60\" rows=\"10\">$review_items[recommendation]</textarea>";
				}
				else {
					echo nl2br($review_items[recommendation]);
				}
				echo "<br /><br />";
				
				// show anonymity option, if applicable
				if($conference_items[review_anon]=="true" && $can_review) {
					echo "<input type=\"checkbox\" name=\"reveal_name\" value=\"true\"";
					if($review_items[reveal_name]=="true") {
						echo " checked";
					}
					echo ">Reveal reviewer's name to author(s)<br /><br />";
				}
				
				if($can_review) {
				?>
				<input type="submit" name="submit" value="Submit Review" class="button"> <input type="reset" class="button"></form>
				<?php
				}
				
				// print reason if can't review paper
				if(!$can_review && time()>strtotime($conference_items[review_deadline])) {
					?><p class="instructions">You can no longer edit or submit a review of this paper. The review deadline has passed.</p><?php
				}
				else if(!$can_review && $paper_items[accepted]=="true") {
					?><p class="instructions">You can no longer edit or submit a review of this paper. It has been accepted.</p><?php
				}
				else if(!$can_review && $paper_items[accepted]=="reject") {
					?><p class="instructions">You can no longer edit or submit a review of this paper. It has been rejected.</p><?php
				}
				?>
				
				</td></tr>
				<tr height="16"><td colspan="2">&nbsp;</td></tr>
			
				</table>
			
			<?php
			}
			?>
			<p><b><a href="<?php echo print_url("reviews.php?action=submit"); ?>">Back to Reviews</a></b></p>
			<?php
		}
		
		// else show list of proposals for this reviewer
		else {
			echo "<p>Review deadline: ".date("F j, Y", strtotime($conference_items[review_deadline]))."</p>";
			?>
			<table border="0" width="600" cellpadding="2" cellspacing="0">
			<?php
			
			// get list of proposals for this reviewer
			$paper_result = $db->query("select * from $dbtable[reviewer_proposals] as r, $dbtable[papers] as p where r.reviewer='$username' and r.paper=p.id and r.cf=p.cf and r.cf='$cf' order by r.paper");

			// loop and print out each paper's title and link to review it
			for($i=0; $i<$db->num_rows($paper_result); $i++) {
				$paper_items = $db->assoc_array($paper_result, $i);
				$review_result = $db->query("select timestamp from $dbtable[reviews] where paper='$paper_items[id]' and reviewer='$username' and cf='$cf'");
				if($db->num_rows($review_result)==0) {
					$update = "false";
					$review_items="";
				}
				else {
					$review_items = $db->assoc_array($review_result);
					$update = "true";
				}
				
				?>
				<tr valign="top"><td width="10"><img src="<?php echo $themesdir; ?>images/arrow.gif" width="12" height="12" border="0" name="papers"></td><td width="590"><b><font class="instructions">Proposal #<?php echo $paper_items[id]; ?></font></b><br />
				
				<font class="ArticleTitle"><a href="<?php echo print_url("reviews.php?action=submit&id=$paper_items[id]"); ?>"><?php echo $paper_items[title]; ?></a></font>
			<?php
			// show date review was submitted, if applicable
			if(!empty($review_items)) {
				echo "<br />\nReview submitted: ".date("F j, Y g:i A", timestamp2php($review_items[timestamp]));
			}
			?>
				
				</td></tr>
				<tr height="16"><td colspan="2">&nbsp;</td></tr>
				<?php
			}
			
			if($db->num_rows($paper_result) == 0) {
				?>
				<tr><td colspan="2">There are no papers to review.</td></tr>
				<tr height="16"><td colspan="2">&nbsp;</td></tr>
				<?php
			}
			
			?>
			<tr valign="middle" height="16"><td width="10"><img src="<?php echo $themesdir; ?>images/arrow.gif" width="12" height="12" border="0"></td><td width="590"><b><a href="<?php echo print_url("reviews.php?action=changepw"); ?>">Change Password</a></b></td></tr>
			<tr valign="middle" height="16"><td width="10"><img src="<?php echo $themesdir; ?>images/arrow.gif" width="12" height="12" border="0"></td><td width="590"><b><a href="<?php echo print_url("reviews.php?action=logout"); ?>">Log Out</a></b></td></tr>
			</table>
			<?php
		
		}
	
	}
	
	// else show reviews on an author's paper(s), if applicable
	else if($login_table == $dbtable[papers]) {
		// get papers author is allowed to look at reviews on from database
		$result = $db->query("Select title, id from $dbtable[papers] where login='$username' and view_reviews='true' and cf='$cf'");
		$numresults = $db->num_rows($result);
		
		// check if user can view reviews
		if($numresults==0) {
			echo "<p>Sorry, you are not allowed to view reviews on your paper(s).</p>";
		}
		else {
			// print out list of reviews if there is more than one
			if($numresults>1) {
				?>
				<font class="ArticleTitle">View Reviews</font></p>
				<blockquote>
				<table border="0" width="400" cellpadding="2" cellspacing="0" border="0" cols="2">
				<tr valign="top" height="16"><td width="10"><img src="<?php echo $themesdir; ?>images/arrow.gif" width="12" height="12" border="0"></td><td width="390">
				<?php
				if(empty($id)) {
				?>
					<b>Select a Paper</b><br />
				<?php
				}
			}
			for($i=0; $i<$numresults; $i++) {
				$items = $db->assoc_array($result, $i);
				
				// show specific paper if only one, or if an id is specified
				if($numresults==1 || !empty($id)) {
					if($numresults==1 || $id==$items[id]) {
						echo "<font class=\"ArticleTitle\">Reviews on \"$items[title]\"</font></p>";
						// get reviews from database
						$review_result = $db->query("Select * from $dbtable[reviews] where paper='$items[id]' and cf='$cf' order by timestamp");
						// loop and print out each review
						for($x=0; $x<$db->num_rows($review_result); $x++) {
							$y=$x+1;
							$review_items = $db->assoc_array($review_result,$x);
							echo "<p><font class=\"instructions\"><b>Reviewer #$y</b>: ";
							if($review_items[reveal_name]=="true") {
								$review_items[reviewer] = sanitize_db_input($review_items[reviewer]);
								$reviewer_result = $db->query("select name, email from $dbtable[reviewers] where login='$review_items[reviewer]' and cf='$cf'");
								$reviewer_items = $db->assoc_array($reviewer_result);
								echo "<a href=\"mailto:$reviewer_items[email]\">$reviewer_items[name]</a>\n";
							}
							else {
								echo "[name withheld]";
							}
							echo "</font><br />
			Date submitted: ".date("F j, Y g:i A", timestamp2php($review_items[timestamp]))."</p>
								<p><b>a) Comments</b><br />
								<blockquote>
								".nl2br($review_items[comments])."
								</blockquote></p>
								<p><b>b) Recommendation</b><br />
								<blockquote>
								".nl2br($review_items[recommendation])."
								</blockquote></p>";
						}
						if($id && $numresults > 1) {
							?>
							<p><b><a href="<?php echo print_url("reviews.php?action=view"); ?>">Back to Reviews</a></b></p>
							<?php
						}
					}
				}
				// else show list of papers
				else {
					echo "<a href=\"".print_url("reviews.php?action=view&id=$items[id]")."\">$items[title]</a><br />";
				}
			}
			if($numresults>1) {
				?>
				</td></tr>
				</table>
				</blockquote>
				<?php
			}
		}
		?>
		
		<table border="0" width="600" cellpadding="2" cellspacing="0">
		<tr valign="middle" height="16"><td width="10"><img src="<?php echo $themesdir; ?>images/arrow.gif" width="12" height="12" border="0"></td><td width="590"><b><a href="<?php echo print_url("reviews.php?action=logout"); ?>">Log Out</a></b></td></tr>
		</table>
		
		<?php
	}
	
}
	
// else display login form
else if($action=="submit" || $action=="view") {

	// print out an error message if login failed
	if($errormsg) {
		echo "<p class=\"instructions\"><b>".sanitize_output($errormsg)."</b></p>";
	}

	?>
	
	<p><b>Access restricted to <?php
	if($action=="submit") {
		echo "reviewers";
	}
	else {
		echo "presenters";
	}
	?>. Please login.</b></p>
	<p><form action="<?php echo print_url("reviews.php"); ?>" method="post">
	<input type="hidden" name="login_table" value="<?php
	if($action=="submit") {
		echo $dbtable[reviewers];
	}
	else {
		echo $dbtable[papers];
	}
	?>">
	<input type="hidden" name="login" value="1">
	Username: <input type="text" name="username"><br />
	Password: <input type="password" name="password"><br />
	<input type="checkbox" name="save" value="1"> Save username and password in cookie for one month<br />
	<input type="submit" value="Login" class="button"> <input type="reset" class="button">
	</form></p>
	<script type="text/javascript">
	document.forms[0].username.focus();
	</script>
	
	<?php
	if($action == "submit") {
	?>
	<p><b><a href="<?php echo print_url("forgotpw.php?type=reviewer"); ?>">Forgot Password?</a></b></p>
	<?php
	}
}

// else show options
else {
	// check if this conference is using an online peer review
	if($conference_items[peer_review]=="online") {
	
	?>
	
	<blockquote>
	<table border="0" width="400" cellpadding="2" cellspacing="0" border="0" cols="2">
	<tr valign="top" height="16"><td width="10"><img src="<?php echo $themesdir; ?>images/arrow.gif" width="12" height="12" border="0"></td><td width="390">
<b>For Reviewers</b>:<br />
<b><a href="<?php echo print_url("reviews.php?action=submit"); ?>">Submit a Review</a></b></td></tr>
	<tr valign="top" height="16"><td width="10"><img src="<?php echo $themesdir; ?>images/arrow.gif" width="12" height="12" border="0"></td><td width="390">
<b>For Authors</b>:<br />
<b><a href="<?php echo print_url("reviews.php?action=view"); ?>">View Reviews on Your Proposal</a></b></td></tr>
	</table>
	</blockquote>
	
	
	<?php
	}
	else {
	?>
	<p>This conference is not using an online peer review.</p>
	<?php
	}

}

?>

   </td>
</tr>
<tr><td>&nbsp;</td></tr>

<?php

// include the html footer file
include("include/footer.inc.php");

?>
