<?php

// Research Support Tool v1.0
// (c) The Public Knowledge Project 2002
// http://www.pkp.ubc.ca
//
// This file is part of Research Support Tool.
// 
// Research Support Tool is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// Research Support Tool is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with Research Support Tool; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// RST configuration and functions for PKP's Open Conference Systems


// include necessary files
include_once("include/db.inc.php");
include_once("include/common.inc.php");

// the RST being used
function rst_type($id = 0) {
	global $conference_items;
	return $conference_items[rst];
}


// return true if item has supplementary items, false otherwise
function rst_has_supp($id) {
	return false;
}


// display RST url (add any extra GET paramters to the URL here)
// if $add_base is true, an absolute URL must be returned
function rst_print_url($url, $add_base = false) {
	if($add_base) {
		$url = $GLOBALS[baseurl].$url;
	}
	return print_url($url);
}


// returns an item's metadata
function rst_get_metadata($id) {
	global $db, $dbtable, $cf, $conference_items, $baseurl;
	
	$result = $db->query("SELECT * FROM $dbtable[papers] WHERE id='$id' AND cf='$cf' AND accepted='true'");
	
	if($db->num_rows($result) == 0) {
		return false;
	}
	
	$row = $db->assoc_array($result);
	
	// include default DC metadata
	include("include/defaults.inc.php");
	
	if(empty($row[paper])) {
		// for submissions without full-text
		$def_type = "Conference Abstract";
	}
	
	// this article's metadata
	// (note: creator, author, subject, and type must be arrays)
	$metadata = array(
		"id" => $row[id],
		"title" => $row[title],
		"creator" => array(),
		"author" => array($row[surname] . ", " . $row[first_name]),
		"contact_email" => $row[email],
		"subject" => array($row[discipline], $row[topic]),
		"description" => $row[abstract],
		"publisher" => $def_publisher,
		"contributor" => array($row[sponsor], $def_contributor),
		"date" => $def_date,
		"type" => array($row[relation] . " " . $def_type, $row[approach]),
		"format" => $row[format],
		"identifier" => $baseurl . "viewrecord.php?id=$row[id]",
		"source" => $def_source,
		"language" => $row[language],
		"relation" => "",
		"coverage" => $row[coverage],
		"rights" => $def_rights,
		"url" => $baseurl . print_url("viewabstract.php?id=$row[id]")
	);
	
	// get authors
	$author = $row[surname] . ", " . $row[first_name];
	if(!empty($row[affiliation])) {
		$author .= "; $row[affiliation]";
	}
	array_push($metadata[creator], $author);
	
	if(!empty($row[add_surnames])) {
		$surnames = explode("\n", $row[add_surnames]);
		$first_names = explode("\n", $row[add_first_names]);
		$affiliations = explode("\n", $row[add_affiliations]);
		for($i=0, $num_authors=count($surnames); $i<$num_authors; $i++) {
			if(!empty($surnames[$i])) {
				$author = $surnames[$i] . ", " . $first_names[$i];
				array_push($metadata[author], $author);
				if(!empty($affiliations[$i])) {
					$author .= "; $affiliations[$i]";
					array_push($metadata[creator], $author);		
				}	
			}
		}
	}
	
	return $metadata;
}


// header for the RST page
function rst_header() {
	global $conference_items;
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html>
<head>	
<title><?php echo $conference_items[name]; ?>: Research Support Tool</title>
<link rel="stylesheet" href="themes/<?php echo $conference_items[theme] ?>/style.css" type="text/css" />
<link rel="stylesheet" href="rst/rst.css" type="text/css" />
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
</head>
<body bgcolor="#DEDEDE">
<table width="100%" border="0" cellpadding="6" cellspacing="0">
<tr bgcolor="#880000"><td bgcolor="#880000"><span class="title" style="font-weight:bold; color:#FFF">Research Support Tool</span></td><td bgcolor="#880000" align="right"><a href="javascript:window.close()" style="font-weight:bold; font-size:10px; color:#FFF">Close Window</a></td></tr>
<tr><td colspan="2" bgcolor="#FFFFFF">
<?php
}


// footer for the RST page
function rst_footer() {
?>
</td></tr>
<tr><td colspan="2" bgcolor="#880000" align="right"><a href="javascript:window.close()" style="font-weight:bold; font-size:10px; color:#FFF">Close Window</a></td></tr>
</table>
<br />
<div align="center" style="font-size:9px">The Research Support Tool was developed by <a href="http://www.pkp.ubc.ca/">The Public Knowledge Project</a></div>
</html>
<?php
}


// return link to page to add a comment to this article (or false, if not supported)
function rst_comment_link($id) {
	global $conference_items;
	if($conference_items[allow_comments]=="true") {
		return print_url("addcomment.php?id=$id");
	} else {
		return false;
	}
}


// return link to printer friendly version of an article (or false, if none is available)
function rst_printer_link($id) {
	return print_url("viewpaper.php?id=$id&print=1");
}


// view author bios
function rst_author_bio($metadata) {
	global $db, $dbtable, $cf;
	
	// get list of authors for this paper
	$result = $db->query("SELECT first_name, surname, affiliation, email, url, add_first_names, add_surnames, add_affiliations, add_emails, add_urls, bio FROM $dbtable[papers] WHERE id='$metadata[id]' AND cf='$cf' AND accepted='true'");

	if($db->num_rows($result) == 0) {
		return false;
	}
	
	$row = $db->assoc_array($result);
	$bio = explode("\n<!-- BEGIN NEW BIO -->\n", $row[bio]);
	?>

	<span class="rsttitle">About the Author<?php (empty($row[add_surnames]) ? "" : "s") ?></span><br /><br />
	<span class="rstsubtitle"><a href="mailto:<?php echo $row[email] ?>"><?php echo $row[first_name] . " " . $row[surname] ?></a></span><br />
	<b><?php echo $row[affiliation] ?></b><br />
	<?php
	if(!empty($row[url])) { echo "<a href=\"$row[url]\">$row[url]</a><br />"; }
	?>
	<br />
	<?php
	if(!empty($bio[0])) { 
		echo nl2br($bio[0]) . "<br /><br />\n";
	}
	
	if(!empty($row[add_surnames])) {
		$surnames = explode("\n", $row[add_surnames]);
		$first_names = explode("\n", $row[add_first_names]);
		$affiliations = explode("\n", $row[add_affiliations]);
		$emails = explode("\n", $row[add_emails]);
		$urls = explode("\n", $row[add_urls]);
		for($i=0, $num_authors=count($surnames); $i<$num_authors; $i++) {
			if(!empty($surnames[$i])) {
				$author = $surnames[$i] . ", " . $first_names[$i];
				?>
				<span class="rstsubtitle"><a href="mailto:<?php echo $emails[$i] ?>"><?php echo $first_names[$i] . " " . $surnames[$i] ?></a></span><br />
				<b><?php echo $affiliations[$i] ?></b><br />
				<?php
				if(!empty($urls[$i])) { echo "<a href=\"$urls[$i]\">$urls[$i]</a><br />"; }
				?>
				<br />
				<?php
				if(!empty($bio[$i+1])) { 
					echo nl2br($bio[$i+1]) . "<br /><br />\n";
				}
			}
		}
	}
}


// return array of RST colors
function rst_colors() {
	return array(
		"bgcolor" => "#880000",
		"bordercolor" => "#000000",
		"textcolor" => "#FFFFFF"
	);
}


// Display citation
function rst_display_citation($id) {
	global $db, $dbtable, $cf, $conference_items, $items, $baseurl;
	
	$result = $db->query("SELECT * FROM $dbtable[papers] WHERE id='$id' AND cf='$cf' AND accepted='true'");
	
	if($db->num_rows($result) == 0) {
		return false;
	}
	
	$items = $db->assoc_array($result);
	
	include("include/citation.inc.php");
}
