<?php

// $Id: functions.inc.php,v 1.106 2003/02/03 16:22:20 eunice Exp $

// Research Support Tool v1.0
// (c) The Public Knowledge Project 2002
// http://www.pkp.ubc.ca
//
// This file is part of Research Support Tool.
// 
// Research Support Tool is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// Open Conference Systems is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with Research Support Tool; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
// 
// defines global functions used by all RSTs


// return a list of all available RST modules
// $rst_path = the path to the RST modules directory
function rst_list_modules($rst_path = "rst/modules") {
	$rsts = array();
	$return_rsts = array("Generic" => "Generic");
	$rst_dir = opendir($rst_path);
	while(false !== ($file = readdir($rst_dir))) {
		if($file != "." && $file != ".." && $file != "Generic" && is_dir("$rst_path/$file") && @file_exists("$rst_path/$file/rst.inc.php")) {
			array_push($rsts, $file);
		}
	}
	
	closedir($rst_dir);
	
	sort($rsts);
	
	foreach($rsts as $rst) {
		$return_rsts[$rst] = str_replace("_", " ", $rst);
	}
	
	return $return_rsts;
}

// creates a simple single button search form, posting to the passed URL
function rst_simple_search_form($url, $query, $search = "Search for: ", $submit = "Search", $message = "", $method = "post") {
	?>
	<form action="<?php echo sanitize_output($url); ?>" method="<?php echo sanitize_output($method); ?>">
	<input type="hidden" name="option" value="Submit" class="button">
	<?php echo sanitize_output($search); ?><input type="text" name="<?php echo sanitize_output($query); ?>"> <input type="submit" value="<?php echo sanitize_output($submit); ?>" class="button">
	</form>
	<br />
	<?php
	if($message) { ?><span class="SecondaryText"><?php echo sanitize_output($message); ?></span> <?php }
}


// takes an array like array("name" => array("url", "search_url"))
// and a message for any extra instructions, and prints a
// generic search form with buttons for each engine
function rst_search_form_buttons($search_engines, $message = "") {
	global $metadata, $topics, $rstname;
		
	?>
<script language="JavaScript">
function goToUrl(url) {
	var text1=document.rst.term1.value;
	var text2=document.rst.term2.value;
	if (text2 == '' && text1 != '')
	{ window.open(url+text1); }
	else if (text1 == '' && text2 != '')
	{ window.open(url+text2); }
	else
	{ window.open(url+text1+'+AND+'+text2); }
	
}
</script>
   <form name="rst" method="post">
	<span class="rsttitle"><?php echo $rstname;?></span><br /><br />
	<span class="rstMainText"><?php echo $metadata[title]; ?></span><br /><br />
	<table width="100%" border="0">
		<tr> 
		  <td width="6%">&nbsp;</td>
		  <td width="5%"><span class="rstMainText">&nbsp;</span></td>
		  <td width="89%"><span class="rstMainText">
			Term 1: 
			<input type="text" name="term1" value="<?php echo sanitize_output($topics[0]);?>"> &nbsp; and
			<br />
			Term 2: 
			<input type="text" name="term2" value="<?php echo sanitize_output($topics[1]);?>">
			<br />
			<br /></span>
		  </td>
		</tr>
		<tr><td colspan="3"><span class="SecondaryText">These search terms, selected by the author(s), can be changed by the reader. To learn more about the resource searched, click on its name. These resources have been selected because of their relevance and their open (free) access to all or part of their contents.</span><hr size="1"><?php if($message) { ?><br /><span class="SecondaryText"><?php echo sanitize_output($message); ?></span><br /><?php } ?><br /></td></tr>

	<?php
	
	$i=1;
	
	foreach ($search_engines as $site => $urls) {
		?>
		<tr> 
		  <td width="6%"> 
			<input type="button" value="Search" onClick="goToUrl('<?php echo sanitize_output($urls[1]); ?>')" class="button">
		  </td>
		  <td width="5%"><span class="rstMainText"><?php echo $i; ?>.</span></td>
		  <td width="89%"><a class="rstMainTextLink" href="<?php echo sanitize_output($urls[0]); ?>"><?php echo sanitize_output($site); ?></a></td>
    	</tr>
		<?php
		$i++;
	}
	
	?>
	</table>
	</form>
	<?php
}


// display a metadata table
function show_meta($metadata) {
	?>
	<br /><span class="MetaText"><b>Metadata Information</b>&nbsp;&nbsp;<a href="#meta"><img src="admin/images/blueinfo.gif" border=0></a></span>
	<br /><?php echo $metadata[title]; ?><br /><br />
	<table border="0" cellpadding="5" cellspacing="1" bgcolor="#000000">
	<tr>
	<td width="10%" align="center" bgcolor="#FFFFFF" nowrap><span class="MetaText"><b>Dublin Core</b></span></td>
	<td nowrap align="center" bgcolor="#FFFFFF"><span class="MetaText"><b>PKP Metadata Items</b></span></td>
	<td align="center" bgcolor="#FFFFFF"><span class="MetaText"><b>Metadata for this Document</b></span></td>
	</tr>
	<?php
	
	// set dublin core items
	$dc_items = array(
		array("1. Title", "Title of document", $metadata[title])
	);
	
	// add authors
	foreach($metadata[creator] as $author) {
		array_push($dc_items,
			array("2. Creator", "Author's name, affiliation, email", $author)
		);
	}

	// add rest of items
	array_push($dc_items,
		array("3. Subject", "Discipline(s)", $metadata[subject][0]),
		array("3. Subject", "Subject(s)", $metadata[subject][1]),
		array("4. Description", "Abstract", $metadata[description]),
		array("5. Publisher", "Organizing agency, location", $metadata[publisher]),
		array("6. Contributor", "Sponsor(s)", join("; ", array_merge(array(), $metadata[contributor]))),
		array("7. Date", "(YYYY-MM-DD)", $metadata[date]),
		array("8. Type", "Status &amp; genre", $metadata[type][0]),
		array("8. Type", "Method", $metadata[type][1]),
		array("9. Format", "HTML or PDF", $metadata[format]),
		array("10. Identifier", "Universal Resource Indicator", "<a href=\"$metadata[url]\">$metadata[identifier]</a>"),
		array("11. Source", "Conference/journal title; vol., (no.) ", $metadata[source]),
		array("12. Language", "English=en", $metadata[language]),
		array("13. Relation", "Supp. Files", join("; ", array_merge(array(), $metadata[relation]))),
		array("14. Coverage", "Geo-spatial location, chronological period, research sample (gender, age, etc.)", join("; ", array_merge(array(), $metadata[coverage]))),
		array("15. Rights", "Copyright and permissions", $metadata[rights])
	);
	

	// print out dublin core meta fields
	for($i=0; $i<count($dc_items); $i++) {
		if($i % 2 == 0) { $bg = "EEEEEE"; }
		else { $bg = "FFFFFF"; }
		echo "
			<tr valign=\"top\">
			<td bgcolor=\"#$bg\" nowrap><span class=\"MetaText\">".$dc_items[$i][0]."</span></td>
			<td bgcolor=\"#$bg\"><span class=\"MetaText\">".$dc_items[$i][1]."</span></td>
			<td bgcolor=\"#$bg\"><span class=\"MetaText\">".nl2br($dc_items[$i][2])."</span></td>
			</tr>";
	}
	
	?>
	</table>
<a name = "meta"></a>
<br /><span class="rstMainText">Metadata is used to index research and support related search functions. <a href="http://www.dublincore.org" class="rstMainTextLink">The Dublin Core Metadata Initiative</a> represents an emerging standard for indexing the source and content of documents. These standards have been employed by the <a href="http://www.openarchives.org" class="rstMainTextLink">Open Archives Initiative</a> to enable "harvesting" and searching of document metadata across multiple research databases. In this case, the metadata tags have been further defined to improve the indexing of scholarly papers, articles and theses within the <a href="http://pkp.ubc.ca" class="rstMainTextLink">Public Knowledge Project</a>.</span>

	<?php

}

function show_suppmeta($metadata, $i) {
        ?>
        <br /><span class="MetaText"><b>Supplementary File Metadata Information</b>&nbsp;&nbsp;<a href="#meta"><img src="admin/images/blueinfo.gif" border=0></a></span>
        <br /><?php echo $metadata[supp_title][$i]; ?><br /><br />
        <table border="0" cellpadding="5" cellspacing="1" bgcolor="#000000">
        <tr>
        <td width="10%" align="center" bgcolor="#FFFFFF" nowrap><span class="MetaText"><b>Dublin Core</b></span></td>
        <td nowrap align="center" bgcolor="#FFFFFF"><span class="MetaText"><b>PKP Metadata Items</b></span></td>
        <td align="center" bgcolor="#FFFFFF"><span class="MetaText"><b>Metadata for this Document</b></span></td>
        </tr>
        <?php

        // set dublin core items
        $dc_items = array(
                array("1. Title", "Title of document", $metadata[supp_title][$i])
        );

        // add rest of items
        array_push($dc_items,
                array("2. Creator", "Author's name, affiliation, email", $metadata[supp_creator][$i]),
                array("3. Subject", "Subject(s)", $metadata[supp_subject][$i]),
                array("4. Description", "Abstract", $metadata[supp_description][$i]),
                array("5. Publisher", "Organizing agency, location", $metadata[supp_publisher][$i]),
                array("6. Contributor", "Sponsor(s)", $metadata[supp_sponsor][$i]),
                array("7. Date", "Create Date (YYYY-MM-DD)", date("Y-m-d", strtotime($metadata[supp_createdate][$i]))),
                array("9. Format", "File Format", $metadata[supp_type][$i]."<br />".$metadata[supp_typeother][$i]),
		array("10. Identifier", "Universal Resource Indicator", "<a href=\"".$metadata[supp_url][$i]."\">".$metadata[supp_url][$i]."</a>" ),
                array("11. Source", "File Source", $metadata[supp_source][$i]),
                array("12. Language", "English=en", $metadata[supp_language][$i]),
		array("13. Relation", "Associated files", "Supplementary file for <a href=\"$metadata[url]\">".$metadata[title]."</a>")
                 );


        // print out dublin core meta fields
        for($i=0; $i<count($dc_items); $i++) {
                if($i % 2 == 0) { $bg = "EEEEEE"; }
                else { $bg = "FFFFFF"; }
                echo "
                        <tr valign=\"top\">
                        <td bgcolor=\"#$bg\" nowrap><span class=\"MetaText\">".$dc_items[$i][0]."</span></td>
                        <td bgcolor=\"#$bg\"><span class=\"MetaText\">".$dc_items[$i][1]."</span></td>
                        <td bgcolor=\"#$bg\"><span class=\"MetaText\">".nl2br($dc_items[$i][2])."</span></td>
                        </tr>";
        }

        ?>
        </table>
     <a name="meta"></a><br /><span class="rstMainText">Metadata is used to index research and support related search functions. <a href="http://www.dublincore.org" class="rstMainTextLink">The Dublin Core Metadata Initiative</a> represents an emerging standard for indexing the source and content of documents. These standards have been employed by the <a href="http://www.openarchives.org" class="rstMainTextLink">Open Archives Initiative</a> to enable "harvesting" and searching of document metadata across multiple research databases. In this case, the metadata tags have been further defined to improve the indexing of scholarly papers, articles and theses within the <a href="http://pkp.ubc.ca" class="rstMainTextLink">Public Knowledge Project</a>.</span>

        <?php

}

function show_suppfiles($metadata) {
	?>
	<br /><span class="MetaText"><b>Supplementary files </b></span>
	<br /><?php echo $metadata[title]; ?><br /><br />
	<?php
	$num = count($metadata[title]);
	
	// print out dublin core meta fields
	for($i=0; $i<$num; $i++) {
		$icount = $i+1;
		echo $icount.".&nbsp;&nbsp;Title: <a href=\"".$metadata[supp_url][$i]."\">".
		$metadata[supp_title][$i].
		"</a><br />&nbsp;&nbsp;&nbsp;Type: <span class=\"MetaText\">".
		$metadata[supp_type][$i].
		"</span> | <a href=\"rst.php?id=$metadata[id]&amp;op=show_suppmeta&amp;i=$i\" target=\"_blank\" class=\"rstlink\"><span class=\"MetaText\">Metadata</span></a><br />";
	}
}




function display_cite($metadata, $vars) {
	if($vars[cite] == "endnote") { header("Content-Type: application/x-endnote-refer"); }
	else if($vars[cite] == "procite" || $vars[cite] == "refman") { header("Content-Type: application/x-Research-Info-Systems"); }
	
	// year format
	$year = date("Y",strtotime($metadata[date]));
	
	// show procite file
	if($vars[cite]=="procite") {
		echo "
	TY  - JOUR\n";
	foreach($metadata[author] AS $author) {
		echo "	AU  - $author\n";
	}
echo "	PY  - $year
	TI  - $metadata[title]
	JF  - $metadata[source]
	Y2  - $year
	KW  - {$metadata[subject][1]}
	N2  - $metadata[description]
	UR  - $metadata[url]
	";
		exit;
	}
	
	// show endnote file
	if($vars[cite] == "endnote") {
		echo "\n";
	foreach($metadata[author] AS $author) {
		echo "	%A $author\n";
	}
echo "	%D $year
	%T $metadata[title]
	%8 $year
	%9 {$metadata[subject][0]}
	%! $metadata[title]
	%K {$metadata[subject][0]}
	%X $metadata[description]
	%U $metadata[url]
	";
		exit;
	}
	
	// show reference manager file
	if($vars[cite] == "refman") {
		echo "
	TY  - JOUR\n";
	foreach($metadata[author] AS $author) {
		echo "	AU  - $author\n";
	}
echo "	PY  - $year
	TI  - $metadata[title]
	JF  - $metadata[source]
	Y2  - $year
	KW  - {$metadata[subject][0]}
	N2  - $metadata[description]
	UR  - $metadata[url]
	";
		exit;
	}
	
	?>
	<span class="ArticleAbstract">
	<?php
	// display citation
	rst_display_citation($metadata[id]);
	?>
	</span><p>&nbsp;</p>
	<span style="color:#840000"><b>Download Directly to Citation Manager</b></span>
	<br /><span class="rstrstMainText">Download the citation below by selecting one of the formats on the left (<a class="rstrstMainTextLink" href="#help"><b>HELP</b></a> is below):</span>
	<br /><br />
	<table width="100%" border="0" cellspacing="0" cellpadding="2">
	  <tr> 
		<td colspan="3" bgcolor="#CCCCCC"><img src="rst/images/spacer.gif" width="1" height="5" border="0"></td>
	  </tr>
	  <tr> 
		<td width="18" valign="top"><img src="rst/images/arrow.gif" width="12" height="12" border="0" hspace="0" vspace="0"></td>
		<td width="120"><a class="rstrstMainTextLink" href="<?php echo rst_print_url("rst.php?id=$metadata[id]&amp;op=display_cite&amp;cite=endnote&amp;no_html=1"); ?>"><b>EndNote</b></a><br /><span class="rstrstMainText">- EndNote format<br />(Mac &amp; Windows)</span></td>
		<td rowspan="5" bgcolor="#EEEEEE" valign="top"><span class="ArticleAbstract">
		<?php
		// display citation
		rst_display_citation($metadata[id]);
		?>
		</span></td>
	  </tr>
	  <tr>
		<td width="18"><img src="rst/images/spacer.gif" width="1" height="1" border="0"></td>
		<td width="120" bgcolor="#EEEEEE">&nbsp;</td>
	  </tr>
	  <tr> 
		<td width="18" valign="top"><img src="rst/images/arrow.gif" width="12" height="12" border="0" hspace="0" vspace="0"></td>
		<td width="120"><a class="rstrstMainTextLink" href="<?php echo rst_print_url("rst.php?id=$metadata[id]&amp;op=display_cite&amp;cite=refman&amp;no_html=1"); ?>"><b>Reference<br />Manager</b></a><span style="color:#A70716">*</span><br /><span class="rstrstMainText">- Ris format<br />(Win only)</span></td>
	  </tr>
	  <tr>
		<td width="18"><img src="rst/images/spacer.gif" width="1" height="1" border="0"></td>
		<td width="120" bgcolor="#EEEEEE">&nbsp;</td>
	  </tr>
	  <tr> 
		<td width="18" valign="top"><img src="rst/images/arrow.gif" width="12" height="12" border="0" hspace="0" vspace="0"></td>
		<td width="120"><a class="rstrstMainTextLink" href="<?php echo rst_print_url("rst.php?id=$metadata[id]&amp;op=display_cite&amp;cite=procite&amp;no_html=1"); ?>"><b>ProCite</b></a><span style="color:#A70716">*</span><br /><span class="rstrstMainText">- Ris format<br />(Mac &amp; Windows)</span></td>
	  </tr>
	  <tr> 
		<td colspan="3" bgcolor="#CCCCCC"><img src="rst/images/spacer.gif" width="1" height="5" border="0"></td>
	  </tr>
	</table>
	
	<p>
	<span style="color:#A70716">*</span>
	<span class="rstrstMainText">WINDOWS ONLY: To automatically import into Reference Manager
	or ProCite, make sure to follow the instructions <a class="rstrstMainTextLink" href="#refmanprocite">below</a>.</span>
	<a name="help"></a>
		<p>
		<hr noshade>
		<p>
		<span style="color:#A70716"><b>Help with downloading citations using Netscape:</b></span><br />
		<span class="rstrstMainText">
		<a class="rstrstMainTextLink" href="#all">All formats</a>&nbsp;&nbsp;||&nbsp;&nbsp;
		<a class="rstrstMainTextLink" href="#endnote">EndNote</a>&nbsp;&nbsp;||&nbsp;&nbsp;
		<a class="rstrstMainTextLink" href="#refmanprocite">Reference Manager and ProCite</a>
		</span>
	<p>
	<a name="all"></a>
		<span class="rstrstMainText"><b>All formats:</b></span>
	<p>
	<dl>
		<dd><span class="rstrstMainText">If you get an alert message when you click one of the above download links that begins
		<b>You have started to download the file "1710" of type "x-endnote-refer"</b>
		-or-
		<b>... of type "x-Research-Info_systems"</b>,
		-or-
		<b>... of type "octet-stream"</b>,
		click the  'Cancel' button and:</span>
		<p><span class="rstrstMainText">
			a. Go to the "Edit/Preferences..." menu and click on "Navigator/Applications"
			<p>
			b. Scroll through the list looking for:
			<p>
			<table width="90%" cellpadding="2" cellspacing="0" border="1" nowrap>
			<tr>
				<th width="30%" bgcolor="#E1E1E1"><span size="-1" face="arial,helvetica">EndNote</span></th>
				<th width="35%" bgcolor="#E1E1E1"><span size="-1" face="arial,helvetica">Reference Manager and ProCite</span></th>
				<th valign="top" width="35%" bgcolor="#E1E1E1" align="center"><span size="-1" face="arial,helvetica">Generic</span></th>
			</tr><tr>
				<td valign="top" width="30%"><span size="-1" face="arial,helvetica">'EndNote' or<br />'application/x-endnote-refer'</span></td>
				<td valign="top" width="35%"><span size="-1" face="arial,helvetica">'application/x-Research-Info-Systems'</span></td>
				<td valign="top" width="35%"><span size="-1" face="arial,helvetica">'Binary Executable File' or<br />'application/octet-stream'</span></td>
			</tr>
			</table>
			<p> 
			If you find it:
			<ul>
				<li>Click on it and select 'Edit'.</li>
				<li>Select the 'Save to disk' radio butt on</li>
			</ul>
			Otherwise, continue to the next step:
			<p>
			<li>If you didn't find an entry in the list from the previous step:<br />
			Still in the 'Applications' section, select 'New' and enter the following values:</li>
			<p>
			<table width="90%" cellpadding="2" cellspacing="0" border="1" nowrap>
			<tr>
				<th><span style="color:#ffffff">.</span></th>
				<th width="20%" bgcolor="#E1E1E1"><span size="-1" face="arial,helvetica">EndNote</span></th>
				<th width="20%" bgcolor="#E1E1E1"><span size="-1" face="arial,helvetica">Reference Manager and ProCite</span></th>
				  <th valign="top" width="20%" bgcolor="#E1E1E1" align="center"><span size="-1" face="arial,helvetica">Generic</span></th>
			</tr><tr>
				<th width="20%" bgcolor="#E1E1E1"><span size="-1" face="arial,helvetica">Description</span></th>
				<td valign="top" width="20%"><span size="-1" face="arial,helvetica">EndNote Citation</span></td>
				<td valign="top" width="20%"><span size="-1" face="arial,helvetica">Reference Manager Citation (or) ProCite Citation</span></td>
				<td valign="top" width="20%"><span size="-1" face="arial,helvetica">Binary Executable File</span></td>
			</tr><tr>
				<th width="20%" bgcolor="#E1E1E1"><span size="-1" face="arial,helvetica">MIME Type</span></th>
				<td valign="top" width="20%"><span size="-1" face="arial,helvetica">application/x-endnote-refer</span></td>
				<td valign="top" width="20%"><span size="-1" face="arial,helvetica">application/x-Research-Info-Systems</span></td>
				<td valign="top" width="20%"><span size="-1" face="arial,helvetica">application/octet-stream</span></td>
			</tr><tr>
				<th width="20%" bgcolor="#E1E1E1"><span size="-1" face="arial,helvetica">Suffixes/File extension</span></th>
				<td valign="top" width="20%"><span size="-1" face="arial,helvetica">enw</span></td>
				<td valign="top" width="20%"><span size="-1" face="arial,helvetica">RIS</span></td>
				<td valign="top" width="20%"><span size="-1" face="arial,helvetica">exe</span></td>
			</tr><tr>
				<th width="20%" bgcolor="#E1E1E1"><span size="-1" face="arial,helvetica">File type<br />(Mac only)</span></th>
				<td valign="top" width="20%"><span size="-1" face="arial,helvetica">TEXT</span></td>
				<td valign="top" width="20%"><span size="-1" face="arial,helvetica">TEXT</span></td>
				<td valign="top" width="20%"><span size="-1" face="arial,helvetica">&nbsp;</span></td>
			</tr><tr>
				<th width="20%" bgcolor="#E1E1E1"><span size="-1" face="arial,helvetica">Tell Netscape what to<br />do with the citation</span></th>
				<td valign="top" width="20%"><span size="-1" face="arial,helvetica">Select the '<strong>Application</strong>' radio button or the 'Browse' button and browse to your copy of EndNote</span></td>
				<td valign="top" width="20%"><span size="-1" face="arial,helvetica">MAC ONLY:<br />Select the '<strong>Application</strong>' radio button and browse to your copy of Reference Manager or ProCite</span></td>
				<td valign="top" width="20%"><span size="-1" face="arial,helvetica">Select the '<strong>Save to disk</strong>' radio button</span></td>
			</tr>
			</table>
	
	</dl>
	<a name="endnote"></a>
	<p>
	<b><span face="arial,helvetica">&nbsp;EndNote Only:</span></b>
	<p>
	<ol>
		<li><span class="rstrstMainText">Make sure you have <a href="<http://www.endnote.com/support/enupdates.asp>">at least version 3.1.2 of EndNote</a>.</span></li>
		<p>
		<li><span class="rstrstMainText">If you are able to download the file and EndNote launches automatically,
		but the citation doesn't get imported, reinstall the <a href="<http://www.endnote.com/support/enupdates.asp>">updater</a>.</span></li>
		<p>
		<li><span class="rstrstMainText">MAC ONLY: If you are able to download the file and EndNote launches automatically, but you get the error message "This file is incompatible with this version of EndNote",
		make sure that the 'file type' (in the General instructions above) is set to TEXT.</span></li>
		<p>
		<li><span class="rstrstMainText">If you are having other problems using EndNote, try reinstalling
		the <a href="<http://www.endnote.com/support/enupdates.asp>">updater</a>.</span></li>
	</ol>
	<a name="refmanprocite"></a>
	<p>
	<b><span class="rstrstMainText">&nbsp;Reference Manager and ProCite Only:</span></b>
	<p>
	<ol>
		<li><span class="rstrstMainText">WINDOWS ONLY:
		Is the citation opening Reference Manager or ProCite but not
		importing the citation? Make sure that you have installed <a href="http://www.risinc.com/webcap/riswinrm.html">Risweb</a>.
		Follow the instructions and then restart your computer.
		</span></li>
		<p>
		<li><span class="rstrstMainText">PROCITE FOR MAC ONLY:
		If you get the error 'no records were found' when you try to transfer the citation into your database,
		make sure that you have selected the 'Ris' file format option.
		</span></li>
	</ol>
	<?php

}


// show define terms description
function define_terms() {
	?>
	Double click on any word that you would like to see explained. The word will be fed into the <a href="http://www.xrefer.com/" class="rstMainTextLink">Xrefer</a> website's search engine which selects definitions from "encyclopedias, dictionaries, thesauri &amp; books of quotations from the world's leading publishers."
	<?php
}


// send an email to a colleague
function email_colleague($metadata, $vars) {	
	$subject = $metadata[title];

	$body = "A colleague ";
	if($vars[to]) { $vars[to] = sanitize_output($vars[to]); }
	if($vars[from]) { $body .= "($vars[from]) "; }
	$body .= "has invited you to view the paper \"$metadata[title]\" by {$metadata[author][0]} at the $conference_items[name] web site. You can view the paper at the following URL: $metadata[url]\n\n";
	
	// check arguments
	if($send && (empty($vars[to]) || empty($vars[from]))) {
		$err = "Submission incomplete. Please make sure you have entered both you and your colleague's email addresses.";
	} else if($send && empty($vars[to])) {
		$err = "Your colleague's email address is invalid.";
	} else if($send && !check_email($vars[from])) {
		$err = "Your email address is invalid.";
	}

	
	if($send && !$err) {
		// send email	
		if($vars[message]) { $body .= "-------------------------\n\n".sanitize_output($vars[message])."\n"; }
		$body = str_replace("&quot;", '"', $body);
		
		mail("$vars[to]", "$subject", $body, "From: $vars[from]", "-f$conference_items[contact_email]");
		
		?>
		<p>Email sent successfully to <b><?php echo $vars[to]; ?></b>.</p>
		<?php
	} else {
		// show form
		?>
		<form action="<?php echo rst_print_url("rst.php?id=$id&amp;op=$op"); ?>" method="post">
		<p>Use this form to send an email to your colleague about this paper.</p>
		
		<?php if($err) { echo "<p><span class=\"instructions\">$err</span></p>"; } ?>
		
		<p><b>Your Colleague's Email Address</b>:<br />
		<input type="text" name="to" size="40" value="<?php echo sanitize_output($vars[to]); ?>"><br />
		<span class="instructions">Enter one or more of your colleagues' email addresses here, separated by commas.</span></p>
		
		<p><b>Your Email Address</b>:<br />
		<input type="text" name="from" size="40" value="<?php echo sanitize_output($vars[from]); ?>"></p>
		
		<p><b>Subject</b>:<br />
		<?php echo $subject; ?></p>
		
		<p><b>Message Body</b>:<br />
		<?php echo sanitize_output($body); ?></p>
		
		<p><b>Include a Message</b>:<br />
		<textarea name="message" cols="40" rows="8"><?php echo sanitize_output($vars[message]); ?></textarea></p>
		
		<p><input type="submit" name="send" value="Send Email" class="button"> <input type="button" value="Cancel" onclick="top.close()" class="button"></p>
		</form>
		<?php
	}	
}


function about_rst() {
	global $rst;
		
	if(file_exists("rst/modules/$rst/about.inc.php")) {
		// show RST-specific about page
		include("rst/modules/$rst/about.inc.php");
	} else {
		// invalid RST, or RST about page not found
		?>
		<p>Please see <a href="http://www.pkp.ubc.ca">http://www.pkp.ubc.ca</a> for more information about the Research Support Tool.</p>
		<?php
	}
	
	?>
 	<p align="center"><a href="http://www.pkp.ubc.ca/"><img src="rst/images/pkp.gif" width="79" height="56" border="0" alt="Public Knowledge" /></a></p>
	<?php
}


function about_rst_types() {
	?>
<p><b>Status and Type of Study</b></p>

<p>Status of Item
<ol>
	<li>Peer-reviewed: The article or paper, with all author identification removed, has been submitted to two or more of the author's peers for anonymous review, prior to publication.</li>
	<li>Non-refereed: The journal editors or conference directors have accepted this article or paper without an anonymous external review.</li>
	<li>Invited: The author was invited to submit their work, which is not then sent out typically for anonymous external review.</li>
</ol></p>

<p>Type of Item
<ol>
	<li>Article: The item has been formally published, after a peer and/or editorial review, and is considered in a finished state.</li>
	<li>Conference paper: It has been presented at a scholarly conference, and is typically a draft version that may be subsequently revised and published.</li>
	<li>Working paper: It represents ideas in progress, and is still being worked on and, as such, invites discussion, assistance, and comment.</li>
</ol></p>
	<?php
}
