<?php

// Open Conference Systems 1.1
// (c) The Public Knowledge Project 2003
// http://www.pkp.ubc.ca
//
// This file is part of Open Conference Systems.
// 
// Open Conference Systems is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// Open Conference Systems is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with Open Conference Systems; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
// 
// submit.php
// 
// $Id: submit.php,v 1.4 2003/04/01 07:58:46 kevin Exp $
// 
// generates a submission form for refereed or non-refereed papers


// include necessary files
include("include/db.inc.php"); 
include("include/common.inc.php");

if(!isset($cf)) {
	header("Location: index.php");
	exit;
}


// include cookie script
include("include/cookie.inc.php");
if(!$login) { getusercookie(); }

// include validation script
include("include/validate.inc.php");


// if logging in, validate the supplied username and password and store in cookie if valid
if($login) {
	if(validate($username,$password,$dbtable[papers],"",true)) {
		setusercookie($username, $password, $save);
		
		// forward them to invited submission page if invited participant
		if(validate($username,$password,$dbtable[invited_speakers])) {
			header("Location: ".print_url("invitedsubmit.php"));
			exit;
		}
	}
	else {
		$action = "login";
	}
}


// check if logging out
if($action == "logout") {
	deleteusercookie();
	Header("Location: ".$baseurl.print_url("submit.php"));
	exit;
}


// check if user is valid
$logged_on = 0;
if(validate($username,$password,$dbtable[papers],"relation not like 'Invited%'")) {
	$logged_on = 1;
}
else if(isset($confuser)) {
	deleteusercookie();
}


// this page's title, depending if an online peer review system is being used
if($conference_items[peer_review]=="online") { 
	$title = "Refereed Abstract and Paper Submission";
}
else {
	$title = "Abstract and Paper Submission";
}


// creates a hierarchal tree to be printed out in header.php
$tree = array("Home"=>print_url("index.php"));

// specify an anchor to move to if adding or deleting an author
if($add_author || $del_author) {
	$anchor = "authors";
}

// specify an anchor to move to if adding or deleting the multiple paper information section
if($add_multiple_info || $del_multiple_info) {
	$anchor = "present_formats";
}

// specify an anchor to move to if adding an appendix
if($add_appendix) {
	$anchor = "appendices";
}


// include the html header file
include("include/header.inc.php");


// check that conference allows non-invited submissions
if($conference_items[peer_review]!="online" && $conference_items[call_for_papers]!="true") {
	echo "This conference does not allow non-invited submissions.";
	include("include/footer.inc.php");
	exit;
}


// variable notes that this a non-invited submission form
$is_noninvited = true;

if(($action=="new" || $preview || $edit || $submit || $anchor) && !$id && !$update && ($conference_items[deadline_close]=="true" && time()>=(strtotime($conference_items[abstract_deadline])+86400)) || time()>=(strtotime($conference_items[end_date])+86400)) {
	echo "<p>New submissions are no longer being accepted.</p>";
}


// include the actual submission form script if previewing, submitting, or editing a submission
else if($action=="new" || $id || $preview || $edit || $submit || $anchor) {
	include("include/submitform.inc.php"); 
}

// show options if user is logged in
else if($logged_on == 1) {
	// check if user has already submitted a paper
	$result = $db->query("select title, id, accepted from $dbtable[papers] where login='$username' and cf='$cf'");

	// change password
	if($action == "changepw") {
		unset($err);
		unset($pass_changed);
			
		// update password
		if(!empty($old_password) && !empty($new_password) && !empty($new_password2)) {
			check_referer();
			
			if(validate($username,$old_password,$dbtable[papers],"",true)) {
				// check if name is valid
				if(!check_name($new_password)) {
					$err = "New password is invalid.";
				}
				else if($new_password == $new_password2) {
					// update password for all papers this user has submitted
					$db->query("update $dbtable[papers] set password='".base64_encode($new_password)."' where login='$username' and password='".base64_encode($old_password)."' and cf='$cf'");
					?>
					<p>Your password has been changed. You will need to <a href="<?php echo print_url("submit.php?action=login"); ?>">login</a> again.</p>
					<?php
					$pass_changed = 1;
				}
				else {
					$err = "New passwords do not match.";
				}
			}
			else {
				$err = "Old password is incorrect.";
			}
		}
		
		if(!isset($pass_changed)) {
			if(isset($err)) { echo "<p>$err</p>"; }
			?>
			<form action="<?php echo print_url("submit.php?action=changepw"); ?>" method="post">
			
			<p>Use this form to change the password used to access <i>all</i> papers you have submitted. Note: passwords are case sensitive.</p>
			
			<p><b>Old Password</b>: <input type="password" name="old_password" value="<?php echo $old_password; ?>"></p>
			<p><b>New Password</b>: <input type="password" name="new_password" value="<?php echo $new_password; ?>"></p>
			<p><b>New Password Again</b>: <input type="password" name="new_password2" value="<?php echo $new_password2; ?>"></p>
			<p><font class="instructions">Passwords may contain only alphanumeric characters.</font></p>
			<p><input type="submit" value="Change Password" class="button"></p>
			</form>
			<?php
		}
	}
	
	// if not, or a new paper has been specified, show a blank submission form
	else if(($db->num_rows($result)==0) || $action=="new" || $id) {
		include("include/submitform.inc.php"); 
	}
	
	// else show list of papers user has submitted
	else {
		?>
		<blockquote>
<table border="0" width="400" cellpadding="2" cellspacing="0" border="0" cols="2">
<tr valign="middle" height="16"><td width="10"><img src="<?php echo $themesdir; ?>images/arrow.gif" width="12" height="12" border="0"></td><td width="390"><b>
		<?php

	// no longer allow new submissions if abstract deadline has passed, if applicable, or if the conference has ended
	if(($conference_items[deadline_close]=="true" && time()>=(strtotime($conference_items[abstract_deadline])+86400)) || time()>=(strtotime($conference_items[end_date])+86400)) {
		echo "New submissions are no longer being accepted";
	}
	// else show link to submit a new abstract or paper
	else {
		echo "<a href=\"".print_url("submit.php?action=new")."\">Submit a New Abstract or Paper</a>";
	}

	?>
	</b></td></tr>
			<tr valign="middle" height="16"><td width="10"><img src="<?php echo $themesdir; ?>images/arrow.gif" width="12" height="12" border="0"></td><td width="390"><b>Edit an Abstract or Paper Previously Submitted</b></td></tr>
	<?php
		// loop and print out a list of papers user has submitted
		$x=0;
		for($i=0; $i<$db->num_rows($result); $i++) {
			$items = $db->assoc_array($result,$i);
			// show accepted papers or all papers if the abstract deadline has not been passed
			if($items[accepted]=="true" || time()<(strtotime($conference_items[abstract_deadline])+86400)) {
				echo "<tr valign=\"middle\" height=\"16\"><td width=\"10\">&nbsp;</td><td width=\"390\">";
				// print link to edit if paper has not been rejected
				if($items[accepted]!="reject") {
					echo "<a href=\"".print_url("submit.php?id=$items[id]")."\">";
				}
				echo "$items[title]";
				if($items[accepted]!="reject") {
					echo "</a>";
				}
				// note as rejected, if applicable
				if($items[accepted]=="reject") {
					echo " (Sorry, this proposal has been rejected)";
				}
				echo "</td></tr>";
			}
			// just show titles of non-accepted papers if abstract deadline has been passed
			else {
				echo "<tr valign=\"middle\" height=\"16\"><td width=\"10\">&nbsp;</td><td width=\"390\">$items[title]";
				// note as rejected, if applicable
				if($items[accepted]=="reject") {
					echo " (Sorry, this proposal has been rejected)";
				}
				echo "</td></tr>\n";
				$x++;
			}
		}
		
		// print message if deadline has passed
		if($x>0) {
			?>
			<tr valign="middle" height="16"><td width="10">&nbsp;</td><td width="390" class="instructions">Unaccepted proposals may no longer be edited.</td></tr>
			<?php
		}
		
		?>
		<tr valign="middle" height="16"><td width="10"><img src="<?php echo $themesdir; ?>images/arrow.gif" width="12" height="12" border="0"></td><td width="390"><b><a href="<?php echo print_url("submit.php?action=changepw"); ?>">Change Password</a></b></td></tr>
		<tr valign="middle" height="16"><td width="10"><img src="<?php echo $themesdir; ?>images/arrow.gif" width="12" height="12" border="0"></td><td width="390"><b><a href="<?php echo print_url("submit.php?action=logout"); ?>">Log Out</a></b></td></tr>
	</table>
	</blockquote>
		<?php
	}
}

// show login form
else if($action=="login") {

// print out an error message if login failed
if($errormsg && $login) {
	echo "<p class=\"instructions\"><b>".sanitize_output($errormsg)."</b></p>";
}

?>

<p><b>Please login to edit an abstract or paper you have previously submitted.</b></p>
<p><form action="<?php echo print_url("submit.php"); ?>" method="post">
<input type="hidden" name="login" value="1">
Username: <input type="text" name="username"><br />
Password: <input type="password" name="password"><br />
<input type="checkbox" name="save" value="1"> Save username and password in cookie for one month<br />
<input type="submit" value="Login" class="button"> <input type="reset" class="button">
</form></p>
<script type="text/javascript">
document.forms[0].username.focus();
</script>

<p><b><a href="<?php echo print_url("forgotpw.php?type=noninvited"); ?>">Forgot Password?</a></b></p>

<?php

}

// show options
else {
?>

<blockquote>
<table border="0" width="500" cellpadding="1" cellspacing="0" border="0">
<tr><td width="16" height="18" valign="middle"><img src="<?php echo $themesdir; ?>images/arrow.gif" width="12" height="12" border="0"></td><td width="488"><b><?php 

// no longer allow new submissions if abstract deadline has passed, if applicable, or if the conference has ended
if(($conference_items[deadline_close]=="true" && time()>=(strtotime($conference_items[abstract_deadline])+86400)) || time()>=(strtotime($conference_items[end_date])+86400)) {
	echo "New submissions are no longer being accepted";
}
// else show link to submit a new abstract or paper
else {
	echo "<a href=\"".print_url("submit.php?action=new")."\">Submit a New Abstract or Paper</a>";
}

?></b></td></tr>
<tr><td width="16" height="18" valign="top"><img src="<?php echo $themesdir; ?>images/arrow.gif" width="12" height="12" border="0"></td><td width="488"><b><a href="<?php echo print_url("submit.php?action=login"); ?>">Login if You Have Previously Submitted an Abstract or Paper</a></b></td></tr>
</table>
</blockquote>
<?php

}

// include the html footer file
include("include/footer.inc.php");

?>
